/*
 * libmedia-service
 *
 * Copyright (c) 2000 - 2011 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: Hyunjun Ko <zzoon.ko@samsung.com>, Haejeong Kim <backto.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

#include <media-util-err.h>
#include "media-svc-album.h"
#include "media-svc-debug.h"
#include "media-svc-env.h"
#include "media-svc-util.h"
#include "media-svc-db-utils.h"

int _media_svc_get_album_id(sqlite3 *handle, const char *album, const char *artist, int *album_id)
{
	int ret = MS_MEDIA_ERR_NONE;
	sqlite3_stmt *sql_stmt = NULL;
	char *sql = NULL;

	media_svc_retvm_if(album == NULL, MS_MEDIA_ERR_INVALID_PARAMETER, "album is NULL");

	if (artist != NULL)
		sql = sqlite3_mprintf("SELECT album_id FROM %s WHERE name = '%q' AND artist = '%q';", MEDIA_SVC_DB_TABLE_ALBUM, album, artist);
	else
		sql = sqlite3_mprintf("SELECT album_id FROM %s WHERE name = '%q' AND artist IS NULL;", MEDIA_SVC_DB_TABLE_ALBUM, album);

	ret = _media_svc_sql_prepare_to_step(handle, sql, &sql_stmt);

	if (ret != MS_MEDIA_ERR_NONE) {
		if (ret == MS_MEDIA_ERR_DB_NO_RECORD)
			media_svc_debug("there is no album.");
		else
			media_svc_error("error when _media_svc_get_album_id. err = [%d]", ret);

		return ret;
	}

	*album_id = sqlite3_column_int(sql_stmt, 0);

	SQLITE3_FINALIZE(sql_stmt);

	return ret;
}

int _media_svc_append_album(sqlite3 *handle, bool is_direct, const char *album, const char *artist, const char *album_art, int *album_id, uid_t uid)
{
	int ret = MS_MEDIA_ERR_NONE;

	char *sql = sqlite3_mprintf("INSERT INTO %s (name, artist, album_art) values (%Q, %Q, %Q);", MEDIA_SVC_DB_TABLE_ALBUM, album, artist, album_art);
	if (is_direct)
		ret = _media_svc_sql_query_direct(sql, uid);
	else
		ret = _media_svc_sql_query(sql, uid);

	SQLITE3_SAFE_FREE(sql);
	media_svc_retv_if(ret != MS_MEDIA_ERR_NONE, ret);

	int inserted_album_id = 0;
	ret = _media_svc_get_album_id(handle, album, artist, &inserted_album_id);
	media_svc_retv_if(ret != MS_MEDIA_ERR_NONE, ret);

	*album_id = inserted_album_id;

	return MS_MEDIA_ERR_NONE;
}
