/*
 * Media Service
 *
 * Copyright (c) 2010 - 2012 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
#include <unicode/uchar.h>
#include <unicode/ustring.h>

#include <stdlib.h>
#include <stdbool.h>
#include <string.h>

#include "media-util-err.h"
#include "media-svc-debug.h"
#include "media-svc-localize_ch.h"
#include "media-svc-util.h"


#define CHINESE_COUNT						20902
#define CHINESE_DUOYINZI_MAX_COUNT			6


#define CHINESE_UNICODE_START				0x4E00
#define CHINESE_UNICODE_END					0x9FA5

static const char *const pinyin_spell_table[] = {
	"yi", "ding|zheng", "kao|qiao|yu", "qi", "shang", "xia", "mo", "wan|mo", "zhang", "san",
	"shang", "xia", "qi|ji", "bu|fou", "yu", "mian", "gai", "chou", "chou", "zhuan",
	"qie|ju", "pi", "shi", "shi", "qiu", "bing", "ye", "cong", "dong", "si",
	"cheng", "diu", "qiu", "liang", "diu", "you", "liang", "yan", "bing", "sang",
	"gun", "jiu", "ge", "ya", "pan", "zhong", "ji", "jie", "feng", "guan|kuang",
	"chuan", "chan", "lin", "zhuo", "zhu", "ba", "wan", "dan", "wei", "zhu",
	"jing", "li", "ju", "pie", "fu", "yi|ji", "yi", "nai", "wu", "jiu",
	"jiu", "tuo|zhe", "me|yao|mB", "yi", "ho", "zhi", "wu", "zha", "hu", "fa",
	"le|yue", "yin", "ping", "pang", "qiao", "hu", "guai", "cheng|sheng", "cheng|sheng", "yi",
	"hao", "zhe", "mie|nie", "jiu", "qi", "ye", "xi", "xiang", "gai", "jiu",
	"hal", "hol", "shu", "dou", "shi", "ji", "nang", "kal", "keol", "tol",
	"mol", "ol", "mai", "luan", "cal", "ru", "xue", "yan", "phoi", "sha",
	"na", "qian", "sol", "er", "zu", "ceor", "qian|gan", "zhi|luan", "gui", "qian",
	"luan", "lin", "yi", "jue", "liao|le", "ma", "yu", "zheng", "shi", "shi",
	"er", "chu", "yu", "kui", "yu", "yun", "hu", "qi", "wu", "jing",
	"si", "sui", "gen", "gen", "ya", "xie|suo", "ya", "qi|zhai", "ya", "ji|qi",
	"tou", "wang|wu", "kang", "da", "jiao", "hai", "yi", "chan", "heng|peng", "mu",
	"ye", "xiang", "jing", "ting", "liang", "xiang", "jing", "ye", "qin|qing", "bo",
	"you", "xie", "dan", "lian", "duo", "wei|men", "ren", "ren", "ji", "ji",
	"wang", "yi", "shi|shen", "ren", "le", "ding", "ze", "jin", "pu", "chou|qiu",
	"ba", "zhang", "jin", "jie", "bing", "reng", "cong|zong", "fo", "jin|san", "lun",
	"bing", "cang", "zi|zai", "shi", "ta", "zhang", "fu", "xian", "xian", "tuo|cha|duo",
	"hong", "tong", "ren", "qian", "gan|han", "yi|ge", "bo", "dai", "ling", "yi",
	"chao", "chang|zhang", "sa", "chang", "yi", "mu", "men", "ren", "fan", "chao|miao",
	"yang|ang", "qian", "zhong", "pi", "wo", "wu", "jian", "jia|jie", "yao|fo", "feng",
	"cang", "ren", "wang", "fen|bin", "di", "fang", "zhong", "qi", "pei", "yu",
	"diao", "dun", "wen", "yi", "xin", "kang", "yi", "ji", "ai", "wu",
	"ji|qi", "fu", "fa", "xiu|xu", "jin", "pi", "dan", "fu", "tang", "zhong",
	"you", "huo", "hui|kuai", "yu", "cui", "yun", "san", "wei", "chuan|zhuan", "che|ju",
	"ya", "qian", "shang", "chang", "lun", "cang|chen", "xun", "xin", "wei", "zhu",
	"chi", "xian|xuan", "nu", "bo|bai|ba", "gu", "ni", "ni", "xie", "ban", "xu",
	"ling", "zhou", "shen", "qu", "si|ci", "peng", "si|shi", "qie|jia|ga", "pi", "zhi",
	"si", "yi|chi", "zheng", "dian|tian", "han|gan", "mai", "dan", "zhu", "bu", "qu",
	"bi", "zhao|shao", "ci", "wei", "di", "zhu", "zuo", "you", "yang", "ti|ben",
	"zhan|dian", "he", "bi", "tuo", "she", "yu", "yi|die", "fo|fu|bi|bo", "zuo", "gou|kou",
	"ning", "tong", "ni", "xian", "qu", "yong", "wa", "qian", "shi", "ka",
	"bao", "pei", "hui|huai", "ge", "lao", "xiang", "ge", "yang", "bai", "fa",
	"ming", "jia", "er|nai", "bing", "ji", "hen", "huo", "gui", "quan", "tiao",
	"jiao", "ci", "yi", "shi", "xing", "shen", "tuo", "kan", "zhi", "gai",
	"lai", "yi", "chi", "kua", "gong", "li", "yin", "shi", "mi", "zhu",
	"xu", "you", "an", "lu", "mou", "er", "lun", "dong|tong", "cha", "chi",
	"xun", "gong", "zhou", "yi", "ru", "cun", "xia", "si", "dai", "lv",
	"ta", "jiao|yao", "zhen", "ce|ze|zhai", "qiao", "kuai", "chai", "ning", "nong", "jin",
	"wu", "hou", "jiong", "cheng|ting", "zhen", "zuo", "hao", "qin", "lv", "jv",
	"shu|dou", "ting", "shen", "tuo|tui", "bo", "nan", "xiao", "bian|pian", "tui", "yu",
	"xi", "cu", "e", "qiu", "xu", "guang", "ku", "wu", "jun", "yi",
	"fu", "liang", "zu", "qiao|xiao", "li", "yong", "hun", "jing", "qian", "san",
	"pei", "su", "fu", "xi", "li", "fu", "ping", "bao", "yu|shu", "si|qi",
	"xia", "xin|shen", "xiu", "yu", "di", "che|ju", "chou", "zhi", "yan", "liang|lia",
	"li", "lai", "si", "jian", "xiu", "fu", "huo", "ju", "xiao", "pai",
	"jian", "biao", "chu|ti", "fei", "feng", "ya", "an", "bei", "yu", "xin",
	"bi", "hu|chi", "chang", "zhi", "bing", "jiu", "yao", "cui|zu", "liang|lia", "wan",
	"lai", "cang", "zong", "ge", "guan", "bei", "tian", "shu", "shu", "men",
	"dao", "tan", "jue", "chui", "xing", "peng", "tang|chang", "hou", "yi", "qi",
	"ti", "gan", "liang|jing", "jie", "sui", "chang", "jie", "fang", "zhi", "kong",
	"juan", "zong", "ju", "qian", "ni", "lun", "zhuo", "wo|wei", "luo", "song",
	"leng", "hun", "dong", "zi", "ben", "wu", "ju", "nai", "cai", "jian",
	"zhai", "ye", "zhi", "sha", "qing", "ning", "ying", "cheng|chen", "qian", "yan",
	"ruan", "zhong|tong", "chun", "jia", "ji|jie", "wei", "yu", "bing", "ruo", "ti",
	"wei", "pian", "yan", "feng", "tang|dang", "wo", "e", "xie", "che", "sheng",
	"kan", "di", "zuo", "cha", "ting", "bei", "xie", "huang", "yao", "zhan",
	"chou|qiao", "an", "you", "jian", "xu", "zha", "ci", "fu", "bi", "zhi",
	"zong", "mian", "ji", "yi", "xie", "xun", "cai|si", "duan", "ce|ze|zhai", "zhen",
	"ou", "tou", "tou", "bei", "zan|za|zBn", "lv|lou", "jie", "wei", "fen", "chang",
	"kui|gui", "sou", "zhi|si", "su", "xia", "fu", "yuan", "rong", "li", "nu",
	"yun", "jiang|gou", "ma", "bang", "dian", "tang", "hao", "jie", "xi", "shan",
	"qian|jian", "que|jue", "cang|chen", "chu", "san", "bei", "xiao", "rong", "yao", "ta|tan",
	"suo", "yang", "fa", "bing", "jia", "dai", "zai", "tang", "gu", "bin",
	"chu", "nuo", "can", "lei", "cui", "yong", "zao|cao", "zong", "peng", "song",
	"ao", "chuan|zhuan", "yu", "zhai", "qi|cou", "shang", "chuang", "jing", "chi", "sha",
	"han", "zhang", "qing", "yan", "di", "xie", "lv|lou", "bei", "piao|biao", "jin",
	"lian", "lu", "man", "qian", "xian", "tan", "ying", "dong", "zhuan", "xiang",
	"shan", "qiao", "jiong", "tui", "zun", "pu", "xi", "lao", "chang", "guang",
	"liao", "qi", "cheng|deng", "zhan|zhuan|chan", "wei", "ji", "bo", "hui", "chuan", "tie|jian",
	"dan", "jiao|yao", "jiu", "seng", "fen", "xian", "yu|ju", "e|wu", "jiao", "jian",
	"tong|zhuang", "lin", "bo", "gu", "xian", "su", "xian", "jiang", "min", "ye",
	"jin", "jia|jie", "qiao", "pi", "feng", "zhou", "ai", "sai", "yi", "jun",
	"nong", "chan|tan|shan", "yi", "dang", "jing", "xuan", "kuai", "jian", "chu", "dan",
	"jiao", "sha", "zai", "can", "bin", "an", "ru", "tai", "chou", "chai",
	"lan", "ni|yi", "jin", "qian", "meng", "wu", "ning", "qiong", "ni", "chang",
	"lie", "lei", "lv", "kuang", "bao", "yu", "biao", "zan", "zhi", "si",
	"you", "hao", "qing", "chen", "li", "teng", "wei", "long", "chu", "chan",
	"rang|xiang", "shu", "hui|xie", "li", "luo", "zan", "nuo", "tang", "yan", "lei",
	"nang", "er", "wu", "yun", "zan", "yuan", "xiong", "chong", "zhao", "xiong",
	"xian", "guang", "dui|rui|yue", "ke", "dui|rui|yue", "mian", "tu", "chang|zhang", "er", "dui|rui|yue",
	"er|ni", "jin", "tu", "si", "yan", "yan", "shi", "shike", "dang", "qibnke",
	"dou", "gongfenPPPU", "hboke", "shen", "dou", "baike", "jing", "gongli", "huang", "ru",
	"wang", "nei", "quan", "liang", "yu|shu", "ba", "gong", "liu|lu", "xi", "han",
	"lan", "gong", "tian", "guan", "xing", "bing", "qi|ji", "ju", "dian", "zi|ci",
	"bun", "yang", "jian", "shou", "ji", "yi", "ji", "chan", "jiong", "mao",
	"ran", "nei|na", "yuan", "mao", "gang", "ran", "ce", "jiong", "ce", "zai",
	"gua", "jiong", "mao", "zhou", "mao|mo", "gou", "xu", "mian", "mi", "rong",
	"yin|you", "xie", "kan", "jun", "nong", "yi", "shen", "shi", "guan", "meng",
	"zhong", "zui", "yuan", "ming", "kou", "lin", "fu", "xie", "mi", "bing",
	"dong", "tai", "gang", "feng|ping", "bing", "hu", "chong", "jue", "ya", "kuang",
	"ye", "leng", "pan", "fa", "min", "dong", "xian", "lie", "qia", "jian",
	"jing|cheng", "sou", "mei", "tu", "qi", "gu", "zhun", "song", "jing|cheng", "liang",
	"qing", "diao", "ling", "dong", "gan", "jian", "yin", "cou", "ai", "li",
	"cang", "ming", "zhun", "cui", "si", "duo", "jin", "lin", "lin", "ning",
	"xi", "du", "ji", "fan", "fan", "fan", "feng", "ju", "chu", "yi kB|yi kB no bo li|tB ko",
	"feng", "mu", "zhi", "fu", "feng", "ping", "feng", "kai", "huang", "kai",
	"gan", "deng", "ping", "kan|qian", "xiong", "kuai", "tu", "ao|wa", "chu", "ji",
	"dang", "han", "han", "zao", "dao", "diao", "dao", "ren", "ren", "chuang",
	"fen", "qie", "yi", "ji", "kan", "qian", "cun", "chu", "wen", "ji",
	"dan", "xing", "hua", "wan", "jue", "li", "yue", "lie", "liu", "ze",
	"gang", "chuang", "fu", "chu", "qu", "diao", "shan", "min", "ling", "zhong",
	"pan", "bie", "jie", "jie", "pao|bao", "li", "shan", "bie", "chan", "jing",
	"gua", "geng", "dao", "chuang", "kui", "ku", "duo", "er", "zhi", "shua",
	"quan|xuan", "cha|sha", "ci", "ke", "jie", "gui", "ci", "gui", "kai", "duo",
	"ji", "ti", "jing", "dou", "luo", "ze", "yuan", "cuo", "xiao|xue", "kei|ke",
	"la", "qian", "cha|sha", "chuang", "gua", "jian", "cuo", "li", "ti", "fei",
	"pou", "chan", "qi", "chuang", "zi", "gang", "wan", "bao|bo", "ji", "duo",
	"qing", "yan|shan", "du|zhuo", "jian", "ji", "bao|bo", "yan", "ju", "huo", "sheng",
	"jian", "duo", "zhi|duan", "wu", "gua", "fu|pi", "sheng", "jian", "ge", "da|zha",
	"kai", "chuang", "chuan", "chan", "tuan|zhuan", "lu|jiu", "li", "peng", "shan", "piao",
	"kou", "jiao|chao", "gua", "qiao", "jue", "hua", "zha", "zhuo", "lian", "ju",
	"pi", "liu", "gui", "jiao|chao", "gui", "jian", "jian", "tang", "huo", "ji",
	"jian", "yi", "jian", "zhi", "chan", "zuan", "mo", "li", "zhu", "li",
	"ya", "quan", "ban", "gong", "jia", "wu", "mai", "lie", "jin|jing", "keng",
	"xie|lie", "zhi", "dong", "zhu|chu", "nu", "jie", "qu", "shao", "yi", "zhu",
	"miao", "li", "jin|jing", "lao", "lao", "juan", "kou", "yang", "wa", "xiao",
	"mou", "kuang", "jie", "lie", "he", "shi", "ke", "jin|jing", "gao", "bo|bei",
	"min", "chi", "lang", "yong", "yong", "mian", "ke", "xun", "juan", "qing",
	"lu", "bu", "meng", "chi", "le|lei", "kai", "mian", "dong", "xu", "xu",
	"kan", "wu", "yi", "xun", "weng|yang", "sheng", "lao", "mu", "lu", "piao",
	"shi", "ji", "qin", "jiang", "jiao|chao", "quan", "xiang", "yi", "qiao", "fan",
	"juan", "tong|dong", "ju", "dan", "xie", "mai", "xun", "xun", "lv", "li",
	"che", "rang|xiang", "quan", "bao", "shao", "yun", "jiu", "bao", "gou", "wu",
	"yun", "mo", "xiong", "gai", "gai", "bao", "cong", "yi", "xiong", "peng",
	"ju", "tao|yao", "ge", "pu", "e", "pao", "fu", "gong", "da", "jiu",
	"gong", "bi", "hua", "bei", "nao", "chi|shi", "fang", "jiu", "yi", "za",
	"jiang", "kang", "jiang", "kuang", "hu", "xia", "qu", "fan", "gui", "qie",
	"zang|cang", "kuang", "fei", "hu", "yu", "gui", "kui|gui", "hui", "dan", "kui|gui",
	"lian", "lian", "suan", "du", "jiu", "jue", "xi", "pi", "qu|ou", "yi",
	"ke|qia", "yan", "bian", "ni", "qu|ou", "shi", "xun", "qian", "nian", "sa",
	"zu", "sheng", "wu", "hui", "ban", "shi", "xi", "wan", "hua", "xie",
	"wan", "bei", "zu|cu", "zhuo", "xie", "dan|shan|chan", "mai", "nan|na", "dan", "ji",
	"bo", "shuai|lv", "bu|bo", "guan|kuang", "bian", "bu", "zhan", "qia|ka", "lu", "you",
	"lu", "xi", "gua", "wo", "xie", "jie", "jie", "wei", "yang|ang", "qiong",
	"zhi", "mao", "yin", "wei", "shao", "ji", "que", "luan", "chi", "juan",
	"xie", "xu", "jin", "que", "wu", "ji", "e", "qing", "xi", "san",
	"chang|an|han", "wei", "e", "ting", "li", "zhe|zhai", "han|an", "li", "ya", "ya",
	"yan", "she", "di", "zha|zhai", "pang", "ya", "qie", "ya", "zhi|shi", "ce",
	"mang", "ti", "li", "she", "hou", "ting", "zui", "cuo", "fei", "yuan",
	"ce", "yuan", "xiang", "yan", "li", "jue", "sha|xia", "dian", "chu", "jiu",
	"jin", "ao", "gui", "yan", "si", "li", "chang", "qian|lan", "li", "yan",
	"yan", "yuan", "si|mou", "gong|hong", "lin|miao", "rou|qiu", "qu", "qu", "ke", "lei",
	"du", "xian|xuan", "zhuan", "san", "can|shen|cen|san", "can|shen|cen|san", "can|shen|cen|san", "can|shen|cen|san", "ai|yi", "dai",
	"you", "cha", "ji", "you", "shuang", "fan", "shou", "guai", "ba", "fa",
	"ruo", "li", "shu", "zhuo|yi|li|jue", "qu", "shou", "bian", "xu", "jia", "pan",
	"sou", "ji", "wei|yu", "sou", "die", "rui", "cong", "kou", "gu", "ju|gou",
	"ling", "gua", "tao|dao", "kou", "zhi", "jiao", "zhao|shao", "ba", "ding", "ke",
	"tai", "chi", "shi", "you", "qiu", "po", "ye|xie", "hao", "si", "tan",
	"chi", "le", "diao", "ji", "dug", "hong", "mie", "xu|yu", "mang", "chi",
	"ge", "xuan|song", "yao", "zi", "he|ge", "ji", "diao", "dou|cun", "tong", "ming",
	"hou", "li", "tu", "xiang", "zha", "xia|he", "ye", "lv", "a", "ma|mB",
	"ou", "huo", "yi", "jun", "chou", "lin", "tun", "yin", "fei", "pi|bi",
	"qin", "qin", "jie|ge", "bu", "fou|pi", "ba", "dun", "fen", "e|hua", "han",
	"ting", "hang|keng", "shun", "qi", "hong", "zhi|zi", "yin|shen", "wu", "wu", "chao",
	"na|ne", "xue|chuo|jue", "xi", "chui", "dou|ru", "wen", "hou", "hou|hong|ou", "wu|yu", "gao",
	"ya|yB", "jun", "lv", "e", "ge", "wen", "dai", "qi", "cheng", "wu",
	"gao", "fu", "jiao", "hong", "chi", "sheng", "na|ne", "tun|tian", "fu|?", "yi",
	"dai", "ou", "li", "bei|bai", "yuan|yun", "wai|he|wo|wa|gua|guo", "hua|qi", "qiang", "wu", "e",
	"shi", "juan", "pen", "wen|min", "ne", "mou|m", "ling", "ran", "you", "di",
	"zhou", "shi", "zhou", "tie|che", "xi", "yi", "qi|zhi", "ping", "zi|ci", "gua|gu",
	"zi|ci", "wei", "xu|hou|gou", "he|a|ke", "nao", "xia", "pei", "yi", "xiao|hao", "shen",
	"hu", "ming", "da|dan", "qu", "ju|zui", "xian|gan", "za", "tuo", "duo", "pou",
	"pao", "bi", "fu", "yang", "he", "zha|za", "he|huo|hu", "hai", "jiu", "yong",
	"fu", "da", "zhou", "wa", "ka", "gu", "ka|ga", "zuo", "bu", "long",
	"dong", "ning", "tuo", "si", "xian", "huo", "qi", "er", "e", "guang",
	"zha", "die|xi", "yi", "lie", "zi", "mie", "mi", "zhi", "yao", "ji|xi|qia",
	"zhou", "ka|luo|lo|ge", "shu|xun", "zan|za|zBn", "xiao", "ke|hai", "hui", "kua", "huai|shi", "tao",
	"xian", "e|an", "xuan", "xiu", "wai|he|wo|wa|gua|guo", "yan|ye", "lao", "yi", "ai", "pin",
	"shen", "tong", "hong", "xiong", "duo", "wa|wB", "ha", "zai", "you", "die|di",
	"pai", "xiang", "ai", "gen|hen", "kuang", "ya", "da", "xiao", "bi", "yue|hui",
	"nian", "hua", "xing", "kuai", "duo", "po", "ji|jie|zhai", "nong", "mou", "yo",
	"hao", "yuan|yun", "long", "pou", "mang", "ge", "o", "chi", "shao", "li",
	"na|nei|nB|ne", "zu", "he", "ku", "xiao", "xian", "lao", "po|ba|bo", "zhe", "zha",
	"liang|lang", "ba", "mie", "lie|lv", "sui", "fu", "bu", "han", "heng|hng", "geng",
	"chuo|yue", "ge|jia", "you", "yan", "gu", "gu", "bei|bai", "han", "suo", "chun",
	"yi", "ai", "jia|qian", "tu", "dan|xian|yan", "wan", "li", "xi", "tang", "zuo",
	"qiu", "che", "wu", "zao", "ya", "dou", "qi", "di", "qin", "ma",
	"ma", "gong|hong", "dou", "ge", "lao", "liang", "suo", "zao", "huan", "leng",
	"sha|shB", "ji", "zu", "wo|wei", "feng", "jin|yin", "hu|xia", "qi", "shou", "wei",
	"shua", "chang", "er|wa", "li", "qiang", "an", "jie|ze|zuo", "yo", "nian", "yu",
	"tian", "lai", "sha", "xi", "tuo", "hu", "ai", "zhou|zhao|tiao", "gou", "ken",
	"zhuo", "zhuo|zhao", "shang", "di", "heng", "lan|lin", "a", "cai", "qiang", "zhun|tun|xiang|dui",
	"wu", "wen", "cui|qi", "sha|jie|die|ti", "gu", "qi", "qi", "tao", "dan", "dan",
	"yue|wa", "zi|ci", "bi|tu", "cui", "chuo|chuai", "he", "ya", "qi", "zhe", "fei",
	"liang", "xian", "pi", "sha", "lB|la", "ze", "qing|ying", "gua", "pa", "ze|shi",
	"se", "zhuan", "nie", "guo", "luo", "yan", "di", "quan", "tan|chan|tuo", "bo",
	"ding", "lang", "xiao", "ju", "tang", "chi", "ti", "an", "jiu", "dan",
	"ka", "yong", "wei", "nan", "shan", "yu", "zhe", "la", "jie", "hou",
	"han", "die|zha", "zhou", "chai", "wai", "nuo|re", "huo|guo|xu", "yin", "zan|za|zBn", "yao",
	"o|wo", "mian", "hu", "yun", "chuan", "hui", "huan", "huan|yuan|xuan|he", "xi", "he|ye",
	"ji", "kui", "zhong|chuang", "wei", "sha", "xu", "huang", "duo|zha", "yan", "xuan",
	"liang", "yu", "sang", "chi", "qiao|jiao", "yan", "dan|shan|chan", "pen|ben", "can|sun|qi", "li",
	"yo", "zha|cha", "wei", "miao", "ying", "pen", "pbo", "kui", "xi", "yu",
	"jie", "lou", "ku", "zao|qiao", "hu", "ti", "yao", "he|xiao|hu", "sha|a", "xiu",
	"qiang", "se", "yong", "su", "gong|hong", "xie", "yi|ai", "suo", "ma|mB", "cha",
	"hai", "ke", "ta|da", "sang", "chen", "ru", "sou", "wa|gu", "ji", "beng|pang",
	"wu", "xian|qian|qie", "shi", "ge", "zi", "jie", "lao", "weng", "wa", "si",
	"chi", "hao", "suo", "jia", "hai|hei", "suo", "qin", "nie", "he", "zi",
	"sai", "ng", "ge", "na", "dia", "ai", "qiang", "tong", "bi", "ao",
	"ao", "lian", "zui|sui", "zhe|zhu", "mo", "sou", "sou", "tan", "di", "qi",
	"jiao", "chong", "jiao|dao", "kai|ge", "tan", "shan|can", "cao", "jia", "ai", "xiao",
	"piao", "lou", "ga", "gu", "xiao|jiao", "hu", "hui", "guo", "ou", "xian",
	"ze", "chang", "xu|shi", "po", "de|dei", "ma", "ma", "hu", "le", "du",
	"ga", "tang", "ye", "beng", "ying", "sai", "jiao", "mi", "xiao", "hua",
	"mai", "ran", "zuo", "peng", "lao", "xiao", "ji", "zhu", "chao|zhao", "kui",
	"zui", "xiao", "si", "hao", "fu|?", "liao", "qiao", "xi", "chu|xu|shou", "tan|chan",
	"dan|tan", "hei|mo", "xun", "e", "zun", "fan|bo", "chi", "hui", "zan", "chuang",
	"cu|za|he", "dan", "jue", "tun|kuo", "ceng", "jiao", "ye", "xi", "qi", "hao",
	"lian", "xu|shi", "deng", "hui", "yin", "pu", "jue", "qin", "xun", "nie",
	"lu", "si", "yan", "ying", "da", "zhan", "o", "zhou|zhuo", "jin", "nong",
	"yue|hui", "xie", "qi", "e", "zao", "yi", "shi", "jiao|qiao|chi", "yuan", "ai",
	"yong", "jue|xue", "kuai", "yu", "pen", "dao", "ga", "xin|hen", "dun", "dang",
	"xin", "sai", "pi", "pi", "yin", "zui", "ning", "di", "lan", "ta",
	"huo|o", "ru", "hao", "he|xia", "yan", "duo", "xiu|pi", "zhou|chou", "ji|jie|zhai", "jin",
	"hao", "ti", "chang", "xun", "me", "ca|cha", "ti", "lu", "hui", "bo|pao|bao",
	"you", "nie", "yin", "hu", "mei|me|mo", "hong", "zhe", "li", "liu", "xie|hai",
	"nang", "xiao", "mo", "yan", "li", "lu", "long", "po", "dan", "chen",
	"pin", "pi", "xiang", "huo", "me", "xi", "duo", "ku", "yan", "chan",
	"ying", "rang", "dian", "la", "ta", "xiao", "jiao|jue", "chuo", "huan", "huo",
	"zhuan", "nie", "xiao", "ca", "li", "chan", "chai", "li", "yi", "luo",
	"nang", "za|zan|can", "su", "xi", "zeng", "jian", "yan|za|nie", "zhu", "lan", "nie",
	"nang", "ramo", "luo", "wei|guo", "hui", "yin", "qiu", "si", "nin", "jian|nan",
	"hui", "xin", "yin", "nan", "tuan", "tuan", "dun|tun", "kang", "yuan", "jiong",
	"pian", "yun", "cong", "hu", "hui", "yuan", "e", "guo", "kun", "cong",
	"wei|tong", "tu", "wei", "lun", "guo", "qun", "ri", "ling", "gu", "guo",
	"tai", "guo", "tu", "you", "guo", "yin", "hun", "pu", "yu", "han",
	"yuan", "lun", "quan|juan", "yu", "qing", "guo", "chuan|chui", "wei", "yuan", "quan|juan",
	"ku", "pu", "yuan", "yuan", "ya", "tuan", "tu", "tu", "tuan", "lve",
	"hui", "yi", "huan|yuan", "luan", "luan", "tu", "ya", "tu", "ting", "sheng",
	"pu", "lu", "kuai", "ya", "zai", "wei|xu", "ge", "yu|zhun", "wu", "gui",
	"pi", "yi", "di|de", "qian|su", "qian", "zhen", "zhuo", "dang", "qia", "xia",
	"shan", "kuang", "chang", "qi|yin", "nie", "mo", "ji", "jia", "zhi", "zhi",
	"ban", "xun", "yi", "qin", "mei|fen", "jun", "rong|keng", "tun|dun", "fang", "ben|fen",
	"ben", "tan", "kan", "huai|pei|pi", "zuo", "keng", "bi", "jing", "di|lan", "jing",
	"ji", "kuai", "di", "jing", "jian", "tan", "li", "ba", "wu", "fen",
	"zhui", "po", "pan|ban", "tang", "kun", "qu", "tan", "zhi", "tuo", "gan",
	"ping", "dian", "gua", "ni", "tai", "pi", "jiong", "yang", "fo", "ao",
	"lu", "qiu", "mu", "ke", "gou", "xue", "fa", "di|chi", "che", "ling",
	"zhu", "fu", "hu", "zhi", "chui", "la", "long", "long", "lu", "ao",
	"dai", "pao", "min", "xing", "dong|tong", "ji", "he", "lv", "ci", "chi",
	"lei", "gai", "yin", "hou", "dui", "zhao", "fu", "guang", "yao", "duo",
	"duo", "gui", "cha", "yang", "yin", "fa", "gou", "yuan", "die", "xie",
	"ken", "shang", "shou", "e", "bing", "dian", "hong", "ya", "kua", "da",
	"ka", "dang", "kai", "hang", "nao", "an", "xing", "xian", "yuan|huan", "bang",
	"pou|fu", "ba", "yi", "yin", "han", "xu", "chui", "cen", "geng", "ai",
	"beng|feng", "di|fang", "que|jue", "yong", "jun", "xia|jia", "di", "mai|man", "lang", "juan",
	"cheng", "yan|shan", "qin|jin", "zhe", "lie", "lie", "pu|bu", "cheng", "hua", "bu",
	"shi", "xun", "guo", "jiong", "ye", "nian", "di", "yu", "bu", "ya",
	"quan", "sui|su", "pi", "qing|zheng", "wan", "ju", "lun", "zheng|cheng", "kong", "chong|shang",
	"dong", "dai", "tan", "an", "cai", "chu|tou", "beng", "xian|kan", "zhi", "duo",
	"yi|shi", "zhi", "yi", "pei", "ji", "zhun", "qi", "sao", "ju", "ni",
	"ku", "ke", "tang", "kun", "ni", "jian", "dui", "jin", "gang", "yu",
	"e", "peng|beng", "gu", "tu", "leng", "fang", "ya", "qian|zan|jian", "kun", "an",
	"shen", "duo|hui", "nao", "tu", "cheng", "yin", "huan", "bi", "lian", "guo",
	"die", "zhuan", "hou", "bao|bu|pu", "bao", "yu", "di", "mao|mou|wu", "jie", "ruan",
	"e|ai|ye", "geng", "kan", "zong", "yu", "huang", "e", "yao", "yan", "bao",
	"ji", "mei", "chang", "du", "tuo", "yin", "feng", "zhong", "jie", "jin",
	"feng", "gang", "chuan", "jian", "ping", "lei", "jiang", "huang", "leng", "duan",
	"wan", "xuan", "xi", "ji", "kuai", "ying", "ta", "cheng", "yong", "kai",
	"su", "su", "shi", "mi", "ta", "weng", "cheng", "tu", "tang", "que",
	"zhong", "li", "peng", "bang", "sai|se", "zang", "dui", "tian", "wu", "zheng",
	"xun", "ge", "zhen", "ai", "gong", "yan", "xian", "tian|zhen", "yuan", "wen",
	"xie", "liu", "hai", "lang", "chang", "peng", "beng", "chen", "lu", "lu",
	"ou|qiu", "qian|zan|jian", "mei", "mo", "zhuan|tuan", "shuang", "shu", "lou", "chi", "man",
	"biao", "jing", "qi", "shu", "zhi|di", "zhang", "kan", "yong", "dian", "chen",
	"zhi|zhuo", "xi", "guo", "qiang", "jin", "shang", "shang", "mu", "cui", "yan",
	"ta", "zeng", "qian", "qiang", "liang", "wei", "zhui", "qiao", "zeng", "xu",
	"shan", "shan", "fa", "pu", "kuai|tui", "tuan|dong", "fan", "qiao|que", "mo", "dun",
	"dun", "zun|dun", "di", "sheng", "duo|hui", "duo", "tan", "deng", "wu", "fen",
	"huang", "tan", "da", "ye", "zhu", "jian", "ao", "qiang", "ji", "qiao|ao",
	"ken", "yi|tu", "pi", "bi", "dian", "jiang", "ye", "yong", "xue|bo|jue", "tan",
	"lan", "ju", "huai", "dang", "rang", "qian", "xun", "xian|lan", "xi", "he",
	"ai", "ya", "dao", "hao", "ruan", "jin", "lei", "kuang", "lu", "yan",
	"tan", "wei", "huai", "long", "long", "rui", "li", "lin", "rang", "chan",
	"xun", "yan", "lei", "ba", "wan", "shi", "ren", "san", "zhuang", "zhuang",
	"sheng", "yi", "mai", "ke|qiao", "zhu", "zhuang", "hu", "hu", "kun", "yi",
	"hu", "xu", "kun", "shou", "mang", "dun", "shou", "yi", "zhi|zhong", "gu|ying",
	"chu", "jiang|xiang", "feng|pang", "bei", "zhai", "bian", "sui", "qun", "ling", "fu",
	"cuo", "xia", "xiong|xuan", "xie", "nao", "xia", "kui", "xi", "wai", "yuan|wan",
	"mao|wan", "su", "duo", "duo", "ye", "qing", "yi", "gou", "gou", "qi",
	"meng", "meng", "yin", "huo", "chen", "da|dai", "ce", "tian", "tai", "fu",
	"guai", "yao", "yang", "hang|ben", "gao", "shi", "tao|ben", "tai", "tou", "yan|tao",
	"bi", "yi", "kua", "jia|ga|xia", "duo", "hua", "kuang", "yun", "jia|ga|xia", "ba",
	"en", "lian", "huan", "di|ti", "yan", "pao", "juan", "qi|ji", "nai", "feng",
	"xie", "fen", "dian", "quan|juan", "kui", "zou", "huan", "qi|qie|xie", "kai", "she|chi|zha",
	"ben", "yi", "jiang", "tao", "zang|zhuang", "ben", "xi", "huang", "fei", "diao",
	"xun|zhui", "beng", "dian", "ao", "she", "weng", "po|ha|tai", "ao|yu", "wu", "ao|yu",
	"jiang", "lian", "duo", "yun", "jiang", "shi", "fen", "huo", "bi", "luan",
	"duo|che", "nv", "nu", "ding|tian", "nai", "qian", "jian", "ta|jie", "jiu", "nuan",
	"cha", "hao", "xian", "fan", "ji", "shuo", "ru", "fei|pei", "wang", "hong",
	"zhuang", "fu", "ma", "dan", "ren", "fu|you", "jing", "yan", "hai|jie", "wen",
	"zhong", "pa", "du", "ji", "keng|hang", "zhong", "yao", "jin", "yun", "miao",
	"fou|pei|pi", "chi", "yue|jue", "zhuang", "niu", "yan", "na|nan", "xin", "fen", "bi",
	"yu", "tuo", "feng", "wan|yuan", "fang", "wu", "yu", "gui", "du", "ba",
	"ni", "zhou", "zhuo", "zhao", "da", "ni|nai", "yuan", "tou", "xian|xuan|xu", "zhi|yi",
	"e", "mei", "mo", "qi", "bi", "shen", "qie", "e", "he", "xu",
	"fa", "zheng", "min", "ban", "mu", "fu", "ling", "zi", "zi", "shi",
	"ran", "shan", "yang", "gan", "jie", "gu", "si", "xing", "wei", "zi",
	"ju", "shan", "pin", "ren", "yao", "dong", "jiang", "shu", "ji", "gai",
	"xiang", "hua|huo", "juan", "jiao|xiao", "gou|du", "mu|lao", "jian", "jian", "yi", "nian",
	"zhi", "zhen", "ji", "xian", "heng", "guang", "jun|xun", "kua|hu", "yan", "ming",
	"lie", "pei", "e", "you", "yan", "cha", "shen|xian", "yin", "shi", "gui",
	"quan", "zi", "song", "wei", "hong", "wa", "lou", "ya", "rao", "jiao",
	"luan", "ping", "xian", "shao", "li", "cheng|sheng", "xie", "mang", "fu", "suo",
	"wu|mu", "wei", "ke", "chuo|lai", "chuo", "ting", "niang", "xing", "nan", "yu",
	"na|nuo", "pou|bi", "nei|sui", "juan", "shen", "zhi", "han", "di", "zhuang", "e",
	"pin", "tui", "man", "mian", "wu|yu", "yan", "wu", "xi|ai", "yan", "yu",
	"si", "yu", "wa", "li", "xian", "ju", "qu", "zhui|shui", "qi", "xian",
	"zhuo", "dong", "chang", "lu", "ai|e", "e", "e", "lou", "mian", "cong",
	"pou|pei|bu", "ju", "po", "cai", "ling", "wan", "biao", "xiao", "shu", "qi",
	"hui", "fu|fan", "wo", "wo", "tan", "fei", "fei", "jie", "tian", "ni",
	"quan|juan", "jing", "hun", "jing", "qian|jin", "dian", "xing", "hu", "wan|wa", "lai",
	"bi", "yin", "zhou|chou", "chuo|nao", "fu", "jing", "lun", "an|n<e", "lan", "hun|kun",
	"yin", "ya", "ju", "li", "dian", "xian", "huB|dB tBi", "hua", "ying", "chan",
	"shen", "ting", "dang|yang", "yao", "wu", "nan", "ruo|chuo", "jia", "tou|yu", "xu",
	"yu", "wei", "di|ti", "rou", "mei", "dan", "ruan|nen", "qin", "hui", "wo",
	"qian", "chun", "miao", "fu", "jie", "duan", "yi|pei", "zhong", "mei", "huang",
	"mian", "an", "ying", "xuan", "jie", "wei", "mei", "yuan", "zheng", "qiu",
	"ti", "xie", "tuo|duo", "lian", "mao", "ran", "si", "pian", "wei", "wa",
	"cu", "hu", "ao|yun|wo", "jie", "bao", "xu", "tou|yu", "gui", "chu|zou", "yao",
	"pi", "xi", "yuan", "ying", "rong", "ru", "chi", "liu", "mei", "pan",
	"ao|yun|wo", "ma", "gou", "kui", "qin|shen", "jia", "sao", "zhen", "yuan", "jie|suo",
	"rong", "ming", "ying", "ji", "su", "niao", "xian", "tao", "pang", "lang",
	"nao", "biao", "ai", "pi", "pin", "yi", "piao", "yu", "lei", "xuan",
	"man", "yi", "zhang", "kang", "yong", "ni", "li", "di", "gui", "yan",
	"jin", "zhuan", "chang", "ze", "han|nan", "nen", "lao", "mo", "zhe", "hu",
	"hu", "ao", "nen", "qiang", "ma", "pie", "gu", "wu", "qiao", "tuo",
	"zhan", "miao", "xian", "xian", "mo", "liao", "lian", "hua", "gui", "deng",
	"zhi", "xu", "yi", "hua", "xi", "kui", "rao", "xi", "yan", "chan",
	"jiao", "mei", "fan", "fan", "xian|yan|jin", "yi", "hui", "jiao", "fu", "shi",
	"bi", "shan", "sui", "qiang", "lian", "huan|xuan|qiong", "xin", "niao", "dong", "yi",
	"can", "ai", "niang", "ning", "mo", "tiao", "chou", "jin", "ci", "yu",
	"pin", "rong", "ru", "nai", "yan", "tai", "ying", "qian", "niao", "yue",
	"ying", "mian", "bi", "mo", "shen", "xing", "ni", "du", "liu", "yuan",
	"lan", "yan", "shuang", "ling", "jiao", "niang", "lan", "xian|qian", "ying", "shuang",
	"xie|hui", "huan|quan", "mi", "li", "luan", "yan", "zhu|chuo", "lan", "zi", "jie",
	"jue", "jue", "kong", "yun", "zi|ma", "zi", "cun", "sun|xun", "fu", "bei",
	"zi", "xiao", "xin", "meng", "si", "tai", "bao", "ji", "gu", "nu",
	"xue", "you", "zhuan", "hai", "luan", "sun|xun", "nao", "mie", "cong", "qian",
	"shu", "chan|can", "ya", "zi", "ni", "fu", "zi", "li", "xue", "bo",
	"ru", "nai", "nie", "nie", "ying", "luan", "mian", "ning", "rong", "ta",
	"gui", "zhai", "qiong", "yu", "shou", "an", "tu|jia", "song", "wan", "rou",
	"yao", "hong", "yi", "jing", "zhun", "mi|fu", "zhu", "dang", "hong", "zong",
	"guan", "zhou", "ding", "wan|yuan", "yi", "bao", "shi", "shi", "chong", "shen",
	"ke", "xuan", "shi", "you", "huan", "yi", "tiao", "shi", "xian", "gong",
	"cheng", "qun", "gong", "xiao", "zai", "zha", "bao|shi", "hai", "yan", "xiao",
	"jia|jiB", "cai", "chen", "rong", "huang", "mi", "kou", "kuan", "bin", "su|xiu",
	"cai", "zan", "ji", "yuan", "ji", "yin", "mi", "kou", "qing", "he",
	"zhen", "jian", "fu", "ning", "bing", "huan", "mei", "qin", "han", "yu",
	"shi", "ning", "jin|qin", "ning", "zhi", "yu", "bao", "kuan", "ning", "qin",
	"mo", "cha", "ju|lou", "gua", "qin", "hu", "wu", "liao", "shi", "ning",
	"zhai", "shen", "wei", "xie", "kuan", "hui", "liao", "jun", "huan", "yi",
	"yi", "bao", "qin", "chong", "bao", "feng", "cun", "dui", "si", "xun",
	"dao", "l<e|luo", "dui", "shou", "po", "feng", "zhuan", "fu", "she|ye|yi", "kei|ke",
	"jiang", "jiang", "zhuan", "wei|yu", "zun", "xun", "shu|zhu", "dui", "dao", "xiao",
	"jie|ji", "shao", "er", "er", "er", "ga", "jian", "shu", "chen", "shang",
	"shang", "mo", "ga", "chang", "liao", "xian", "xian", "hun", "you", "wang",
	"you", "liao", "liao", "yao", "long|mang|meng|pang", "wang", "wang", "wang", "ga", "yao",
	"duo", "kui", "zhong", "jiu", "gan", "gu", "gan", "tui", "gan", "gan",
	"shi", "yin", "chi|che", "kao", "ni", "jin", "wei|yi", "niao|sui", "ju", "pi",
	"ceng", "xi", "bi", "ju", "jie", "tian", "qu", "ti", "jie", "wu",
	"diao", "shi", "shi", "ping|bing", "ji", "xie", "zhen", "xi", "ni", "zhan",
	"xi", "wei", "man", "e", "lou", "ping|bing", "ti", "fei", "shu|zhu", "xie|ti",
	"tu", "lv", "lv", "xi", "ceng", "lv", "ju", "xie", "ju", "jue",
	"liao", "jue", "shu|zhu", "xi", "che|cao", "tun|zhun", "ni|ji", "shan", "wa", "xian",
	"li", "an", "hui", "hui", "hong|long", "yi", "qi", "ren", "wu", "han|an",
	"shen", "yu", "chu", "sui", "qi|kai", "yin", "yue", "ban", "yao", "ang",
	"ya", "wu", "jie", "e", "ji", "qian", "fen", "wan", "qi", "cen",
	"qian", "qi", "cha", "jie", "qu", "gang", "xian", "ao", "lan", "dao",
	"ba", "zuo", "zuo", "yang", "ju", "gang", "ke", "gou", "xue", "po",
	"li", "tiao", "ju", "yan", "fu", "xiu", "jia", "ling", "tuo", "pi",
	"ao", "dai", "kuang", "yue", "qu", "hu", "po", "min", "an", "tiao",
	"ling", "di", "ping", "dong", "zBi|ze mo", "kui", "xiu", "mao", "tong", "xue",
	"yi", "bian", "he", "ke|ba", "luo", "e", "fu|nie", "xun", "die", "lu",
	"en", "er", "gai", "quan", "tong|dong", "yi", "mu", "shi", "an", "wei",
	"huan", "zhi|shi", "mi", "li", "fa", "tong", "wei", "you", "qia", "xia",
	"li", "yao", "jiao|qiao", "zheng", "luan", "jiao", "e", "e", "yu", "xie|ye",
	"bu", "qiao", "qun", "feng", "feng", "nao", "li", "you", "xian", "rong",
	"dao", "shen", "cheng", "tu", "geng", "jun", "gao", "xia", "yin", "wu",
	"lang", "kan", "lao", "lai", "xian", "que", "kong", "chong", "chong", "ta",
	"lin", "hua", "ju", "lai", "qi", "min", "kun", "kun", "zu|cui", "gu",
	"cui", "ya", "ya", "gang", "lun", "lun", "ling", "jue", "duo", "zheng",
	"guo", "yin", "dong", "han", "zheng", "wei", "xiao", "pi|bi", "yan", "song",
	"jie", "beng", "zu", "jue", "dong", "zhan|chan", "gu", "yin", "zi", "ze",
	"huang", "yu", "wai|wei", "yang|dang", "feng", "qiu", "yang", "ti", "yi", "zhi|shi",
	"shi|die", "zai", "yao", "e", "zhu", "kan|zhan", "lv", "yan", "mei", "han",
	"ji", "ji", "huan", "ting", "sheng", "mei", "qian|kan", "wu|mao", "yu", "zong",
	"lan", "ke|jie", "yan", "yan", "wei", "zong", "cha", "sui", "rong", "ke",
	"qin", "yu", "qi", "lou", "tu", "cui", "xi", "weng", "cang", "dang|tang",
	"rong|ying", "jie", "kai|ai", "liu", "wu", "song", "kao|qiao", "zi", "wei", "beng",
	"dian", "cuo", "qin|qian", "yong", "nie", "cuo", "ji", "shi", "ruo", "song",
	"zong", "jiang", "liao", "kang", "yan", "die|di", "cen", "ding", "tu", "lou",
	"zhang", "zhan|chan", "zhan|chan", "ao", "cao", "qu", "qiang", "wei", "zui", "dao",
	"dao", "xi", "yu", "pi|pei", "long", "xiang", "ceng", "bo", "qin", "jiao",
	"yan", "lao", "zhan", "lin", "liao", "liao", "qin", "deng", "tuo", "zun",
	"jiao|qiao", "jue|gui", "yao", "jiao", "yao", "jue", "zhan|shan", "yi", "xue", "nao",
	"ye", "ye", "yi", "nie", "xian", "ji", "xie|jie", "ke|jie", "gui|xi|juan", "di",
	"ao", "zui", "wei", "ni", "rong", "dao", "ling", "jie", "yu", "yue",
	"yin", "ru", "jie", "li|lie", "gui|xi|juan", "long", "long", "dian", "ying|hong", "xi",
	"ju", "chan", "ying", "kui", "yan", "wei", "nao", "quan", "chao", "cuan",
	"luan", "dian", "dian", "nie", "yan", "yan", "yan", "kui", "yan", "chuan",
	"kuai", "chuan", "zhou", "huang", "jing|xing", "xun", "chao", "chao", "lie", "gong",
	"zuo", "qiao", "ju", "gong", "ge", "wu", "pu", "pu", "cha|chai|ci", "qiu",
	"qiu", "ji", "yi", "si", "ba", "zhi", "zhao", "xiang|hang", "yi", "jin",
	"xun", "juan", "pa", "xun", "jin", "fu", "za", "bi", "shi", "bu",
	"ding", "shuai", "fan", "nie", "shi", "fen", "pa", "zhi", "xi", "hu",
	"dan", "wei", "zhang", "tang|nu", "dai", "mo|wa", "pei", "pa", "tie", "fu",
	"lian", "zhi", "zhou", "bo", "zhi", "di", "mo", "yi", "yi", "ping",
	"qia", "juan", "ru", "shuai", "dai", "zhen", "shui", "qiao", "zhen", "shi",
	"qun", "xi", "bang", "dai", "gui", "chou|dao", "ping", "zhang", "jian|san", "wan",
	"dai", "wei", "chang", "sha|qie", "qi|ji", "ze", "guo", "mao", "zhu", "hou",
	"zhen", "zheng", "mi", "wei", "wo", "fu", "yi", "bang", "ping", "die",
	"gong", "pan", "huang", "tao", "mi", "jia", "teng", "hui", "zhong", "shan|qiao|shen",
	"man", "mu", "biao", "guo", "ze", "mu", "bang", "zhang", "jing", "chan",
	"fu", "zhi", "hu", "fan", "chuang|zhuang", "bi", "bi", "zhang", "mi", "qiao",
	"chan", "fen", "meng", "bang", "chou|dao", "mie", "chu", "jie", "xian", "lan",
	"gan", "ping", "nian", "jian", "bing", "bing", "xing", "gan", "yao", "huan",
	"you", "you", "ji", "guang|an", "pi", "ting", "ze", "guang", "zhuang", "me|mo",
	"qing", "bi", "qin", "dun|tun", "chuang", "gui", "ya", "bai|ting", "jie", "xu",
	"lu", "wu", "zhuang", "ku", "ying", "di|de", "pao", "dian", "ya", "miao",
	"geng", "ci", "fu", "tong", "pang", "fei", "xiang", "yi", "zhi", "tiao",
	"zhi", "xiu", "du|duo", "zuo", "xiao", "tu", "gui", "ku", "mang|meng|pang", "ting",
	"you", "bu", "bing|ping", "cheng", "lai", "bei", "ji|cuo", "an", "shu", "kang",
	"yong", "tuo", "song", "shu", "qing", "yu", "yu", "miao", "sou", "ce",
	"xiang", "fei", "jiu", "e", "gui|wei|hui", "liu", "sha|xia", "lian", "lang", "sou",
	"zhi", "bu", "qing", "jiu", "jiu", "jin|qin", "ao", "kuo", "lou", "yin",
	"liao", "dai", "lu", "yi", "chu", "chan", "tu", "si", "xin", "miao",
	"chang", "wu", "fei", "guang", "kao", "kuai", "bi", "qiang|se", "xie", "lin",
	"lin", "liao", "lu", "ji", "ying", "xian", "ting", "yong", "li", "ting",
	"yin", "xun", "yan", "ting", "di", "po|pai", "jian", "hui", "nai", "hui",
	"gong", "nian", "kai", "bian", "yi", "qi", "nong|long", "fen", "ju", "yan",
	"yi", "zang", "bi", "yi", "yi", "er", "san", "shi", "er", "shi",
	"shi", "gong", "diao", "yin", "hu", "fu", "hong", "wu", "tui", "chi",
	"jiang", "ba", "shen", "di|ti|tui", "zhang", "jue|zhang", "tao", "fu", "di", "mi",
	"xian", "hu", "chao", "nu", "jing", "zhen", "yi", "mi", "juan|quan", "wan",
	"shao", "ruo", "xuan|yuan", "jing", "diao", "zhang", "jiang", "qiang|jiang", "peng", "dan|tan",
	"qiang|jiang", "bi", "bi", "she", "dan|tan", "jian", "gou", "ge", "fa", "bi",
	"kou", "jian", "bie", "xiao", "dan|tan", "guo", "qiang|jiang", "hong", "mi", "guo",
	"wan", "jue", "xue", "ji", "gui", "dang", "lu", "lu", "tuan", "hui",
	"zhi", "hui", "hui", "yi", "yi", "yi", "yi", "huo", "huo", "shan|xian",
	"xing", "wen", "tong", "yan", "yan", "yu", "chi", "cai", "biao", "diao",
	"bin", "peng|bang", "yong", "piao", "zhang", "ying", "chi", "chi", "zhuo|bo", "tuo|yi",
	"ji", "pang|fang", "zhong", "yi", "wang", "che", "bi", "di", "ling", "fo",
	"wang", "zheng", "cu", "wang", "jing", "dai", "xi", "xun", "hen", "yang",
	"huai", "lv", "hou", "wang|jia|wa", "cheng|zheng", "zhi", "xu", "jing", "tu", "cong",
	"cong", "lai", "cong", "de|dei", "pai", "xi", "dong", "ji", "chang", "zhi",
	"cong|zong", "zhou", "lai", "yu", "xie", "jie", "jian", "shi|ti", "jia|xia", "bian",
	"huang", "fu", "xun", "wei", "pang", "yao", "wei", "xi", "zheng", "piao",
	"ti|chi", "de", "zhi|zheng", "zhi|zheng", "bie", "de", "zhong|chong", "che", "jiao|yao", "hui",
	"jiao", "hui", "mei", "long", "xiang", "bao", "qu|ju", "xin", "xin", "bi",
	"yi", "le", "ren", "dao", "ding|ting", "gai", "ji", "ren", "ren", "chan",
	"tan", "te", "te|tui", "gan|han", "yi|qi", "shi|tai", "cun", "zhi", "wang", "mang",
	"xi|lie", "fan", "ying", "tian", "min|wen", "min|wen", "zhong", "chong", "wu", "ji",
	"wu", "xi", "jia", "you", "wan", "cong", "song|zhong", "kuai", "yu|shu", "bian",
	"zhi", "qi|shi", "cui", "chen", "tai", "tun|zhun|dun", "qian|qin", "nian", "hun", "xiong",
	"niu", "kuang|wang", "xian", "xin", "kang|hang", "hu", "kai", "fen", "huai", "tai",
	"song", "wu", "ou", "chang", "chuang", "ju", "yi", "bao", "chao", "min|men",
	"pei", "zuo|zha", "zen", "yang", "kou|ju", "ban", "nu", "nao|niu", "zheng", "pa",
	"bu", "tie|zhan", "hu|gu", "hu", "cu|ju|zu", "da", "lian", "si|sai", "you|chou", "di",
	"dai", "yi", "tu|die", "you", "fu", "ji", "peng", "xing", "yuan", "ni",
	"guai", "fei", "xi", "bi", "you|yao", "qie", "xuan", "cong", "bing", "huang",
	"xu|xue", "chu", "bi|pi", "shu", "xi|shu", "tan", "yong", "zong", "dui", "mi",
	"gi", "yi", "shi", "nen|nin", "xun", "shi", "xi", "lao", "heng", "kuang",
	"mou", "zhi", "xie", "lian", "tiao|yao", "huang", "die", "hao", "kong", "gui",
	"heng", "xi|qi|xu", "xiao|jiao", "shu", "si", "hu|kua", "qiu", "yang", "hui", "hui",
	"chi", "jia", "yi", "xiong", "guai", "lin", "hui", "zi", "xu", "chi",
	"shang", "nv", "hen", "en", "ke", "dong", "tian", "gong", "quan|zhuan", "xi",
	"qia", "yue", "peng", "ken", "de", "hui", "e|wu", "qiu", "tong", "yan",
	"kai", "ce", "nao", "yun", "mang", "yong", "yong", "yuan|juan", "pi", "kun",
	"qiao", "yue", "yu|shu", "tu", "jie|ke", "xi", "zhe", "lin", "ti", "han",
	"hao|jiao", "qie", "ti", "bu", "yi", "qian", "hui", "xi", "bei", "man|men",
	"yi", "heng", "song", "quan", "cheng", "kui|li", "wu", "wu", "you", "li",
	"liang", "huan", "cong", "yi|nian", "yue", "li", "nin", "nao", "e", "que",
	"xuan", "qian", "wu", "min", "cong", "fei", "bei", "de", "cui", "chang",
	"men", "li", "ji", "guan", "guan", "xing", "dao", "qi", "kong", "tian",
	"lun", "xi", "kan", "gun", "ni", "qing", "chou", "dun", "guo", "zhan",
	"jing", "wan", "yuan|wan", "jin", "ji", "lan|lin", "yu|xu", "huo", "he", "juan|quan",
	"tan|dan", "ti", "ti", "nian", "wang", "chuo|chui", "hu", "hun|men", "xi", "chang",
	"xin", "wei", "hui", "e|wu", "suo|rui", "zong", "jian", "yong", "dian", "ju",
	"can", "cheng", "de", "bei", "qie", "can", "dan|da", "guan", "duo", "nao",
	"yun", "xiang", "zhui", "die", "huang", "chun", "qiong", "re", "xing", "ce",
	"bian", "min", "zong", "ti|shi", "qiao", "chou", "bei", "xuan", "wei", "ge",
	"qian", "wei", "yu", "yu|tou", "bi", "xuan", "huan", "min", "bi", "yi",
	"mian", "yong", "qi|kai", "dang|shang|tang|yang", "yin", "e", "chen|xin|dan", "mao", "ke|qia", "ke",
	"yu", "ai", "qie", "yan", "nuo", "gan", "yun", "cong|song", "sai|si", "leng",
	"fen", "ying", "kui", "kui", "que", "gong|hong", "yun", "su", "su|shuo", "qi",
	"yao", "song", "huang", "ji", "gu", "ju", "chuang", "ni", "xie", "kai",
	"zheng", "yong", "cao", "xun", "shen", "bo", "kai|xi", "yuan", "xi|xie", "hun",
	"yong", "yang", "li", "cao|sao", "tao", "yin", "ci", "xu|chu", "qian|qie", "tai",
	"huang", "yun", "shen", "ming", "gong|hong", "she", "cao|cong", "piao", "mu", "mu",
	"guo", "chi", "can", "can", "can", "cui", "min", "te", "zhang", "tong",
	"ao", "shuang", "man", "guan", "que", "zao", "jiu", "hui", "kai", "lian",
	"ou", "song", "qin|jin", "yin", "lv", "shang", "wei", "tuan", "man", "qian",
	"she", "yong", "qing", "kang", "di|chi", "zhi|zhe", "lou|lv", "juan", "qi", "qi",
	"yu", "ping", "liao", "cong", "you", "chong", "zhi", "tong", "cheng", "qi",
	"qu", "peng", "bei", "bie", "qiong", "jiao", "zeng", "chi", "lian", "ping",
	"kui", "hui", "qiao", "cheng|deng|zheng", "yin", "yin", "xi", "xi", "dan|da", "tan",
	"duo", "dui", "dui|dun|tun", "su", "jue", "ce", "xiao|jiao", "fan", "fen", "lao",
	"lao", "chong", "han", "qi", "xian", "min", "jing", "liao", "wu", "can",
	"jue", "cu", "xian", "tan", "sheng", "pi", "yi", "chu", "xian", "nao|nang",
	"dan", "tan", "jing", "song", "han", "jiao|ji", "wei", "xuan|huan", "dong", "qin",
	"qin", "ju", "cao|sao", "ken", "xie", "ying", "ao", "mao", "yi", "lin",
	"se", "jun", "huai", "men", "lan", "ai", "lin", "yan", "guo", "xia",
	"chi", "yu", "yin", "dai", "meng", "ai|yi|ni", "meng", "dui", "qi|ji", "mo",
	"lan|xian", "men", "chou", "zhi", "nuo", "nuo", "yan", "yang", "bo", "zhi",
	"kuang", "kuang", "you", "fu", "liu", "mie", "cheng", "hui", "chan", "meng",
	"lan", "huai", "xuan", "rang", "chan", "ji", "ju", "huan", "she", "yi",
	"lian", "nan", "mi", "tang", "jue", "gang|zhuang", "gang|zhuang", "gang|zhuang", "ge", "yue",
	"wu", "jian", "qu", "shu", "rong", "xi|hu", "cheng", "wo", "jie", "ge",
	"jian", "qiang", "huo", "qiang", "zhan", "dong", "qi", "jia", "die", "zei",
	"jia", "ji", "zhi", "kan", "ji", "kui", "gai", "deng", "zhan", "qiang",
	"ge", "jian", "jie", "yu", "jian", "yan", "lu", "xi|hu", "zhan", "xi|hu",
	"xi|hu", "chuo", "dai", "qu", "hu", "hu", "hu", "e", "shi", "ti",
	"mao", "hu", "li", "fang", "suo", "bian|pian", "dian", "jiong", "shang|jiong", "yi",
	"yi", "shan", "hu", "fei", "yan", "shou", "shou", "cai", "za|zha", "qiu",
	"le|li|cai", "pu", "ba|pa", "da", "reng", "fan|fu", "ru", "zai", "tuo", "zhang",
	"diao|di|yue|li", "kang|gang", "yu|wu", "yu|wu|ku", "han", "shen", "cha", "tuo|chi|yi", "gu|xi|ge|jie", "kou",
	"wu", "den", "qian", "zhi", "ren", "kuo", "men", "sao", "yang", "niu",
	"ban", "che", "rao", "xi|cha|qi", "qian|qin", "ban", "jia", "yu", "fu", "ba|ao",
	"xi|zhe", "pi", "di", "zhi|sun|kan", "e", "den", "zhao", "cheng", "ji", "yan",
	"kuang|wang|zai", "bian", "chao", "ju", "wen", "hu|gu", "yue", "jue", "ba", "qin",
	"dan|shen", "zheng", "yun", "wan", "ne|ni|rui|na", "yi", "shu", "zhua", "pou", "tou",
	"dou", "kang", "zhe|she", "pou|fu", "fu", "pao", "ba", "ao|niu", "ze|zhBi", "tuan",
	"kou", "lun", "qiang|cheng", "yun", "hu", "bao", "bing", "zhi|zhai", "peng", "nan",
	"bu|pu", "pi", "tai", "yao|tao", "zhen", "zha", "yang", "bao", "he|qia", "ni",
	"ye", "di", "chi", "pi|pei", "jia", "mo|ma", "mei", "chen", "ya", "chou",
	"qu", "min", "zhu", "jia|ya", "fu|bi", "zha", "zhu", "dan", "chai|ca", "mu",
	"nian", "la", "fu", "pao", "ban|pan", "pai", "lin", "na", "guai", "qian",
	"ju", "tuo|ta|zhi", "ba", "tuo", "tuo", "ao|niu", "ju|gou", "zhuo", "pan|pin|fan", "zhao",
	"bai", "bai", "di", "ni", "ju", "kuo", "long", "jian", "qia", "yong",
	"lan", "ning", "bo", "ze|zhai", "qian", "hen", "kuo|gua", "shi", "jie|jia", "zheng",
	"nin", "gong", "gong", "quan", "shuan", "cun|zun", "za|zan", "kao", "yi|chi|hai", "xie",
	"ce|se|chuo", "hui", "pin", "zhuai|ye", "shi|she", "na", "bai", "chi", "gua", "zhi",
	"kuo|guang", "duo", "duo", "zhi", "qie", "an", "nong", "zhen", "ge", "jiao",
	"kua|ku", "dong", "ru|na", "tiao", "lie", "zha", "lv", "die|she", "wa", "jue",
	"lie ri", "ju", "zhi", "luan", "ya", "zhua|wo", "ta", "xie|jia", "nao", "dang",
	"jiao", "zheng", "ji", "hui", "xian", "yu", "ai", "tuo|shui", "nuo", "cuo",
	"bo", "geng", "ti", "zhen", "cheng", "suo|sB|shB", "suo|sB|shB", "keng|qian", "mei", "nong",
	"ju", "bang|peng", "jian", "yi", "ting", "shan", "nuo", "wan", "xie|jia", "cha",
	"peng", "jiao|ku", "wu", "jun", "jiu", "tong", "kun", "huo|chi", "tu|shu|cha", "zhuo",
	"pou|fu", "luo|lv", "ba", "han", "shao", "nie", "juan", "ze", "shu|song|sou", "ye|yu",
	"jue|zhuo", "bu", "wan", "bu|pu|zhi", "zun", "ye", "zhai", "lv", "sou", "tuo|shui",
	"lao", "sun", "bang", "jian", "huan", "dao", "wei", "wan|yu", "qin", "peng",
	"she", "lie", "min", "men", "fu|bu", "bai", "ju", "dao", "wo|luo", "ai",
	"juan|quan", "yue", "zong", "chen", "chui", "jie", "tu", "ben", "na", "nian|nie",
	"ruo|wei|re", "zuo", "wo|xia", "qi", "xian", "cheng", "dian", "sao", "lun", "qing|qian",
	"gang", "duo", "shou", "diao", "pou", "di", "zhang", "hun", "ji", "tao",
	"qia", "qi", "pai", "shu", "qian|wan", "ling", "ye", "ya", "jue", "zheng",
	"liang", "gua", "ni|nie|yi", "huo|xu", "shan|yan", "zheng|ding", "lve", "cai", "tan", "che",
	"bing", "jie", "ti", "kong", "tui", "yan", "cuo", "zou|zhou|chou", "ju", "tian",
	"qian", "ken", "bai", "pa", "jie", "lu", "guai", "ming", "jie", "zhi",
	"dan|shan", "meng", "chan|xian|can|shan", "sao", "guan", "peng", "yuan", "nuo", "jian", "zheng|keng",
	"jiu|you", "jian", "yu", "yan", "kui", "nan", "hong", "rou", "pi|che", "wei",
	"sai|zong|cai", "zou", "xuan", "miao", "ti|di", "nie", "cha", "shi", "zong|song", "zhen",
	"yi", "xun", "huang|yong", "bian", "yang", "huan", "yan", "zan|zuan", "an", "xu|ju",
	"ya", "wo", "ke|qia", "chuai|tuan|zhui", "ji", "ti|di", "la", "la", "cheng", "kai",
	"jiu", "jiu", "tu", "jie|qi", "hui", "gen", "chong|dong", "xiao", "she|die|ye", "xie",
	"yuan", "qian|jian", "ye", "cha", "zha", "bei", "yao", "wei", "beng", "lan",
	"wen", "qin", "chan", "ge", "lou", "zong", "gen", "jiao", "gou", "qin",
	"rong", "que", "chou|zou", "chuai", "zhan", "sun", "sun", "bo", "chu", "rong|nang",
	"bang|peng", "cuo", "sao", "e", "yao", "dao", "zhi", "nu|nuo|nou", "la|xie|xian", "jian",
	"sou", "qiu", "gao", "gan", "shuo", "sang", "jin", "mie", "e", "chui",
	"nuo", "shan", "ta", "jie|zhe", "tang", "pan|ban|po", "ban", "da", "li", "tao",
	"hu|ku", "zhi|nai", "wa", "hua", "qian", "wen", "qiang|cheng", "tian|shen", "zhen", "e",
	"xie", "na|nuo", "quan", "cha", "zha", "ge", "wu", "en", "she", "kang",
	"she|nie", "shu", "bai", "yao", "bin", "sou", "tan", "sa|sha|shai", "chan|sun", "suo",
	"jiu|liu|liao|jiao|nao", "chong", "chuang", "guai", "bing", "feng|peng", "shuai", "di|tu|zhi", "qi|ji|cha", "sou|song",
	"zhai", "lian", "cheng", "chi", "guan", "lu", "luo", "lou", "zong", "gai|xi",
	"hu|chu", "zha", "qiang", "tang", "hua", "cui", "zhi|nai", "mo|ma", "jiang|qiang", "gui",
	"ying", "zhi", "ao|qiao", "zhi", "nie|che", "man", "chan|can", "kou", "chu", "se|mi|su",
	"tuan", "jiao|chao", "mo", "mo", "zhe", "chan|xian|can|shan", "keng|qian", "biao", "jiang", "yao",
	"gou", "qian", "liao", "ji", "ying", "jue", "pie", "pie", "lao", "dun",
	"xian", "ruan", "gui", "zan|zen|qian", "yi", "xian", "cheng", "cheng", "sa", "nao",
	"hong", "si", "han", "heng|guang", "da", "zun", "nian", "lin", "zheng|cheng", "hui|wei",
	"zhuang", "jiao", "ji", "cao", "dan", "dan|shan", "che", "bo", "che", "jue",
	"xiao|sou", "liao", "ben", "fu", "qiao", "bo", "cuo|zuo", "zhuo", "zhuan", "wei|tuo",
	"pu", "qin", "dun", "nian", "hua", "xie", "lu", "jiao", "cuan", "ta",
	"han", "qiao|yao|ji", "zhua|wo", "jian", "gan", "yong", "lei", "nang", "lu", "shan",
	"zhuo", "ze|zhai", "pu", "chuo", "ji", "dang", "se", "cao", "qing", "qing|jing",
	"huan", "jie", "qin", "kuai", "dan", "xie", "qia|jia|ye", "pi|bo", "bo|bai", "ao",
	"ju", "ye", "e", "meng", "sou", "mi", "ji", "tai", "zhuo", "dao",
	"xing", "lan", "ca", "ju", "ye", "ru", "ye", "ye", "ni", "huo",
	"jie", "bin", "ning", "ge", "zhi", "zhi|jie", "kuo", "mo", "jian", "xie",
	"lie|la", "tan", "bai", "sou", "lu", "li|luo|yue", "rao", "ti|zhi|zhai", "pan", "yang",
	"lei", "ca|sa", "shu", "zan", "nian", "xian", "jun|pei", "huo", "li|luo", "la|lai",
	"huan", "ying", "lu|luo", "long", "qian", "qian", "zan|cuan", "qian", "lan", "xian|jian",
	"ying", "mei", "rang", "chan", "weng", "cuan", "xie", "she|nie", "luo", "jun",
	"mi|mo", "chi", "zan|cuan", "luan", "tan", "zuan", "li|shai", "dian", "wa", "dang",
	"jiao", "jue", "lan", "li|luo", "nang", "zhi", "gui", "gui", "qi|yi|ji", "xun",
	"pu", "pu", "shou", "kao", "you", "gai", "yi", "gong", "gan|han", "ban",
	"fang", "zheng", "po", "dian", "kou", "min", "wu|mou", "gu", "he", "ce",
	"xiao", "mi", "chu|shou", "ge|guo|e", "di", "xu", "jiao", "min", "chen", "jiu",
	"shen", "duo|dui", "yu", "chi", "ao", "bai", "xu", "jiao", "duo|dui", "lian",
	"nie", "bi", "chang", "dian", "duo|que", "yi", "gan", "san", "ke", "yan",
	"dun|dui", "qi|yi|ji", "tou", "xiao|xue", "duo|que", "jiao", "jing", "yang", "xia", "min",
	"shu|shuo", "ai|zhu", "qiao", "ai|zhu", "zheng", "di", "chen", "fu", "shu|shuo", "liao",
	"qu", "xiong|xuan", "yi", "jiao", "shan", "jiao", "zhuo|zhu", "yi|du", "lian", "bi",
	"li|tai", "xiao", "xiao", "wen", "xue", "qi", "qi", "zhai", "bin", "jue|jiao",
	"zhai", "lang", "fei", "ban", "ban", "lan", "yu|zhong", "lan", "wei|men", "dou",
	"sheng", "liao", "jia", "hu", "xie", "jia", "yu", "zhen", "jiao", "wo|guan",
	"tou|tiao", "dou", "jin", "chi", "yin|zhi", "fu", "qiang", "zhan", "qu", "zhuo",
	"zhan", "duan", "zhuo", "si", "xin", "zhuo", "zhuo", "qin", "lin", "zhuo",
	"chu", "duan", "zhu", "fang", "chan|jie", "hang", "yu|wu", "shi", "pei", "liu|you",
	"mie", "pang|bang", "qi", "zhan", "mao", "lv", "pei", "pi|bi", "liu", "fu",
	"fang", "xuan", "jing", "jing", "ni", "zu", "zhao", "yi", "liu", "shao",
	"jian", "en", "yi", "qi", "zhi", "fan", "piao", "fan", "zhan", "kuai",
	"sui", "yu", "wu", "ji", "ji", "ji", "huo", "ri", "dan", "jiu",
	"zhi", "zao", "xie", "tiao", "xun", "xu", "ga", "la", "gan|han", "han",
	"tai|ying", "di|de", "xu", "chan", "shi", "kuang", "yang", "shi", "wang", "min",
	"min", "tun|zhun", "chun", "wu", "yun", "bei", "ang", "ze", "ban", "jie",
	"kun", "sheng", "hu", "fang", "hao", "gui", "chang", "xuan", "ming", "hun",
	"fen", "qin", "hu", "yi", "xi", "xin", "yan", "ze", "fang", "tan",
	"shen", "ju", "yang", "zan", "bing", "xing", "ying", "xuan", "po", "zhen",
	"ling", "chun", "hao", "mei", "zuo", "mo", "bian", "xu", "hun", "zhao",
	"zong", "shi", "shi", "yu", "fei", "die|yi", "mao", "ni", "chang", "wen",
	"dong", "ai", "bing", "ang", "zhou", "long", "xian", "kuang", "tiao", "chao",
	"shi", "huang", "huang", "xuan", "kui", "xu|kua", "jiao", "jin", "zhi", "jin",
	"shang", "tong", "hong", "yan", "gai", "xiang", "shai", "xiao", "ye", "yun",
	"hui", "han", "han", "jun", "wan", "xian", "kun", "zhou", "xi", "sheng|cheng",
	"sheng", "bu", "zhe", "zhe", "wu", "wan", "hui", "hao", "chen", "wan",
	"tian", "zhuo", "zui", "zhou", "pu", "jing|ying", "xi", "shan", "ni", "xi",
	"qing", "qi|du", "jing", "gui", "zheng", "yi", "zhi", "an|yan", "wan", "lin",
	"liang", "cheng", "wang", "xiao", "zan", "fei", "xuan", "xuan", "yi", "xia",
	"yun", "hui", "xu", "min", "kui", "ye", "ying", "shu|du", "wei", "shu",
	"qing", "mao", "nan", "jian|lan", "nuan", "an", "yang", "chun", "yao", "suo",
	"pu", "ming", "jiao", "kai", "hao", "weng", "chang", "qi", "hao", "yan",
	"li", "ai", "ji", "ji", "men", "zan", "xie", "hao", "mu", "mu",
	"cong", "ni", "zhang", "hui", "bao|pu", "han", "xuan", "chuan", "liao", "xian",
	"tan", "jing", "pie", "lin", "tun", "xi", "yi", "ji", "huang", "dai",
	"ye", "ye", "li", "tan", "tong", "xiao", "fei", "shen", "zhao", "hao",
	"yi", "xiang", "xing", "shen", "jiao", "bao", "jing", "yan", "ai", "ye",
	"ru", "shu", "meng", "xun", "yao", "pu|bao", "li", "chen", "kuang", "die",
	"liao", "yan", "huo", "lu", "xi", "rong", "long", "nang", "luo", "luan",
	"shai", "tang", "yan", "zhu", "yue", "yue", "qu", "ye", "geng", "ye",
	"hu", "he", "shu", "cao", "cao", "sheng", "man", "zeng|ceng", "zeng|ceng", "ti",
	"zui", "can|qian|jian", "xu", "hui|kuai", "yin", "qie|he", "fen", "bi|pi", "yue", "you",
	"ruan", "peng", "fen|ban", "fu", "ling", "fei|ku", "qu|xu|chun", "ti", "nv|ga", "tiao",
	"shuo", "zhen", "lang", "lang", "juan|zui", "ming", "huang|mang|wang", "wang", "tun", "zhao|chao",
	"ji", "qi|ji", "ying", "zong", "wang", "tong|chuang", "lang", "lao", "meng", "long",
	"mu", "pin", "wei", "mo", "ben", "zha", "shu|zhu", "shu|zhu", "teul", "zhu|shu",
	"ren", "ba", "piao|pu|po", "duo", "duo", "dao|tiao|mu", "li", "qiu|gui", "ji", "jiu",
	"bi", "xiu", "cheng", "ci", "sha", "ru", "za", "quan", "qian", "yu|wu",
	"gan", "wu", "cha", "shan|sha", "xun", "fan", "wu", "zi", "li", "xing",
	"cai", "cun", "ren|er", "shao|biao", "tuo|zhe", "di|duo", "zhang", "mang", "chi", "yi",
	"gu|gai", "gong", "du", "yi|li|duo|tuo", "qi", "shu", "gang", "tiao", "jie", "mian",
	"wan", "lai", "jiu", "mang", "yang", "ma", "miao", "si|zhi|xi", "yuan|wan", "hang",
	"fei|bei", "bei", "jie", "dong", "gao", "yao", "xian", "chu", "chun", "pa",
	"shu|dui", "hua", "xin", "niu|chou", "zhu", "chou", "song", "ban", "song", "ji",
	"wo|yue", "jin", "gou", "ji", "mao", "pi", "pi|mi", "wang", "ang", "fang|bing",
	"fen", "yi", "fu", "nan", "xi", "hu|di", "ya", "dou", "xin", "zhen",
	"yao", "lin", "rui", "e", "mei", "zhao", "guo", "zhi|qi", "cong|zong", "yun",
	"hua", "sheng", "shu", "zao", "di|duo", "li", "lu", "jian", "cheng", "song|mB ti su",
	"qiang", "feng", "zhan", "xiao", "xian|zhen", "ku", "ping", "si|tai", "xi", "zhi",
	"guai", "xiao", "jia", "jia", "ju|gou", "bao|fu", "mo", "yi|xie", "ye", "ye",
	"shi", "nie", "bi", "tuo|duo", "yi|duo|li", "ling", "bing", "ni|chi", "la", "he",
	"pan|ban", "fan", "zhong", "dai", "ci", "yang|ying", "fu", "bai|bo", "mou", "gan",
	"qi", "ran", "rou", "mao", "shao", "song", "zhe", "xia", "you", "shen",
	"gui|ju", "tuo", "zuo|zha", "nan", "ning", "yong", "di", "zhi|die", "zha|zu", "cha|zha",
	"dan", "gu", "bu|pu", "jiu", "ao", "fu", "jian", "ba|fu|pei|bo|bie", "duo|zuo|wu", "ke",
	"nai", "zhu", "bi|bie", "liu", "chai", "zha", "si", "zhu", "bei|pei", "shi|fei",
	"guai", "cha|zha", "yao", "cheng", "jiu", "shi", "zhi", "liu", "mei", "li",
	"rong", "zha|shan|shi|ce", "zao", "biao", "zhan", "zhi", "long", "dong", "lu", "sa",
	"li|yue", "lan", "yong", "shu", "xun", "shuan", "qi|qie", "chen", "qi|xi", "li",
	"yi", "xiang", "zhen", "li", "se", "gua|tian", "kan", "ben|bing", "ren", "xiao|jiao",
	"bai", "ren", "bing", "zi", "chou", "yi|xie", "ci", "xu", "zhu", "jian|zun",
	"zui", "er", "er", "you|yu", "fa", "gong", "kao", "lao", "zhan", "lie",
	"yin", "yang", "he|hu", "gen", "zhi|yi", "shi", "ge", "zai", "luan", "fu",
	"jie", "heng|hang", "gui", "tao", "guang", "wei", "kuang", "ru", "an", "an",
	"juan", "yi|ti", "zhuo", "ku", "zhi", "qiong", "tong", "sang", "sang", "huan",
	"jie|ju", "jiu", "xue", "duo", "chui", "yu|mou", "za|zan", "kB sei", "ying", "jie",
	"liu", "zhan", "ya", "nao", "zhen", "dang", "qi", "qiao", "hua", "gui|hui",
	"jiang", "zhuang", "xun", "suo", "sha", "chen|zhen", "bei", "ting|ying", "gua", "jing",
	"bo", "ben|fan", "fu", "rui", "tong", "jue", "xi", "lang", "liu", "feng",
	"qi", "wen", "jun", "gan", "su|yin", "liang", "qiu", "ting", "you", "mei",
	"bang", "long", "peng", "zhuang", "di", "xuan|juan|xie", "tu|cha", "zao", "ao|you", "gu",
	"bi", "di", "han", "zi", "zhi", "ren|er", "bei", "geng", "jian", "huan",
	"wan", "nuo", "jia", "tiao", "ji", "xiao", "lv", "kuan", "shao|sao", "chen",
	"fen", "song", "meng", "wu", "li", "si|qi", "dou", "qin", "ying", "suo",
	"ju", "ti", "xie", "kun", "zhuo", "shu", "chan|yan", "fan", "wei", "jing",
	"li", "bin|bing", "xia", "fo", "chou|tao|dao", "zhi", "lai", "lian", "jian", "zhuo",
	"ling", "li", "qi", "bing", "lun", "cong|song", "qian", "mian", "qi", "qi",
	"cai", "gun|hun", "chan", "de|zhe", "fei", "pai|bei|pei", "bang", "bang|pou|bei", "hun", "zong",
	"cheng", "zao", "ji", "li|lie", "peng", "yu", "yu", "gu", "jun", "dong",
	"tang", "gang", "wang", "di|dai|ti", "que", "fan", "cheng", "zhan", "qi", "yuan",
	"yan", "yu", "quan|juan", "yi", "sen", "ren|shen", "chui", "leng|ling", "qi", "zhuo",
	"fu|su", "ke", "lai", "zou|sou", "zou", "zhao|zhuo", "guan", "fen", "fen", "chen",
	"qing", "ni", "wan", "guo", "lu", "hao", "jie|qie", "yi", "chou|zhou|diao", "ju",
	"ju", "cheng|sheng", "zu|cui", "liang", "qiang|kong", "zhi", "zhui|chui", "ya", "ju", "bei",
	"jiao", "zhuo", "zi", "bin", "peng", "ding", "chu", "chang", "men", "hua",
	"jian", "gui", "xi", "du", "qian", "dao", "gui", "dian", "luo", "zhi",
	"quan|juan", "mi eng", "fu", "geng", "peng", "shan", "yi", "tuo", "sen", "duo|chuan",
	"ye", "fu", "wei|hui", "wei", "duan", "jia", "zong", "jian|han", "yi", "zhen|shen",
	"xi", "yan|ya", "yan", "chuan", "jian", "chun", "yu", "he", "zha|cha", "wo",
	"pian", "bi", "yao", "guo|kua", "xu", "ruo", "yang", "la", "yan", "ben",
	"hui", "kui", "jie", "kui", "si", "feng", "xie", "tuo", "ji|zhi", "jian",
	"mu", "mao", "chu", "ku|hu", "hu", "lian", "leng", "ting", "nan", "yu",
	"you", "mei", "song|cong", "xuan|yuan", "xuan", "yang|ying", "zhen", "pian", "die|ye", "ji",
	"jie", "ye", "chu", "shun|dun", "yu", "cou|zou", "wei", "mei", "di|shi", "ji",
	"jie", "kai|jie", "qiu", "ying", "rou", "huang", "lou", "le|yue", "quan", "xiang",
	"pin", "shi", "gai", "tan", "lan", "wen|yun", "yu", "chen", "lv", "ju",
	"shen", "chu", "bi|pi", "xie", "jia", "yi", "zhan|nian|zhen", "fu|bo", "nuo", "mi",
	"lang", "rong", "gu", "jian|jin", "ju", "ta", "yao", "zhen", "bang", "sha|xie",
	"yuan", "zi", "ming", "su", "jia", "yao", "jie", "huang", "gan", "fei",
	"zha", "qian", "ma", "sun", "yuan", "xie", "rong", "shi", "zhi", "cui",
	"wen", "ting", "liu", "rong", "tang", "que", "zhai", "si", "sheng", "ta",
	"ke", "xi", "gu", "qi", "gao", "gao", "sun", "pan", "tao", "ge",
	"chun", "dian", "nou", "ji", "shuo", "gou", "chui", "qiang", "cha", "qian|lian|xian",
	"huai", "mei", "xu", "gang", "gao", "zhuo", "tuo", "qiao", "yang", "dian|zhen",
	"jia", "jian|kan", "zui", "dao", "long", "bin|bing", "zhu", "sang", "xi|die", "ji|gui",
	"lian", "hui", "rong|yong", "qian", "guo", "gai", "gai", "tuan|shuan|quan", "hua", "qi|se",
	"sen", "cui|zhi", "peng", "you|chao", "hu", "jiang", "hu", "huan", "gui", "nie",
	"yi", "gao", "kang", "gui", "gui", "cao", "man|wan", "jin", "di", "zhuang",
	"le|yue", "lang", "chen", "cong|zong", "li|chi", "xiu", "qing", "shang", "fan", "tong",
	"guan", "ze", "su", "lei", "lu", "liang", "mi", "lou", "chao|jiao", "su",
	"ke", "chu", "cheng", "biao", "lu", "jiu|liao", "zhe", "zha", "shu", "zhang",
	"man", "mo|mu", "niao|mu", "yang", "tiao", "peng", "zhu", "sha|xie", "xi", "quan",
	"heng", "jian", "cong", "ji", "yan", "qiang", "xue", "ying", "er", "xun",
	"zhi", "qiao", "zui", "cong", "piao", "shu", "hua", "gui", "zhen", "zun",
	"yue", "shan", "xi", "chun", "dian", "fa|fei", "gan", "mo", "wu", "qiao",
	"rao|nao", "lin", "liu", "qiao", "xian", "run", "fan", "zhan|jian", "tuo", "liao",
	"yun", "shun", "tui|dun", "cheng", "tang|cheng", "meng", "ju", "cheng", "su|qiu", "jue",
	"jue", "tan|dian", "hui", "ji", "nuo", "xiang", "tuo", "ning", "rui", "zhu",
	"tong|chuang", "zeng|ceng", "fen|fei", "qiong", "ran|yan", "heng", "qian", "gu", "liu", "lao",
	"gao", "chu", "xi", "sheng", "zi", "zan", "ji", "dou", "jing", "lu",
	"xian", "cu|chu", "yuan", "ta", "shu|qiao", "jiang", "tan", "lin", "nong", "yin",
	"xi", "hui", "shan", "zui", "xuan", "cheng", "gan", "ju", "zui", "yi",
	"qin", "pu", "yan", "lei", "feng", "hui", "dang", "ji", "sui", "bo",
	"ping|bo", "cheng", "chu", "zhua", "gui|hui", "ji", "jie", "jia", "qing", "zhai|shi|tu",
	"jian", "qiang", "dao", "yi", "biao", "song", "she", "lin", "li", "cha",
	"meng", "yin", "chou|tao|dao", "tai", "mian", "qi", "tuan", "bin|bing", "huo", "ji",
	"qian|lian", "ni|mi", "ning", "yi", "gao", "jian|kan", "yin", "nou|ruan|ru", "qing", "yan",
	"qi", "mi", "zhao", "gui", "chun", "ji", "kui", "po", "deng", "chu",
	"ge", "mian", "you", "zhi", "huang|guo|gu", "qian", "lei", "lei", "sa", "lu",
	"li", "cuan", "lv|chu", "mie|mei", "hui", "ou", "lv", "zhi", "gao", "du",
	"yuan", "li|yue", "fei", "zhuo|zhu", "sou", "lian", "jiang", "chu", "qing", "zhu",
	"lu", "yan", "li", "zhu", "chen", "jue|ji", "e", "su", "huai|gui", "nie",
	"yu", "long", "la|lai", "qiao", "xian", "gui", "ju", "xiao", "ling", "ying",
	"jian", "yin", "you", "ying", "xiang", "nong", "bo", "chan|zhan", "lan", "ju",
	"shuang", "she", "wei|zui", "cong", "quan", "qu", "cang", "jiu", "yu", "luo",
	"li", "cuan", "luan", "dang", "qu", "yan", "lan", "lan", "zhu", "lei",
	"li", "ba", "nang", "yu", "ling", "guan", "qian", "ci", "huan", "xin",
	"yu", "yu|yi", "qian|xian", "ou", "xu", "chao", "chu|qu|xi", "qi", "ke|ai", "yi|yin",
	"jue", "xi|kai", "xu", "he", "yu", "kuai", "lang", "kuan", "shuo|sou", "xi",
	"ei|ai", "qi", "qi", "xu|chua", "chi|chuai", "qin", "kuan", "kan|qian", "kuan", "kan|ke",
	"chuan", "sha", "gua", "yan|yin", "xin", "xie", "yu", "qian", "xiao", "ye",
	"ge", "wu", "tan", "jin|qun", "ou", "hu", "ti", "huan", "xu", "pen",
	"xi", "xiao", "xu", "xi|she", "shan", "lian|han", "chu", "yi", "e", "yu",
	"chuo", "huan", "zhi", "zheng", "ci", "bu", "wu", "qi", "bu", "bu",
	"wai", "ju", "qian", "zhi|chi", "se", "chi", "se|sha", "zhong", "sui", "sui",
	"li", "ze", "yu", "li", "gui", "dai", "dai", "si", "jian", "zhe",
	"mo|wen", "mo", "yao", "mo", "cu", "yang", "tian", "sheng", "dai", "shang",
	"xu", "xun", "shu", "can", "jing", "piao", "qia", "qiu", "su", "qing|jing",
	"yun", "lian", "yi", "fou|bo", "zhi|shi", "ye|yan", "can", "hun|mei", "dan", "ji",
	"die", "zhen", "yun", "wen", "chou", "bin", "ti", "jin", "shang", "yin",
	"chi", "jiu", "kui|hui", "cuan", "yi", "dan", "du", "jiang", "lian", "bin",
	"du", "jian", "jian", "shu", "ou", "duan", "zhu", "yin|yan", "qing|keng|sheng", "yi",
	"sha", "ke|qiao", "ke|qiao", "xiao|yao", "xun", "dian", "hui", "hui", "gu", "qiao",
	"ji", "yi", "ou", "hui", "duan", "yi", "xiao", "wu", "guan|wan", "mu",
	"mei", "mei", "ai", "jie", "du|dai", "yu", "bi", "bi", "bi", "pi",
	"pi", "bi", "chan", "mao", "hao", "cai", "bi", "lie", "jia", "zhan",
	"sai", "mu", "tuo", "xun", "er", "rong", "xian", "ju", "mu", "hao",
	"qiu", "dou|nuo", "mushiruPPPV", "tan", "pei", "ju", "duo", "cui", "bi", "san",
	"san", "mao", "sai|sui", "shu", "shu", "tuo", "he", "jian", "ta", "san",
	"lv", "mu", "mao", "tong", "rong", "chang", "pu", "lu", "zhan", "sao",
	"zhan", "meng", "lu", "qu", "die", "shi|zhi", "di", "min", "jue", "meng|mang",
	"qi", "pie", "nai", "qi", "dao", "xian", "chuan", "fen", "yang|ri", "nei",
	"nei", "fu", "shen", "dong", "qing", "qi", "yin", "xi", "hai", "yang",
	"an", "ya", "ke", "qing", "ya", "dong", "dan", "lv", "qing", "yang",
	"yun", "yun", "shui", "shui", "zheng|cheng", "bing", "yong", "dang", "shui", "le",
	"ni", "tun", "fan", "gui|jiu", "ting", "zhi", "qiu", "bin|pa", "ze", "mian",
	"cuan", "hui", "diao", "han", "cha", "zhuo|que", "chuan", "wan", "fan", "da",
	"xi", "tuo", "mang", "qiu", "qi", "shan", "pin", "han", "qian", "wu",
	"wu", "xun", "si", "ru", "gong", "jiang", "chi", "wu", "tu", "jiu",
	"tang|shang", "zhi|ji", "zhi", "qian", "mi", "gu|yu", "wang", "jing", "jing", "rui",
	"jun", "hong", "tai", "tai", "ji", "bian", "bian", "gan|han|cen", "wen|men", "zhong",
	"fang|pang", "xiong", "jue", "hu|huang", "niu|you", "qi", "fen", "xu", "xu", "qin",
	"yi", "wo", "yun", "yuan", "hang", "yan", "shen|chen", "chen", "dan", "you",
	"dun", "hu", "huo", "qi", "mu", "nv|niu", "mei|mo", "ta|da", "mian", "mi|wu",
	"chong", "hong|pang", "bi", "sha", "zhi", "pei", "pan", "zhui|zi", "za", "gou",
	"pai", "mei|mo", "ze", "feng", "ou", "li", "lun", "cang", "feng", "wei",
	"hu", "mo", "mei", "shu", "ju", "za", "tuo|duo", "tuo", "tuo|duo", "he",
	"li", "mi|li", "yi|chi", "fa", "fei", "you", "tian", "zhi", "zhao", "gu",
	"zhan", "yan", "si", "kuang", "jiong", "ju", "xie|yi", "qiu", "yi|die", "jia",
	"zhong", "quan", "bo|po", "hui", "mi|bi", "ben", "ze", "chu|she", "le", "you|ao",
	"gu", "hong", "gan", "fa", "mao", "si", "hu", "peng|ping", "ci", "fan",
	"zhi", "su", "ning", "cheng", "ling", "pao", "bo", "qi", "si", "ni",
	"ju", "yue|sa", "zhu", "sheng", "lei", "xuan", "jue|xue", "fu", "pan", "min",
	"tai", "yang", "ji", "yong", "guan", "beng", "xue", "long|shuang", "lu", "dan",
	"luo|po", "xie", "po", "ze|shi", "jing", "yin", "pan", "jie", "yie", "hui",
	"hui", "zai", "cheng", "yin", "wei", "hou", "jian", "yang", "lie", "si",
	"ji", "er", "xing", "fu", "sa|xi", "se|qi|zi", "zhi", "yin", "wu", "xi|xian",
	"kao", "zhu", "jiang", "luo", "luo", "an|yan|e", "dong", "ti", "si", "lei",
	"yi", "mi", "quan", "jin", "po", "wei", "xiao", "xie", "hong", "xu",
	"su|shuo", "kuang", "tao", "qie|jie", "ju", "er", "zhou", "ru", "ping", "xun",
	"xiong", "zhi", "guang", "huan", "ming", "huo", "wa", "qia", "pai", "wu",
	"qu", "liu", "yi", "jia", "jing", "qian|jian", "jiang", "jiao", "zhen", "shi",
	"zhuo", "ce", "fa", "kuai|hui", "ji", "liu", "chan", "hun", "hu|xu", "nong",
	"xun", "jin", "lie", "qiu", "wei", "zhe", "jun|xun", "han", "bang", "mang",
	"zhuo", "you|di", "xi", "bo", "dou", "huan", "hong", "yi", "pu", "ying|cheng",
	"lan", "hao", "lang", "han", "li", "geng", "fu", "wu", "li", "chun",
	"feng|hong", "yi", "yu", "tong", "lao", "hai", "jin", "jia", "chong", "jiong",
	"mei", "sui|nei", "cheng", "pei", "xian", "shen", "tu", "kun", "ping", "nie",
	"han", "jing", "xiao", "she", "nian", "tu", "yong|chong", "xiao", "xian", "ting",
	"e", "su", "tun|yun", "juan", "cen", "ti", "li", "shui", "si", "lei",
	"shui", "tao", "du", "lao", "lai", "lian", "wei", "wo|guo", "yun", "huan",
	"di", "heng", "run", "jian", "zhang", "se", "fu", "guan", "xing", "shou|tao",
	"shuan", "ya", "chuo", "zhang", "ye", "kong|nang", "wan|wo|yuan", "han", "tuo", "dong",
	"he", "wo", "ju", "she", "liang", "hun", "ta", "zhuo", "dian", "qie|ji",
	"de", "juan", "zi", "xi", "xiao", "qi", "gu", "guo|guan", "yan", "lin",
	"tang|chang", "zhou", "peng", "hao", "chang", "shu", "qi", "fang", "zhi", "lu",
	"nao|chuo|zhuo", "ju", "tao", "cong", "lei", "zhe", "ping|peng", "fei", "song", "tian",
	"pi|pei", "dan", "yu|xu", "ni", "yu", "lu", "gan", "mi", "jing|cheng", "ling",
	"lun", "yin", "cui", "qu", "huai", "yu", "nian|shen", "shen", "biao|hu", "chun|zhun",
	"hu", "yuan", "lai", "hun", "qing", "yan", "qian", "tian", "miao", "zhi",
	"yin", "bo", "ben", "yuan", "wen|min", "ruo|re|luo", "fei", "qing", "yuan", "ke",
	"ji", "she", "yuan", "se", "lu", "zi", "du|dou", "yi", "jian", "mian|sheng",
	"pai", "xi", "yu", "yuan", "shen", "shen", "rou", "huan", "zhu", "jian",
	"nuan", "yu", "qiu|wu", "ting", "qu|ju", "du", "feng", "zha", "bo", "wo",
	"wo|guo", "ti|di", "wei", "wen", "ru", "xie", "ce", "wei", "he", "gang|jiang",
	"yan", "hong", "xuan", "mi", "ke", "mao", "ying", "yan", "you", "hong|qing",
	"miao", "sheng", "mei", "zai", "hun", "nai", "gui", "chi", "e", "pai",
	"mei", "lian", "qi", "qi", "mei", "tian", "cou", "wei", "can", "tuan",
	"mian", "hui|min|xu", "po", "xu", "ji", "pen", "jian", "jian", "hu", "feng",
	"xiang", "yi", "yin", "zhan", "shi", "jie", "zhen", "huang", "tan", "yu",
	"bi", "min|hun", "shi", "tu", "sheng", "yong", "ju", "dong", "tuan|nuan", "qiu|jiao",
	"qiu|jiao", "qiu", "yan|yin", "tang|shang", "long", "huo", "yuan", "nan", "ban|pan", "you",
	"quan", "zhuang|hun", "liang", "chan", "xian", "chun", "nie", "zi", "wan", "shi",
	"man", "ying", "la", "kui|hui", "feng|hong", "jian", "xu", "lou", "wei", "gai",
	"bo", "ying", "po", "jin", "yan|gui", "tang", "yuan", "suo", "yuan", "lian|nian|xian",
	"yao", "meng", "zhun", "cheng", "ke", "tai", "da|ta", "wa", "liu", "gou",
	"sao", "ming", "zha", "shi", "yi", "lun", "ma", "pu", "wei", "li",
	"zai", "wu", "xi", "wen", "qiang", "ze", "shi", "su", "ai", "zhen|qin",
	"sou", "yun", "xiu", "yin", "rong", "hun", "su", "suo", "ni|niao", "ta",
	"shi", "ru", "ai", "pan", "chu|xu", "chu", "pang", "weng", "cang", "mie",
	"ge", "dian", "hao|xue", "huang", "qi|xi|xie", "zi", "di", "zhi", "xing|ying", "fu",
	"jie", "hua", "ge", "zi", "tao", "teng", "sui", "bi", "jiao", "hui",
	"gun", "yin", "ze|hao", "long", "zhi", "yan", "she", "man", "ying", "chun",
	"lv", "lan", "luan", "yao", "bin", "tan", "yu", "xiu", "hu", "bi",
	"biao", "zhi", "jiang", "kou", "shen", "shang", "di", "mi", "ao", "lu",
	"hu|xu", "hu", "you", "chan", "fan", "yong", "gun", "man", "qing", "yu",
	"piao", "ji", "ya", "chao", "qi", "xi", "ji", "lu", "lou", "long",
	"jin", "guo", "cong|song", "lou", "zhi", "gai", "qiang", "li", "yan", "cao",
	"jiao", "cong", "chun", "tuan|zhuan", "ou", "teng", "ye", "xi", "mi", "tang",
	"mo", "shang", "han", "lian", "lan", "wa", "chi", "gan", "feng|peng", "xuan",
	"yi", "man", "zi", "mang", "kang", "luo|ta", "ben|peng", "shu", "zhang", "zhang",
	"chong|zhuang", "xu", "huan", "huo|kuo", "jian", "yan", "shuang", "liao|liu", "cui", "ti",
	"yang", "jiang", "cong|zong", "ying", "hong", "xiu", "shu", "guan", "ying", "xiao",
	"cong|zong", "kun", "xu", "lian", "zhi", "wei", "pi|pie", "yu", "jiao|qiao", "po",
	"dang|xiang", "hui", "jie", "wu", "pa", "ji", "pan", "wei", "su", "qian",
	"qian", "xi|ya", "lu", "xi", "xun", "dun", "huang|guang", "min", "run", "su",
	"lao|liao", "zhen", "cong|zong", "yi", "zhi", "wan", "tan|shan", "tan", "chao", "xun",
	"kui|hui", "ye", "shao", "tu|zha", "zhu", "san|sa", "hei", "bi", "shan", "chan",
	"chan", "shu", "tong", "pu", "lin", "wei", "se", "se", "cheng", "jiong",
	"cheng|deng", "hua", "jiao", "lao", "che", "gan", "cun", "jing", "si", "shu|zhu",
	"peng", "han", "yun", "liu", "hong|gong", "fu", "hao", "he", "xian", "jian",
	"shan", "xi", "ao", "lu", "lan", "ning", "yu", "lin", "mian|sheng", "zao",
	"dang", "huan", "ze|shi", "xie", "yu", "li", "shi", "xue", "ling", "wan|man",
	"zi", "yong", "kuai|hui", "can", "lian", "dian", "ye", "ao", "huan", "zhen",
	"chan", "man", "gan", "dan|tan", "yi", "sui", "pi", "ju", "ta", "qin",
	"ji", "zhuo", "lian", "nong", "guo|wo", "jin", "fen|pen", "se", "ji|sha", "sui",
	"hui|huo", "chu", "ta", "song", "ding|ting", "se", "zhu", "lai", "bin", "lian",
	"mi|ni", "shi", "shu", "mi", "ning", "ying", "ying", "meng", "jin", "qi",
	"bi|pi", "ji", "hao", "ru", "cui|zui", "wo", "tao", "yin", "yin", "dui",
	"ci", "huo|hu", "qing", "lan", "jun|xun", "ai|kai|ke", "pu", "zhuo|zhao", "wei", "bin",
	"gu", "qian", "ying", "bin", "kuo", "fei", "cang", "me", "jian", "wei|dui",
	"luo|po", "zan|cuan", "lv", "li", "you", "yang", "lu", "si", "zhi", "ying",
	"du|dou", "wang", "hui", "xie", "pan", "shen", "biao", "chan", "mie|mo", "liu",
	"jian", "pu|bao", "se", "cheng|deng", "gu", "bin", "huo", "xian", "lu", "qin",
	"han", "ying", "rong", "li", "jing", "xiao", "ying", "sui", "wei|dui", "xie",
	"huai|wai", "xue", "zhu", "long|shuang", "lai", "dui", "fan", "hu", "lai", "shu",
	"lian", "ying", "mi", "ji", "lian", "jian|zun", "ying", "fen", "lin", "yi",
	"jian", "yue", "chan", "dai", "rang|nang", "jian", "lan", "fan", "shuang", "yuan",
	"zhuo|jiao|ze", "feng", "she", "lei", "lan", "cong", "qu", "yong", "qian", "fa",
	"guan", "jue", "yan", "hao", "ying", "sa", "zan|cuan", "luan", "yan", "li",
	"mi", "shan", "tan", "dang|tang", "jiao", "chan", "ying", "hao", "ba", "zhu",
	"lan", "lan", "nang", "wan", "luan", "xun|quan", "xian", "yan", "gan", "yan",
	"yu", "huo", "huo|biao", "mie", "guang", "deng", "hui", "xiao", "xiao", "hui",
	"hong", "ling", "zao", "zhuan", "jiu", "zha|yu", "xie", "chi", "zhuo", "zai",
	"zai", "can", "yang", "qi", "zhong", "fen|ben", "niu", "jiong|gui", "wen", "pu",
	"yi", "lu", "chui", "pi", "kai", "pan", "yan", "yan", "pang|feng", "mu",
	"chao", "liao", "que", "kang", "dun", "guang", "xin", "zhi", "guang", "guang",
	"wei", "qiang", "bian", "da", "xia", "zheng", "zhu", "ke", "zhao", "fu",
	"ba", "xie", "xie", "ling", "zhuo|chu", "xuan", "ju", "tan", "pao|bao", "jiong",
	"pao|fou", "tai", "tai", "bing", "yang", "tong", "shan|qian", "zhu", "zha", "dian",
	"wei", "shi", "lian", "chi", "huang", "zhou", "hu", "shuo", "lan", "ting",
	"jiao|yao", "xu", "heng", "quan", "lie", "huan", "yang", "xiao", "xiu", "xian",
	"yin", "wu", "zhou", "yao", "shi", "wei", "tong|dong", "mie", "zai", "kai",
	"hong", "lao|luo", "xia", "zhu", "xuan", "zheng", "po", "yan", "hui", "guang",
	"che", "hui", "kao", "chen", "fan", "shao", "ye", "hui", "uu", "tang",
	"jin", "re", "lie", "xi", "fu|pao", "jiong", "xie|che", "pu", "ting", "zhuo",
	"ting", "wan", "hai", "peng", "lang", "yan", "xu", "feng", "chi", "rong",
	"hu", "xi", "shu", "he", "xun|hun", "ku", "juan|ye", "xiao", "xi", "yan",
	"han", "zhuang", "qu|jun", "di", "xie|che", "ji|qi", "wu", "yan", "lv", "han",
	"yan", "huan", "men", "ju", "dao", "bei", "fen", "lin", "kun", "hun",
	"tun", "xi", "cui", "wu", "hong", "chao|ju", "fu", "wo|ai", "jiao", "zong|cong",
	"feng", "ping", "qiong", "ruo", "xi|yi", "qiong", "xin", "zhuo|chao", "yan", "yan",
	"yi", "jue", "yu", "gang", "ran", "pi", "xiong|ying", "gang", "sheng", "chang",
	"shao", "xiong|ying", "nem", "geng", "qu", "chen", "he", "kui", "zhong", "duan",
	"xia", "hui|yun|xun", "feng", "lian", "xuan", "xing", "huang", "jiao", "jian", "bi",
	"ying", "zhu", "wei", "tuan", "shan|qian", "xi|yi", "nuan", "nuan", "chan", "yan",
	"jiong", "jiong", "yu", "mei", "sha", "wei", "ye|zha", "jin", "qiong", "rou",
	"mei", "huan", "xu", "zhao", "wei", "fan", "qiu", "sui", "yang", "lie",
	"zhu", "jie", "zao", "gua", "bao", "hu", "yun", "nan", "shi", "huo",
	"bian", "gou", "tui", "tang", "chao", "shan", "en|yun", "bo", "huang", "xie",
	"xi", "wu", "xi", "yun", "he", "he|xiao", "xi", "yun", "xiong", "xiong",
	"shan", "qiong", "yao", "xun", "mi", "lian", "ying", "wu", "rong", "gong",
	"yan", "qiang", "liu", "xi", "bi", "biao", "cong|zong", "lu|ao", "jian", "shu",
	"yi", "lou", "peng|feng", "sui|cui", "yi", "teng", "jue", "zong", "yun|yu", "hu",
	"yi", "zhi", "ao", "wei", "liu", "han|ran", "ou", "re", "jiong", "man",
	"kun", "shang", "cuan", "zeng", "jian", "xi", "xi", "xi", "yi", "xiao",
	"chi", "huang", "chan|dan", "ye", "tan", "ran", "yan", "xun", "qiao", "jun",
	"deng", "dun", "shen", "jiao|qiao|jue|zhuo", "fen", "si", "liao", "yu", "lin", "tong|dong",
	"shao", "fen", "fan", "yan", "xun", "lan", "mei", "tang", "yi", "jiong",
	"men", "zhu", "jiao", "ying", "yu", "yi", "xue", "lan", "tai|lie", "zao",
	"can", "sui", "xi", "que", "zong", "lian", "hui", "zhu", "xie", "ling",
	"wei", "yi", "xie", "zhao", "hui", "da", "nong", "lan", "xu", "xian",
	"he", "xun", "jin", "chou", "tao", "yao", "he", "lan", "biao", "rong|ying",
	"li|lie", "mo", "bao", "ruo", "lv", "la|lie", "ao", "xun", "kuang|huang", "shuo",
	"liao", "li", "lu", "jue", "liao", "yan|xun", "xi", "xie", "long", "ye",
	"can", "rang", "yue", "lan", "cong", "jue", "chong", "guan", "qu", "che",
	"mi", "tang", "lan", "zhu", "lan", "ling", "cuan", "yu", "zhao|zhua", "zhao|zhua",
	"pa", "zheng", "pao", "cheng|chen", "yuan", "ai", "wei", "han", "jue", "jue",
	"fu", "ye", "ba", "die", "ye", "yao", "zu", "shuang", "er", "pan",
	"chuang", "ke", "zang", "die", "qiang", "yong", "qiang", "pian", "ban", "pan",
	"chao", "jian", "pai", "du", "chuang", "yu", "zha", "bian|mian", "die", "bang",
	"bo", "chuang", "you", "you|yong", "du", "ya", "cheng", "niu", "niu", "pin",
	"jiu|le", "mou|mu", "ta", "mu", "lao", "ren", "mang", "fang", "mao", "mu",
	"gang", "wu", "yan", "ge|qiu", "bei", "si", "jian", "gu", "you|chou", "ke",
	"sheng", "mu", "di", "qian", "quan", "quan", "zi", "te", "xi", "mang",
	"keng", "qian", "wu", "gu", "xi", "li", "li", "pou", "ji", "gang",
	"zhi|te", "ben", "quan", "chun", "du", "ju", "jia", "jian|qian", "feng", "pian",
	"ke", "ju", "kao", "chu", "xi", "bei", "luo", "jie", "ma", "san",
	"wei", "mao|li", "dun", "tong", "qiao", "jiang", "xi", "li", "du", "lie",
	"bai", "piao", "bao", "xi", "chou", "wei", "kui", "chou", "quan", "quan",
	"quan|ba", "fan", "qiu", "ji", "chai", "zhuo|bao", "han|an", "ge", "zhuang", "guang",
	"ma", "you", "kang|gang", "pei|fei", "hou", "ya", "yin", "huan|fan", "zhuang", "yun",
	"kuang", "niu", "di", "kuang", "zhong", "mu", "bei", "pi", "ju", "yi|quan|chi",
	"sheng|xing", "pao", "xia", "tuo|yi", "hu", "ling", "fei", "pi", "ni", "yao",
	"you", "gou", "xue", "ju", "dan", "bo", "ku", "xian", "ning", "huan",
	"hen", "jiao", "he", "zhao", "jie", "xun", "shan", "ta|shi", "rong", "shou",
	"tong|dong", "lao", "du", "xia", "shi", "kuai", "zheng", "yu", "sun", "yu",
	"bi", "mang|dou", "xi|shi", "juan", "li", "xia", "yin", "suan", "lang", "bei",
	"zhi", "yan", "sha", "li", "han", "xian", "jing", "pai", "fei", "xiao",
	"bai|pi", "qi", "ni", "biao", "yin", "lai", "lie", "jian|yan", "qiang", "kun",
	"yan", "guo", "zong", "mi", "chang", "yi", "zhi", "zheng", "ya|wei", "meng",
	"cai", "cu", "she", "lie", "ceon", "luo", "hu", "zong", "gui", "wei",
	"feng", "wo", "yuan", "xing", "zhu", "mao", "wei", "chuan", "xian", "tuan",
	"ya|jia|qie", "nao", "xie|he|ge|hai", "jia", "hou", "bian|pian", "you", "you", "mei", "cha",
	"yao", "sun", "bo|po", "ming", "hua", "yuan", "sou", "ma", "huan", "dai",
	"yu", "shi", "hao", "qiang", "yi", "zhen", "cang", "hao|gao", "man", "jing",
	"jiang", "mo", "zhang", "chan", "ao", "ao", "hao", "suo", "fen", "jue",
	"bi", "bi", "huang", "pu", "lin", "xu", "tong", "yao|xiao", "lao", "shuo|xi",
	"xiao", "shou", "dun", "jiao", "ge|lie|xie", "juan", "du", "hui", "kuai", "xian",
	"xie", "ta", "xian", "xun", "ning", "bian|pian", "huo", "nou|ru", "meng", "lie",
	"nao|you", "guang", "shou", "lu", "ta", "xian", "mi", "rang", "huan", "nao|you",
	"luo", "xian", "qi", "jue", "xuan", "miao", "zi", "shuai|lv", "lu", "yu",
	"su", "wang", "qiu", "ga", "ding", "le", "ba", "ji", "hong", "di",
	"chuan", "gan", "jiu", "yu", "qi", "yu", "chang|yang", "ma", "hong", "wu",
	"fu", "min|wen", "jie", "ya", "bin|fen", "bian", "bang", "yue", "jue", "men|yun",
	"jue", "wan", "jian|qian", "mei", "dan", "pin", "wei", "huan", "xian", "qiang|cang",
	"ling", "dai", "yi", "an|gan", "ping", "dian", "fu", "xuan|xian", "xi", "bo",
	"ci", "gou", "jia", "shao", "po", "ci", "ke", "ran", "sheng", "shen",
	"yi|tai", "zu|ju", "jia", "min", "shan", "liu", "bi", "zhen", "zhen", "jue",
	"fa", "long", "jin", "jiao", "jian", "li", "guang", "xian", "zhou", "gong",
	"yan", "xiu", "yang", "xu", "luo", "su", "zhu", "qin", "yin|ken", "xun",
	"bao", "er", "xiang", "yao", "xia", "hang", "gui", "chong", "xu", "ban",
	"pei", "lao", "dang", "ying", "hun|hui", "wen", "e", "cheng", "di|ti", "wu",
	"wu", "cheng", "jun", "mei", "bei", "ting", "xian", "chu", "han", "xuan|qiong",
	"yan", "qiu", "xuan", "lang", "li", "xiu", "fu", "liu", "ya", "xi",
	"ling", "li", "jin", "lian", "suo", "suo", "feng", "wan", "dian", "pin|bing",
	"zhan", "cui|se", "min", "yu", "ju", "chen", "lai", "min", "sheng", "wei|yu",
	"tian", "shu", "zhuo|zuo", "beng|pei", "cheng", "hu", "qi", "e", "kun", "chang",
	"qi", "beng", "wan", "lu", "cong", "guan", "yan", "diao", "bei", "lin",
	"qin", "pi", "pa", "que", "zhuo", "qin", "fa", "jin", "qiong", "du",
	"jie", "hun|hui", "yu", "mao", "mei", "chun", "xuan", "ti", "xing", "dai",
	"rou", "min", "jian", "wei", "ruan", "huan", "xie|jie", "chuan", "jian", "zhuan",
	"chang|yang", "lian", "quan", "xia", "duan", "yuan", "ye", "nao", "hu", "ying",
	"yu", "huang", "rui", "se", "liu", "shi", "rong", "suo", "yao", "wen",
	"wu", "zhen", "jin", "ying", "ma", "tao", "liu", "tang", "li", "lang",
	"gui", "tian|zhen", "qiang|cang", "cuo", "jue", "zhao", "yao", "ai", "bin|pian", "tu|shu",
	"chang", "kun", "zhuan", "cong", "jin", "yi", "cui", "cong", "qi", "li",
	"jing", "zao|suo", "qiu", "xuan", "ao", "lian", "men", "zhang", "yin", "ye",
	"ying", "zhi", "lu", "wu", "deng", "xiu", "zeng", "xun", "qu", "dang",
	"lin", "liao", "qiong|jue", "su", "huang", "gui", "pu", "jing", "fan", "jin",
	"liu", "ji", "hui", "jing", "ai", "bi", "can", "qu", "zao", "dang",
	"jiao", "guan", "tan", "hui|kuai", "huan", "se", "sui", "tian", "chu", "yu",
	"jin", "lu|fu", "bin|pian", "shu", "wen", "zui", "lan", "xi", "ji|zi", "xuan",
	"ruan", "wo", "gai", "lei", "du", "li", "zhi", "rou", "li", "zan",
	"qiong", "ti", "gui", "sui", "la", "long", "lu", "li", "zan", "lan",
	"ying", "mi|xi", "xiang", "qiong|wei", "guan", "dao", "zan", "huan|ye|ya", "gua", "bo",
	"die", "bo|pao", "hu", "zhi|hu", "piao", "ban", "rang", "li", "wa", "shiwa",
	"xiang|hong", "qianwa", "ban", "pen", "fang", "dan", "weng", "ou", "fenwa", "maowa",
	"ki ro ton|mao wa", "hu", "ling", "yi", "ping", "ci", "bai", "juan", "chang", "chi",
	"liwa", "dang", "wa", "bu", "zhui", "ping", "bian", "zhou", "zhen", "liwa",
	"ci", "ying", "qi", "xian", "lou", "di", "ou", "meng", "zhuan", "beng",
	"lin", "zeng", "wu", "pi", "dan", "weng", "ying", "yan", "gan", "dai",
	"shen", "tian", "tian", "han", "chang", "sheng", "qing", "shen", "chan", "chan",
	"rui", "sheng", "su", "shen", "yong", "shuai", "lu", "fu", "yong", "beng",
	"beng", "ning", "tian", "you", "jia", "shen", "you", "dian", "fu", "nan",
	"dian|tian|sheng", "ping", "ting|ding", "hua", "ting|ding", "zhen", "zai|zi", "meng", "bi", "bi|qi",
	"mu", "xun", "liu", "chang", "mu", "yun", "fan", "fu", "geng", "tian",
	"jie", "jie", "quan", "wei", "fu|bi", "tian", "mu", "tap", "pan", "jiang",
	"wa", "da|fu", "nan", "liu", "ben", "zhen", "xu|chu", "mu", "mu", "ce|ji",
	"zai|zi", "gai", "bi", "da", "zhi|chou|shi", "lve", "qi", "lve", "fan|pan", "yi",
	"fan|pan", "hua", "she|yu", "she", "mu", "jun", "yi", "liu", "she", "die",
	"chou", "hua", "dang", "zhui", "ji", "wan", "jiang", "cheng", "chang", "tuan",
	"lei", "ji", "cha", "liu", "die", "tuan", "lin", "jiang", "jiang|qiang", "chou",
	"pi", "die", "die", "pi|ya|shu", "jie|qie", "dan", "shu", "shu", "zhi|di", "yi|ni",
	"ne", "nai", "ding", "bi", "jie", "liao", "gang", "ge|yi", "jiu", "zhou",
	"xia", "shan", "xu", "n<e|yao", "li|lai", "yang", "chen", "you", "ba", "jie",
	"jue|xue", "qi", "ya|xia", "cui", "bi", "yi", "li", "zong", "chuang", "feng",
	"zhu", "pao", "pi", "gan", "ke", "ci", "xue", "zhi", "da", "zhen",
	"fa|bian", "zhi", "teng", "ju", "ji", "fei", "gou", "shan|dian", "jia", "xuan",
	"zha", "bing", "nie", "zheng", "yong", "jing", "quan", "teng|chong", "tong", "yi",
	"jie", "wei|you|yu", "hui", "tan|shi", "yang", "zhi", "zhi", "hen", "ya", "mei",
	"dou", "jing", "xiao", "tong", "tu", "mang", "pi", "xiao", "suan", "pu",
	"li", "zhi", "cuo", "duo", "wu", "sha", "lao", "shou", "huan", "xian",
	"yi", "beng|peng", "zhang", "guan", "tan", "fei", "ma", "ma|lin", "chi", "ji",
	"tian|dian", "an|ye|e", "chi", "bi", "bi", "min", "gu", "dui", "ke|e", "wei",
	"yu", "cui", "ya", "zhu", "cu", "dan", "shen", "zhong", "zhi|chi", "yu",
	"hou", "feng", "la", "yang", "chen", "tu", "yu", "guo", "wen", "huan",
	"ku", "jia|xia", "yin", "yi", "lou", "sao", "jue", "chi", "xi", "guan",
	"yi", "wen", "ji", "chuang", "ban", "hui|lei", "liu", "chai|cuo", "shou", "n<e|yao",
	"dian|chen", "da|dB", "bie", "tan", "zhang", "biao", "shen", "cu", "luo", "yi",
	"zong", "chou", "zhang", "zhai", "sou", "se", "que", "diao", "lou", "lou",
	"mo", "qin", "yin", "ying", "huang", "fu", "liao", "long", "qiao|jiao", "liu",
	"lao", "xian", "fei", "dan", "yin", "he", "ai", "ban", "xian", "guan",
	"gui|wei", "nong", "yu", "wei", "yi", "yong", "pi", "lei", "li|lai", "shu",
	"dan", "lin", "dian", "lin", "la", "bie", "ji", "chi", "yang", "xuan",
	"jie", "zheng", "mo", "li", "huo", "la", "ji", "dian", "xuan", "ying",
	"yin", "qu", "yong", "tan", "dian", "luo", "luan", "luan", "bo", "uu",
	"gui", "ba", "fa", "deng", "fa", "bai", "bai", "qie", "ji|bi", "zao",
	"zao", "mao", "di|de", "pa|ba", "jie", "huang", "gui", "ci", "ling", "gao|yao",
	"mo", "ji", "jiao", "peng", "gao|yao", "ai", "e", "hao", "han", "bi",
	"wan", "chou", "qian", "xi", "ai", "xiao", "hao", "huang", "hao", "ze",
	"cui", "hao", "xiao", "ye", "po", "hao", "jiao", "ai", "xing", "huang",
	"li|luo|bo", "piao", "he", "jiao", "pi", "gan", "pao", "zhou", "jun", "qiu",
	"cun", "que", "zha", "gu", "jun", "jun", "zhou", "zha|cu", "gu", "zhao|zhan|dan",
	"du", "min", "qi", "ying", "yu", "bei", "diao", "zhong", "pen", "he",
	"ying", "he", "yi", "bo", "wan", "he", "ang", "zhan", "yan", "jian",
	"he", "yu", "kui", "fan", "gai|ge|he", "dao", "pan", "fu", "qiu", "sheng|cheng",
	"dao", "lu", "zhan", "meng", "li", "jin", "xu", "jian", "pan", "guan",
	"an", "lu", "xu", "zhou|chou", "dang", "an", "gu", "li", "mu", "ding",
	"gan", "xu", "mang", "mang|wang", "zhi", "qi", "yuan", "xian|tian", "xiang", "dun",
	"xin", "xi|pan", "pan", "feng", "dun", "min", "ming", "sheng|xing", "shi", "yun|hun",
	"mian", "pan", "fang", "miao", "dan", "mei", "mao", "kan", "xian", "kou",
	"shi", "yang|ying", "zheng", "yao|ao", "shen", "huo", "da", "zhen", "kuang", "ju|xu|kou",
	"shen", "yi|chi", "sheng", "mei", "mo|mie", "zhu", "zhen", "zhen", "mian", "shi",
	"yuan", "die|ti", "ni", "zi", "zi", "chao", "zha", "xuan", "bing|fang", "pang|pan",
	"long", "gui|sui", "tong", "mi", "die|zhi", "di", "ne", "ming", "xuan|shun|xun", "chi",
	"kuang", "juan", "mou", "zhen", "tiao", "yang", "yan", "mo", "zhong", "mo",
	"zhuo|zhao|zhe", "zheng", "mei", "suo", "qiao|shao|xiao", "han", "huan", "di", "cheng", "cuo|zhuai",
	"juan", "e", "mian", "xian", "xi", "kun", "lai", "jian", "shan", "tian",
	"gun", "wan", "leng", "shi", "qiong", "li", "ya", "jing", "zheng", "li",
	"lai", "sui|zui", "juan", "shui", "sui", "du", "bi", "bi", "mu", "hun",
	"ni", "lu", "yi|ze|gao", "jie", "cai", "zhou", "yu", "hun", "ma", "xia",
	"xing", "hui", "hun", "zai", "chun", "jian", "mei", "du", "hou", "xuan",
	"ti", "kui", "gao", "rui", "mao", "xu", "fa", "wo", "miao", "chou",
	"gui|wei|kui", "mi", "weng", "kou|ji", "dang", "chen", "ke", "sou", "xia", "qiong|huan",
	"mo", "ming", "man|men", "fen", "ze", "zhang", "yi", "diao|dou", "kou", "mo",
	"shun", "cong", "lou|lv", "chi", "man|men", "piao", "cheng", "gui", "meng", "wan",
	"run|shun", "pie", "xi", "qiao", "pu", "zhu", "deng", "shen", "shun", "liao",
	"che", "xian|jian", "kan", "ye", "xue", "tong", "wu|mi", "lin", "gui|kui", "jian",
	"ye", "ai", "hui", "zhan", "jian", "gu", "zhao", "qu|ju", "wei", "chou",
	"sao", "ning|cheng", "xun", "yao", "huo|yue", "meng", "mian", "pin", "mian", "lei",
	"kuang|guo", "jue", "xuan", "mian", "huo", "lu", "meng", "long", "guan|quan", "man",
	"xi", "chu", "tang", "kan", "zhu", "mao", "jin|qin|guan", "jin|qin|guan", "yu|xu|jue", "shuo",
	"ze", "jue", "shi", "yi", "shen", "zhi", "hou", "shen", "ying", "ju",
	"zhou", "jiao", "cuo", "duan", "ai", "jiao", "zeng", "yue", "ba", "shi|dan",
	"ding", "qi", "ji", "zi", "gan", "wu", "zhe", "ku", "gang|qiang|kong", "xi",
	"fan", "kuang", "dang", "ma", "sha", "dan", "jue", "li", "fu", "min",
	"e", "xu|hua", "kang", "zhi", "qi|qie", "kan", "jie", "pin|bin|fen", "e", "ya",
	"pi", "zhe", "yan", "sui", "zhuan", "che", "dun", "wa", "yan", "jin",
	"feng", "fa", "mo", "zha", "ju", "yu", "ke|luo", "tuo", "tuo", "di",
	"zhai", "zhen", "e", "fu|fei", "mu", "zhu", "li|la", "bian", "nu", "ping",
	"peng", "ling", "pao", "le", "po", "bo", "po", "shen", "za", "ai",
	"li", "long", "tong", "yong", "li", "kuang", "chu", "keng", "quan", "zhu",
	"kuang|guang", "gui", "e", "nao", "qia", "lu", "wei|gui", "ai", "luo|ge", "ken|xian|gun|yin",
	"xing", "yan", "dong", "peng|ping", "xi", "lao", "hong", "shuo|shi", "xia", "qiao",
	"qing", "wei|ai|gai", "qiao", "ce", "keng", "xiao", "que|ke|ku", "chan", "lang", "hong",
	"yu", "xiao", "xia", "mang|bang", "luo|long", "yong|tong", "che", "che", "wo", "liu",
	"ying", "mang", "que", "yan", "sha", "kun", "yu", "ze", "hua", "lu",
	"chen", "jian", "nve", "song", "zhuo", "keng", "peng", "yan", "zhui|chui|duo", "kong",
	"cheng", "qi", "zong|cong", "qing", "lin", "jun", "bo", "ding", "min", "diao",
	"jian|zhan", "he", "lu|liu", "ai", "sui", "que|xi", "leng", "bei", "yin", "dui",
	"wu", "qi", "lun", "wan", "dian", "nao|gang", "bei", "qi", "chen", "ruan",
	"yan", "die", "ding", "zhou", "tuo", "jie|ya", "ying", "bian", "ke", "bi",
	"wei", "shuo|shi", "zhen", "duan", "xia", "dang", "ti|di", "nao", "peng", "jian",
	"di", "tan", "cha", "tian", "qi", "dun", "feng", "xuan", "que", "que|qiao",
	"ma", "gong", "nian", "su|xie", "e", "ci", "liu", "si|ti", "tang", "bang|pang",
	"hua|ke|gu", "pi", "kui|wei", "sang", "lei", "cuo", "tian", "xia|qia|ya", "xi", "lian|qian",
	"pan", "wei|ai|gai", "yun", "dui", "zhe", "ke", "la", "zhuan", "yao", "gun",
	"zhuan", "chan", "qi", "ao|qiao", "peng", "liu", "lu", "kan", "chuang", "chen",
	"yin", "lei", "biao", "qi", "mo", "qi|zhu", "cui", "zong", "qing", "chuo",
	"lun", "ji", "shan", "lao|luo", "qu", "zeng", "deng", "jian", "xi", "lin",
	"ding", "dian", "huang", "pan|bo", "ji|she", "qiao", "di", "li", "jian", "jiao",
	"xi", "zhang", "qiao", "dun", "jian", "yu", "zhui", "he|qiao", "ke|huo", "ze",
	"lei", "jie", "chu", "ye", "que|hu", "dang", "yi", "jiang", "pi", "pi",
	"yu", "pin", "e|qi", "ai", "ke", "jian", "yu", "ruan", "meng", "pao",
	"ci", "bo", "yang", "mie", "ca", "xian|xin", "kuang", "lei", "lei", "zhi",
	"li", "li", "fan", "que", "pao", "ying", "li", "long", "long", "mo",
	"bo", "shuang", "guan", "jian", "ca", "yan", "shi", "shi", "li", "reng",
	"she", "yue", "si", "qi", "ta", "ma", "xie", "yao", "xian", "zhi|qi",
	"qi", "zhi", "beng|fang", "dui", "zhong", "ren", "yi", "shi", "you", "zhi",
	"tiao", "fu", "fu", "mi|bi", "zu", "zhi", "suan", "mei", "zuo", "qu",
	"hu", "zhu", "shen", "sui", "ci", "chai", "mi", "lv", "yu", "xiang",
	"wu", "tiao", "piao", "zhu", "gui", "xia", "zhi", "ji|zhai", "gao", "zhen",
	"gao", "shui|lei", "jin", "shen", "gai", "kun", "di", "dao", "huo", "tao",
	"qi", "gu", "guan", "zui", "ling", "lu", "bing", "jin", "dao", "zhi",
	"lu", "chan|shan", "bi|pi", "chu", "hui", "you|chao", "xi", "yin", "zi", "huo",
	"zhen", "fu", "yuan", "xu", "xian", "shang|yang", "ti|zhi", "yi", "mei", "si",
	"di", "bei", "zhuo", "zhen", "ying", "ji", "gao", "tang", "si", "ma",
	"ta", "fu", "xuan", "qi", "yu", "xi", "ji", "si", "shan|chan", "dan",
	"gui", "sui", "li", "nong", "mi", "dao", "li", "rang", "yue", "ti",
	"zan", "lei", "rou", "yu", "yu|ou", "li", "xie", "qin", "he", "tu",
	"xiu", "si", "ren", "tu", "zi", "cha|na", "gan", "yi|zhi", "xian", "bing",
	"nian", "qiu", "qiu", "zhong", "fen", "hao|mao", "yun", "ke", "miao", "zhi",
	"jing", "bi", "zhi", "yu", "mi|bi", "ku", "ban", "pi", "ni", "li",
	"you", "zu", "pi", "bo", "ling", "mo", "cheng", "nian", "qin", "yang",
	"zuo", "zhi", "di", "shu", "ju", "zi", "huo|kuo", "ji", "cheng|chen", "tong",
	"shi|zhi", "huo|kuo", "huo", "yin", "zi", "zhi", "jie", "ren", "du", "yi",
	"zhu", "hui", "nong", "fu|pu", "xi", "gao", "lang", "fu", "xun|ze", "shui",
	"lv", "kun", "gan", "jing", "ti", "cheng", "tu|shu", "shao", "shui", "ya",
	"lun", "lu", "gu", "zuo", "ren", "zhun", "bang", "bai", "ji|qi", "zhi",
	"zhi", "kun", "leng|ling", "peng", "ke", "bing", "chou", "zui|zu|su", "yu", "su",
	"lve", "uu", "yi", "xi|qie", "bian", "ji", "fu", "pi|bi", "nuo", "jie",
	"zhong", "zong", "xu", "cheng|chen", "dao", "wen", "xian|jian|lian", "zi|jiu", "yu", "ji",
	"xu", "zhen", "zhi", "dao", "jia", "ji|qi", "gao", "gao", "gu", "rong",
	"sui", "rong", "ji", "kang", "mu", "can|shan|cen", "men|mei", "zhi", "ji", "lu",
	"su", "ji", "ying", "wen", "qiu", "se", "kweok", "yi", "huang", "qie",
	"ji", "sui", "xiao|rao", "pu", "jiao", "zhuo|bo", "tong|zhong", "zuo", "lu", "sui",
	"nong", "se", "hui", "rang", "nuo", "yu", "pin", "ji", "tui", "wen",
	"cheng|chen", "huo", "kuang", "lv", "biao|pao", "se", "rang", "zhuo|jue", "li", "cuan|zan",
	"xue", "wa", "jiu", "qiong", "xi", "qiong", "kong", "yu", "shen", "jing",
	"yao", "chuan", "zhun", "tu", "lao", "qie", "zhai", "yao", "bian", "bao",
	"yao", "bing", "wa", "zhu|ku", "jiao|liao|liu", "qiao", "diao", "wu", "wa|gui", "yao",
	"zhi", "chuang", "yao", "tiao|yao", "jiao", "chuang", "jiong", "xiao", "cheng", "kou",
	"cuan", "wo", "dan", "ku", "ke", "zhuo", "huo", "su", "guan", "kui",
	"dou", "zhuo", "yin|xun", "wo", "wa", "ya|ye", "yu", "ju", "qiong", "yao",
	"yao", "tiao", "chao", "yu", "tian|dian|yan", "diao", "ju", "liao", "xi", "wu",
	"kui", "chuang", "chao|ke", "kuan|cuan", "kuan|cuan", "long", "cheng", "cui", "liao", "zao",
	"cuan", "qiao", "qiong", "dou", "zao", "long", "qie", "li", "chu", "shi",
	"fu", "qian", "chu|qi", "hong", "qi", "hao", "sheng", "fen", "shu", "miao",
	"qu|kou", "zhan", "zhu", "ling", "long", "bing", "jing", "jing", "zhang", "bai",
	"si", "jun", "hong", "tong", "song", "jing|zhen", "diao", "yi", "shu", "jing",
	"qu", "jie", "ping", "duan", "li", "zhuan", "ceng|zeng", "deng", "cun", "wai",
	"jing", "kan", "jing", "zhu", "zhu|du", "le|jin", "peng", "yu", "chi", "gan",
	"mang", "zhu", "wan", "du", "ji", "jiao", "ba", "suan", "ji", "qin",
	"zhao", "sun", "ya", "zhui|rui", "yuan", "hu", "hang", "xiao", "cen|jin|han", "pi|bi",
	"bi", "jian", "yi", "dong", "shan", "sheng", "da|xia|na", "di", "zhu", "na",
	"chi", "gu", "li", "qie", "min", "bao", "tiao", "si", "fu", "ce",
	"ben", "fa", "da", "zi", "di", "ling", "zuo|ze", "nu", "fu|fei", "gou",
	"fan", "jia", "ge", "fan", "shi", "mao", "po", "ti", "jian", "qiong",
	"long", "min", "bian", "luo", "gui", "qu", "chi", "yin", "yao", "xian",
	"bi", "qiong", "kuo", "deng", "jiao", "jin", "quan", "sun", "ru", "fa",
	"kuang", "zhu", "tong", "ji", "da", "hang", "ce", "zhong", "kou", "lai",
	"bi", "shai", "dang", "zheng", "ce", "fu", "yun|jun", "tu", "pa", "li",
	"lang", "ju", "guan", "jian", "han", "tong", "xia", "zhi", "cheng", "suan",
	"shi", "zhu", "zuo", "xiao", "shao", "ting", "ce", "yan", "gao", "kuai",
	"gan", "chou", "kuang", "gang", "yun", "o", "qian", "xiao", "jian", "pou|bu|fu|pu",
	"lai", "zou", "pai|bei", "bi", "bi", "ge", "tai|chi", "guai|dai", "yu", "jian",
	"zhao|dao", "gu", "chi", "zheng", "qing|jing", "sha", "zhou", "lu", "bo", "ji",
	"lin", "suan", "jun|qun", "fu", "zha", "gu", "kong", "qian", "quan", "jun",
	"chui", "guan", "wan|yuan", "ce", "zu", "po", "ze", "qie", "tuo", "luo",
	"dan", "xiao", "ruo", "jian", "xuan", "bian", "sun", "xiang", "xian", "ping",
	"zhen", "xing", "hu", "shi|yi", "zhu", "yue|yao|chuo", "chun", "lv", "wu", "dong",
	"shuo|xiao|qiao", "ji", "jie", "huang", "xing", "mei", "fan", "chuan", "zhuan", "pian",
	"feng", "zhu", "hong", "qie", "hou", "qiu", "miao", "qian", "gu", "kui",
	"yi", "lou", "yun", "he", "tang", "yue", "chou", "gao", "fei", "ruo",
	"zheng", "gou", "nie", "qian", "xiao", "cuan", "gong|gan|long", "peng|pang", "du", "li",
	"bi", "zhuo|huo", "chu", "shai", "chi", "zhu", "qiang|cang", "long", "lan", "jian",
	"bu", "li", "hui", "bi", "zhu|di", "cong", "yan", "peng", "cen|zan|can", "zhuan|zuan|suan",
	"pi", "piao|biao", "dou", "yu", "mie", "tuan|zhuan", "ze", "shai", "guo|gui", "yi",
	"hu", "chan", "kou", "cu", "ping", "zao", "ji", "gui", "su", "lou",
	"ce|ji", "lu", "nian", "suo", "cuan", "diao", "suo", "le", "duan", "zhu",
	"xiao", "bo", "mi|mie", "shai|si", "dang", "liao", "dan", "dian", "fu", "jian",
	"min", "kui", "dai", "jiao", "deng", "huang", "sun|zhuan", "lao", "zan", "xiao",
	"lu", "shi", "zan", "qi", "pai", "qi", "pai", "gan", "ju", "lu",
	"lu", "yan", "bo", "dang", "sai", "zhua", "gou", "qian", "lian", "bu|bo",
	"zhou", "lai", "shi", "lan", "kui", "yu", "yue", "hao", "zhen|jian", "tai",
	"ti", "nie", "chou", "ji", "yi", "qi", "teng", "zhuan", "zhou", "fan|pan|bian",
	"sou|shu", "zhou", "qian", "zhuo", "teng", "lu", "lu", "jian", "tuo", "ying",
	"yu", "lai", "long", "shen shi|sen si|qie", "lian", "lan", "qian", "yue", "zhong", "qu",
	"lian", "bian", "duan", "zuan", "li", "shai", "luo", "ying", "yue", "zhuo",
	"yu", "mi", "di", "fan", "shen", "zhe", "shen", "nv", "he", "lei",
	"xian", "zi", "ni", "cun", "zhang", "qian", "zhai", "bi", "ban", "wu",
	"sha|chao", "kang|jing", "rou", "fen", "bi", "cui", "yin", "zhe", "mi", "ta",
	"hu", "ba", "li", "gan", "ju", "po", "yu", "cu", "nian", "zhou",
	"chi", "su", "tiao", "li", "xi", "su", "hong", "tong", "zi|ci", "ce|se",
	"yue", "zhou|yu", "lin", "zhuang", "bai", "lao", "fen", "er", "qu", "he",
	"liang", "xian", "fu", "liang", "can", "jing", "li", "yue", "lu", "ju",
	"qi", "cui", "bai", "zhang", "lin", "zong", "jing", "guo", "hua", "san|shen",
	"shen", "tang", "bian", "rou", "mian", "hou", "xu", "zong", "hu", "jian",
	"zan", "ci", "li", "xie", "fu", "nuo", "bei", "gu|gou", "xiu", "gao",
	"tang", "qiu", "jia", "cao", "zhuang", "tang", "mi|mei", "san|shen", "fen", "zao",
	"kang", "jiang", "mo", "san|shen", "san", "nuo", "xi", "liang", "jiang", "kuai",
	"bo", "huan", "shu", "zong", "xian", "nuo", "tuan", "nie", "li", "zuo",
	"di", "nie", "tiao", "lan", "mi|si", "si", "jiu", "xi|ji", "gong", "zheng",
	"jiu", "gong", "ji", "cha", "zhou", "xun", "yue|yao", "hong|gong", "yu", "he|ge",
	"wan", "ren", "wen", "wen", "qiu", "na", "zi", "tou", "niu", "fou",
	"ji|jie", "shu", "chun", "bi", "zhen", "sha", "hong", "zhi", "ji", "fen",
	"yun", "ren", "dan", "jin", "su", "fang", "suo", "cui", "jiu", "zha|za",
	"ha", "jin", "fu", "zhi", "qi", "zi", "chou", "hong", "zha|za", "lei",
	"xi", "fu", "xie", "shen", "bo|bi", "zhu", "qu", "ling", "zhu", "shao",
	"gan", "yang", "fu", "tuo", "zhen|tian", "dai", "chu", "shi", "zhong", "xian",
	"zu", "jiong", "ban", "qu", "mo", "shu", "zui", "kuang", "jing", "ren",
	"hang", "xie", "jie", "zhu", "chou", "gua|kua", "bai|mo", "jue", "kuang", "hu",
	"ci", "huan|geng", "geng", "tao", "xie|jie", "ku", "jiao", "quan|shuan", "gai|ai", "luo|lao",
	"xuan", "beng|bing|peng", "xian", "fu", "gei|ji", "tong|dong", "rong", "tiao|diao|dao", "yin", "lei",
	"xie", "juan", "xu", "gai|hai", "die", "tong", "si", "jiang", "xiang", "hui",
	"jue", "zhi", "jian", "juan", "chi|zhi", "mian|wen|man|wan", "zhen", "lv", "cheng", "qiu",
	"shu", "bang", "tong", "xiao", "huan|wan", "qin|xian", "geng", "xu", "ti", "xiu",
	"xie", "hong", "xi", "fu", "ting", "sui", "dui", "kun", "fu", "jing",
	"hu", "zhi", "yan|xian", "jiong", "feng", "ji", "xu", "ren", "zong|zeng", "lin|chen",
	"duo", "li|lie", "lv", "jing", "chou", "quan", "shao", "qi", "qi", "zhun",
	"ji|qi", "wan", "qian|qing|zheng", "xian", "shou", "wei", "qing|qi", "tao", "wan", "gang",
	"wang", "beng", "zhui", "cai", "guo", "cui", "lun|guan", "liu", "qi", "zhan",
	"bi", "chuo|chao", "ling", "mian", "qi", "ji", "tian|tan|chan", "zong", "gun", "zou",
	"xi", "zi", "xing", "liang", "gei|ji", "fei", "rui", "min", "yu", "zong",
	"fan", "lv|lu", "xu", "ying", "shang", "zi", "xu", "xiang", "jian", "ke",
	"xian", "ruan", "mian", "ji|qi", "duan", "chong|zhong", "di", "min", "miao|mao", "yuan",
	"xie|ye", "bao", "si", "qiu", "bian", "huan", "geng", "zong", "mian", "wei",
	"fu", "wei", "tou|xu|shu", "gou", "miao", "xie", "lian", "zong", "bian|pian", "gun|yun",
	"yin", "ti", "gua|wo", "zhi", "yun|wen", "cheng", "chan", "dai", "xie", "yuan",
	"zong", "xu", "sheng", "wei", "geng", "seon", "ying", "jin", "yi", "zhui",
	"ni", "bang", "gu", "pan", "zhou", "jian", "ci|cuo|suo", "quan", "shuang", "yun|wen",
	"xia", "cui|sui|shuai", "xi", "rong", "tao", "fu", "yun", "zhen", "gao", "ru",
	"hu", "zai|zeng", "teng", "xian|xuan", "su", "zhen", "zong", "tao", "huang", "cai",
	"bi", "feng", "cu", "li", "suo|su", "yan|yin", "xi", "zong", "lei", "zhuan|juan",
	"qian", "man", "zhi", "lv", "mu|mo", "piao", "lian", "mi", "xuan", "zong",
	"ji", "shan", "sui", "fan|po", "lv", "beng", "yi", "sao", "mou|miu|miao|mu|liao", "yao|you|zhou",
	"qiang", "sheng", "xian", "ji", "zong", "xiu", "ran", "xuan", "sui", "qiao",
	"zeng", "zuo", "zhi", "shan", "san", "lin", "ju|jue", "fan", "liao", "chuo",
	"zun", "jian", "rao", "chan", "rui", "xiu", "hui", "hua", "zuan", "xi",
	"qiang", "wen", "da", "sheng", "hui", "xi|ji", "se", "jian", "jiang", "huan",
	"qiao|sao", "cong", "xie", "jiao|zhuo", "bi", "dan|tan|chan", "yi", "nong", "sui", "yi",
	"sha", "ru", "ji", "bin", "qian", "lan", "pu|fu", "xun", "zuan", "zi",
	"peng", "yao|li", "mo", "lei", "xie", "zuan", "kuang", "you", "xu", "lei",
	"xian", "chan", "jiao", "lu", "chan", "ying", "cai", "xiang|rang", "qian", "zui",
	"zuan", "luo", "li|xi|sa", "dao", "lan", "lei", "lian", "si", "jiu", "yu",
	"hong|gong", "zhou", "xian|qian", "he|ge", "yue|yao", "ji", "wan", "kuang", "ji", "ren",
	"wei", "yun", "hong", "chun", "pi|bi", "sha", "gang", "na", "ren", "zong",
	"lun|guan", "fen", "zhi", "wen", "fang", "zhu", "zhen", "niu", "shu", "xian",
	"gan", "xie", "fu", "lian", "zu", "shen", "xi", "zhi", "zhong", "zhou",
	"ban", "fu", "chu", "shao", "yi", "jing", "dai", "bang", "rong", "jie",
	"ku", "rao", "die", "hang", "hui", "gei|ji", "xuan", "jiang", "luo|lao", "jue",
	"jiao", "tong", "bing", "xiao", "juan", "xiu", "xi", "sui", "tao", "ji",
	"ti", "ji", "xu", "ling", "ying", "xu", "qi", "fei", "chuo|chao", "shang",
	"gun", "sheng", "wei", "mian", "shou", "beng", "chou", "tao", "liu", "quan",
	"zong|zeng", "zhan", "wan", "lv|lu", "zhui", "zi", "ke", "xiang", "jian", "mian",
	"lan", "ti", "miao", "ji|qi", "yun|wen", "hui", "si", "duo", "duan", "bian|pian",
	"xian", "gou", "zhui", "huan", "di", "lv", "bian", "min", "yuan", "jin",
	"fu", "ru", "zhen", "feng", "cui|sui|shuai", "gao", "chan", "li", "yi", "jian",
	"bin", "piao", "man", "lei", "ying", "suo|su", "mou|miu|miao|mu|liao", "sao", "xie", "liao",
	"shan", "zeng", "jiang", "qian", "qiao|sao", "huan", "jiao|zhuo", "zuan", "fou", "xie",
	"gang", "fou", "que", "fou", "que", "bo", "ping", "xiang", "zhao", "gang",
	"ying", "ying", "qing", "xia", "guan", "zun", "tan", "cheng", "qi", "weng",
	"ying", "lei", "tan", "lu", "guan", "wang", "wang", "wang", "wang", "han",
	"rb", "luo", "fu", "shen", "fa", "gu", "zhu", "ju", "mao", "gu",
	"min", "gang", "ba|pi", "gua", "ti", "juan", "fu", "shen", "yan", "zhao",
	"zui", "guai|gua", "zhuo", "yu", "zhi", "an", "fa", "lan", "shu", "si",
	"pi", "ma", "liu", "ba|pi", "fa", "li", "chao", "wei", "bi", "ji",
	"zeng", "chong", "liu", "ji", "juan", "mi", "zhao", "luo", "pi", "ji",
	"ji", "luan", "yang|xiang", "mi", "qiang", "da", "mei", "yang|xiang", "ling", "you",
	"fen", "ba", "gao", "yang", "gu", "qiang", "zang", "mei|gao", "ling", "yi|xi",
	"zhu", "di", "xiu", "qiang", "yi", "xian", "rong", "qun", "qun", "qiang",
	"huan", "suo", "xian", "yi", "you", "qiang|kong", "qian|xian|yan", "yu", "geng", "jie",
	"tang", "yuan", "xi", "fan", "shan", "fen", "shan", "lian", "lei", "geng",
	"nou", "qiang", "chan", "yu", "hong|gong", "yi", "chong", "weng", "fen", "hong",
	"chi", "chi", "cui", "fu", "xia", "ben", "yi", "la", "yi", "pi|bi|po",
	"ling", "liu", "zhi", "qu|yu", "xi", "xie", "xiang", "xi", "xi", "ke",
	"qiao", "hui", "hui", "xiao", "sha", "hong", "jiang", "di|zhai", "cui", "fei",
	"dao|zhou", "sha", "chi", "zhu", "jian", "xuan", "chi", "pian", "zong", "wan",
	"hui", "hou", "he", "he", "han", "ao", "piao", "yi", "lian", "hou|qu",
	"ao", "lin", "pen", "qiao", "ao", "fan", "yi", "hui", "xuan", "dao",
	"yao", "lao", "lao", "kao", "mao", "zhe", "qi|shi", "gou", "gou", "gou",
	"die", "die", "er", "shua", "ruan|nuo", "er|nai", "nai", "duan|zhuan", "lei", "ting",
	"zi", "geng", "chao", "hao", "yun", "ba|pa", "pi", "si|chi", "si", "qu|chu",
	"jia", "ju", "huo", "chu", "lao", "lun", "ji|jie", "tang", "ou", "lou",
	"nou", "jiang", "pang", "zha|ze", "lou", "ji", "lao", "huo", "you", "mo",
	"huai", "er", "yi", "ding", "ye", "da", "song", "qin", "yun|ying", "chi",
	"dan", "dan", "hong", "geng", "zhi", "pan", "nie", "dan", "zhen", "che",
	"ling", "zheng", "you", "wa|tui|zhuo", "liao", "long", "zhi", "ning", "tiao", "er|nv",
	"ya", "tie|zhe", "guo", "xu", "lian", "hao", "sheng", "lie", "pin", "jing",
	"ju", "bi", "di|zhi", "guo", "wen", "xu", "ping", "cong", "ding", "ni",
	"ting", "ju", "cong", "kui", "lian", "kui", "cong", "lian", "weng", "kui",
	"lian", "lian", "cong", "ao", "sheng", "song", "ting", "kui", "nie", "zhi",
	"dan", "ning", "qie", "ni|jian", "ting", "ting", "long", "yu", "yu", "zhao",
	"si", "su", "yi", "su", "si", "zhao", "zhao", "rou", "yi", "lei|le",
	"ji", "qiu", "ken", "cao", "ge", "bo|di", "huan", "huang", "chi", "ren",
	"xiao", "ru", "zhou", "yuan", "du", "gang", "rong|chen", "gan", "chai", "wo",
	"chang", "gu", "zhi", "qin|han", "fu", "fei", "ban", "pei", "pang|pan", "jian",
	"fang", "zhun|chun", "you", "na", "ang", "ken", "ran", "gong", "yu", "wen",
	"yao", "qi", "pi|bi", "qian", "xi", "xi", "fei", "ken", "jing", "tai",
	"shen", "zhong", "zhang", "xie", "shen", "wei", "zhou", "die", "dan", "fei|bi",
	"ba", "bo", "qu", "tian", "bei", "gua", "tai", "zi|fei", "fei|ku", "zhi",
	"ni", "ping|peng", "zi", "fu|zhou", "pang|pan", "zhen", "xian", "zuo", "pei", "jia",
	"sheng", "zhi", "bao", "mu", "qu", "hu", "qia", "chi", "yin", "xu",
	"yang", "long", "dong", "ka", "lu", "jing", "nu", "yan", "pang", "kua",
	"yi", "guang", "hai", "ge", "dong", "chi", "jiao", "xiong", "xiong", "er",
	"an", "heng", "pian", "neng|nai", "zi", "gui|kui", "zheng", "tiao", "zhi", "cui",
	"mei", "xie", "cui", "xie", "mai", "mai", "ji", "xie", "nin", "kuai",
	"sa", "zang", "qi", "nao", "mi", "nong", "luan", "wan", "bo", "wen",
	"wan", "xiu", "jiao", "jing", "rou", "heng", "cuo", "lie", "shan", "ting",
	"mei", "chun", "shen", "jia", "te", "juan", "cu", "xiu", "xin", "tuo",
	"pao", "cheng", "nei", "fu", "dou", "tuo", "niao", "nao", "pi", "gu",
	"luo", "li", "lian", "zhang", "cui", "jie", "liang", "shui", "pi", "biao",
	"lun", "pian", "guo", "juan", "chui", "dan", "tian", "nei", "jing", "nai",
	"la", "ye", "a", "ren", "shen", "zhui", "fu", "fu", "ju", "fei",
	"qiang", "wan", "dong", "pi", "guo", "zong", "ding", "wo", "mei", "ruan",
	"zhuan", "chi", "cou", "luo", "ou", "di", "an", "xing", "nao", "shu",
	"shuan", "nan", "yun", "zhong", "rou", "e", "sai", "tu", "yao", "jian",
	"wei", "jiao", "yu", "jia", "duan", "bi", "chang", "fu", "xian", "ni",
	"mian", "wa", "teng", "tui", "bang", "qian", "lv", "wa", "shou", "tang",
	"su", "zhui", "ge", "yi", "bo", "liao", "ji", "pi", "xie", "gao",
	"lv", "bin", "ou", "chang", "lu|biao", "guo", "pang", "chuai", "biao", "jiang",
	"fu", "tang", "mo", "xi", "zhuan|chuan|chun", "lv", "jiao", "ying", "lv", "zhi",
	"xue", "cun", "lin", "tong", "peng", "ni", "chuai", "liao", "cui", "kui",
	"xiao", "teng", "fan|pan", "zhi", "jiao", "shan", "hu|wu", "cui", "run", "xiang",
	"sui", "fen", "ying", "shan|dan", "zhua", "dan", "kuai", "nong", "tun", "lian",
	"bi|bei", "yong", "jue", "chu", "yi", "juan", "la|ge", "lian", "sao", "tun",
	"gu", "qi", "cui", "bin", "xun", "nao", "wo|yue", "zang", "xian", "biao",
	"xing", "kuan", "la", "yan", "lu", "huo", "za", "luo", "qu", "zang",
	"luan", "ni|luan", "za", "chen", "qian|xian", "wo", "guang|jiong", "zang|cang", "lin", "guang|jiong",
	"zi", "jiao", "nie", "chou|xiu", "ji", "gao", "chou", "mian|bian", "nie", "zhi",
	"zhi", "ge", "jian", "die|zhi", "zhi|jin", "xiu", "tai", "zhen", "jiu", "xian",
	"yu", "cha", "yao", "yu", "chong", "xi", "xi", "jiu", "yu", "yu",
	"xing", "ju", "jiu", "xin", "she", "she", "she", "jiu", "shi", "tan",
	"shu", "shi", "tian", "tan", "pu", "pu", "guan", "hua", "tian", "chuan",
	"shun", "xia", "wu", "zhou", "dao", "chuan", "shan", "yi", "fan", "pa",
	"tai", "fan", "ban", "chuan", "hang", "fang", "ban", "bi", "lu", "zhong",
	"jian", "cang", "ling", "zhu", "ze", "duo", "bo", "xian", "ge", "chuan",
	"xia", "lu", "qiong", "pang", "xi", "kua", "fu", "zao", "feng", "li",
	"shao", "yu", "lang", "ting", "yu", "wei", "bo", "meng", "nian", "ju",
	"huang", "shou", "ke", "bian", "mu", "die", "dao", "bang", "cha", "yi",
	"sou", "cang", "cao", "lou", "dai", "xue", "yao", "chong", "deng", "dang",
	"qiang", "lu", "yi", "ji", "jian", "huo", "meng", "qi", "lu", "lu",
	"chan", "shuang", "gen", "liang", "jian", "jian", "se", "yan", "fu", "ping",
	"yan", "yan", "cao", "ao", "yi", "le", "ding", "qiu", "ai", "nai",
	"tiao", "qiu", "jie", "peng", "wan", "yi", "chai|cha", "mian", "mi", "gan",
	"qian", "yu", "yu", "shao", "xiong", "du", "hu|xia", "qi", "mang", "zi",
	"hui|hu", "sui", "zhi", "xiang", "bi|pi", "fu", "tun|chun", "wei", "wu", "zhi",
	"qi", "shan", "wen", "qian", "ren", "fu", "kou", "jie|gai", "lu", "xu|zhu",
	"ji", "qin", "qi", "yuan|yan", "fen", "ba", "rui", "xin", "ji", "hua",
	"lun|hua", "fang", "wu|hu", "jue", "gou", "zhi", "yun", "qin", "ao", "chu",
	"mao", "ya", "fei|fu", "reng", "hang", "cong", "chan|yin", "you", "bian", "yi",
	"qie", "wei", "li", "pi", "e", "xian", "chang", "cang", "zhu", "su",
	"di|ti", "yuan", "ran", "ling", "tai", "tiao|shao", "di", "miao", "qing", "ji",
	"yong", "ke|he", "mu", "bei", "bao", "gou", "min", "yi", "yi", "ju|qu",
	"pie", "ruo|re", "ku", "zhu|ning", "ni", "pa|bo", "bing", "shan", "xiu", "yao",
	"xian", "ben", "hong", "ying", "zuo|zha", "dong", "cha", "die", "nie", "gan",
	"hu", "ping|peng", "mei", "fu", "sheng|rui", "gu", "bi", "wei", "fu", "zhuo",
	"mao", "fan", "jia", "mao", "mao", "ba", "ci", "mo", "zi", "zhi",
	"chi", "ji", "jing", "long", "cong", "niao", "yuan", "xue", "ying", "qiong",
	"ge", "ming", "li", "rong", "yin", "gen", "qian", "chai", "chen", "yu",
	"hao", "zi", "lie", "wu", "ji", "gui", "ci", "jian", "ci", "hou",
	"guang", "mang", "cha", "jiao", "jiao", "fu", "yu", "zhu", "zi", "jiang",
	"hui", "yin", "cha", "fa", "rong", "ru", "chong", "mang", "tong", "zhong",
	"qian", "zhu", "xun", "huan", "fu", "quan", "gai", "da", "jing", "xing",
	"chuan", "cao", "jing", "er", "an", "qiao", "chi", "ren", "jian", "ti",
	"huang", "ping", "li", "jin", "lao", "shu", "zhuang", "da", "jia", "rao",
	"bi", "ce", "qiao", "hui", "ji", "dang", "zi", "rong", "hun", "xing",
	"luo", "ying", "qian", "jin", "sun", "yin", "mai", "hong", "zhou", "yao",
	"du", "wei", "li", "dou", "fu", "ren", "yin", "he", "bi", "bu",
	"yun", "di", "tu", "sui", "sui", "cheng", "chen", "wu", "bie", "xi",
	"geng", "li", "pu", "zhu", "mo", "li", "zhuang", "zuo", "tuo", "qiu",
	"suo|sha", "suo", "chen", "peng|feng", "ju", "mei", "meng", "xing", "jing", "che",
	"shen|xin", "jun", "yan", "ting", "you", "cuo", "guan|wan", "han", "you", "cuo",
	"jia", "wang", "su|you", "niu", "shao|xiao", "xian", "lang|liang", "fu|piao", "e", "mo|mu",
	"wen|wan|mian", "jie", "nan", "mu", "kan", "lai", "lian", "shi", "wo", "tu",
	"xian|lian", "huo", "you", "ying", "ying", "neus", "chun", "mang", "mang", "ci",
	"wan|yun", "jing", "di", "qu", "dong", "jian", "zou|chu", "gu", "la", "lu",
	"ju", "wei", "jun", "nie|ren", "kun", "he", "pu", "zi|zai", "gao", "guo",
	"fu", "lun", "chang", "chou", "song", "chui", "zhan", "men", "cai", "ba",
	"li", "tu", "bo", "han", "bao", "qin", "juan", "xi", "qin", "di",
	"jie|sha", "pu", "dang", "jin", "qiao|zhao", "tai|zhi|chi", "geng", "hua", "gu", "ling",
	"fei", "qin|jin", "an", "wang", "beng", "zhou", "yan", "zu", "jian", "lin|ma",
	"tan", "shu", "tian", "dao", "hu", "qi", "he", "cui", "tao", "chun",
	"bi", "chang", "huan", "fei", "lai", "qi", "meng", "ping", "wei", "dan",
	"sha", "huan", "yan", "yi", "tiao", "qi", "wan", "ce", "nai", "zhen",
	"tuo", "jiu", "tie", "luo", "bi", "yi", "pan", "bo", "pao", "ding",
	"ying", "ying", "ying", "xiao", "sa", "qiu", "ke", "xiang", "wan", "yu",
	"yu", "fu", "lian", "xuan", "xuan", "nan", "ce", "wo", "chun", "shao",
	"yu", "bian", "mao", "an", "e", "luo|la|lao", "ying", "kuo", "kuo", "jiang",
	"mian", "zuo", "zuo", "zu", "bao", "rou", "xi", "ye", "an", "qu",
	"jian", "fu", "lv", "jing", "pen", "feng", "hong", "hong", "hou", "xing",
	"tu", "zhu|zhuo|zhe", "zi", "xiang", "ren", "ge", "qia", "qing", "mi", "huang",
	"shen", "pu", "gai", "dong", "zhou", "qian", "wei", "bo", "wei", "pa",
	"ji", "hu", "zang", "jia", "duan", "yao", "jun", "cong", "quan", "wei",
	"zhen", "kui", "ting", "hun", "xi", "shi", "qi", "lan", "zong", "yao",
	"yuan", "mei", "yun", "shu", "di", "zhuan", "guan", "ran", "xue", "chan",
	"kai", "kui|kuai", "uu", "jiang", "lou", "wei", "pai", "yong", "sou", "yin",
	"shi", "chun", "shi", "yun", "zhen", "lang", "ru|na", "meng", "li", "que",
	"suan", "yuan|huan", "li", "ju", "xi", "bang", "chu", "xu|shu", "tu", "liu",
	"huo", "dian", "qian", "ju", "po", "cuo", "yuan", "chu", "yu", "kuai",
	"pan", "pu", "pu", "na", "shuo", "xi", "fen", "yun", "zheng", "jian",
	"ji", "ruo", "cang", "en", "mi", "hao", "sun", "zhen", "ming", "sou",
	"xu", "liu", "xi", "gu", "lang", "rong", "weng", "gai|ge|he", "cuo", "shi",
	"tang", "luo", "ru", "suo", "xuan", "bei", "yao|zhuo", "gui", "bi", "zong",
	"gun", "zuo", "tiao", "ce", "pei", "lan", "dan", "ji", "li", "shen",
	"lang", "yu", "ling", "ying", "mo", "diao|tiao|di", "tiao", "mao", "tong", "zhu",
	"peng", "an", "lian", "cong", "xi", "ping", "qiu|xu|fu", "jin", "chun", "jie",
	"wei", "tui", "cao", "yu", "yi", "zi|ju", "liao|lu", "bi", "lu", "xu",
	"bu", "zhang", "lei", "qiang", "man", "yan", "ling", "ji", "biao", "gun",
	"han", "di", "su", "lu", "she", "shang", "di", "mie", "hun", "wan",
	"bu", "di", "cuo", "zhe", "shen", "xuan", "wei", "hu", "ao", "mi",
	"lou", "cu", "zhong", "cai", "po", "jiang", "mi", "cong", "niao", "hui",
	"juan", "yin", "jian", "nian", "shu", "yin", "guo", "chen", "hu", "sha",
	"kou", "qian", "ma", "zang", "ze", "qiang", "dou", "lian", "lin", "kou",
	"ai", "bi", "li", "wei", "ji", "qian", "sheng", "fan", "meng", "ou",
	"chan", "dian", "xun", "jiao", "rui", "rui", "lei", "yu", "qiao", "zhu",
	"hua", "jian", "mai", "yun", "bao", "you", "qu", "lu", "rao", "hui",
	"e", "ti", "fei", "jue", "zui", "fa", "ru", "fen", "kui", "shun",
	"rui", "ya", "xu", "fu", "jue", "dang", "wu", "dong", "si", "xiao",
	"xi", "sa", "yun", "shao", "qi", "jian", "yun", "sun", "ling", "yu",
	"xia", "weng", "ji", "hong", "si", "nong", "lei", "xuan", "yun", "yu",
	"xi|xiao", "hao", "bao|bo", "hao", "ai", "wei", "hui", "hui", "ji", "ci",
	"xiang", "wan|luan", "mie", "yi", "leng", "jiang", "can", "shen", "qiang|se", "lian",
	"ke", "yuan", "da", "ti", "tang", "xue", "bi", "zhan", "sun", "xian|lian",
	"fan", "ding", "xie", "gu", "xie", "shu", "jian", "hao|kao", "hong", "sa",
	"xin", "xun", "yao", "bai", "sou", "shu", "xun", "dui", "pin", "yuan|wei",
	"ning", "chou|zhou", "mai|wo", "ru", "piao", "tai", "ji", "zao", "chen", "zhen",
	"er", "ni", "ying", "gao", "cong", "xiao|hao", "qi", "fa", "jian", "xu",
	"kui", "jie|ji", "bian", "diao|zhuo", "mi", "lan", "jin", "cang|zang", "miao", "qiong",
	"qi", "xian", "liao", "ou", "xian", "su", "lv", "yi", "mai", "xie",
	"li", "yi", "la", "lei", "jiao", "di", "zhi", "bei", "teng", "yao|yue",
	"mo", "huan", "biao|pao", "fan", "sou", "tan", "tui", "qiong", "qiao", "wei",
	"liu", "hui", "ou", "gao", "yun", "bao", "li", "shu", "zhu|chu", "ai",
	"lin", "zao", "xuan", "qin", "lai", "huo", "tuo", "wu", "rui", "rui",
	"qi", "heng", "lu", "su", "tui", "mang", "yun", "ping", "yu", "xun",
	"ji", "jiong", "xuan", "mo", "qiu", "su", "jiong", "peng", "nie", "nie",
	"rang", "yi", "xian", "yu", "ju", "lian", "lian", "yin", "qiang", "ying",
	"long", "tou", "hua", "yue", "ling", "qu", "yao", "fan", "mi", "lan",
	"gui", "lan", "ji", "dang", "man", "lei", "lei", "hui", "feng", "zhi",
	"wei", "kui", "zhan", "huai", "li", "ji", "mi", "lei", "huai", "luo",
	"ji", "kui", "lu", "jian", "sal", "teng", "lei", "quan", "xiao", "yi",
	"luan", "men", "bie", "hu", "hu", "lu", "nve", "lv", "si", "xiao",
	"qian", "chu", "hu", "xu", "cuo", "fu", "xu", "xu", "lu", "hu",
	"yu", "hao", "jiao", "ju", "guo", "bao", "yan", "zhan", "zhan", "kui",
	"bin", "xi", "shu", "chong", "qiu", "diao", "ji", "qiu", "ding", "shi",
	"xia", "jue", "zhe", "she", "yu", "han", "zi", "hong", "hui", "meng",
	"ge", "sui", "xia", "chai", "shi", "yi", "ma", "xiang", "fang|bang", "e",
	"ba", "chi", "qian", "wen", "wen", "rui", "bang|beng", "pi", "yue", "yue",
	"jun", "qi", "tong", "yin", "qi|zhi", "can", "yuan|wan", "jue|que", "hui", "qin|qian",
	"qi", "zhong", "ya", "hao", "mu", "wang", "fen", "fen", "hang", "gong|zhong",
	"zao", "fu", "ran", "jie", "fu", "chi", "dou", "bao", "xian", "ni",
	"dai|de", "qiu", "you", "zha", "ping", "chi", "you", "he", "han", "ju",
	"li", "fu", "ran", "zha", "gou|qu|xu", "pi", "pi|bo", "xian", "zhu", "diao",
	"bie", "bing", "gu", "zhan", "qu", "she|yi", "tie", "ling", "gu", "dan",
	"tun", "ying", "li", "cheng", "qu", "mou", "ge|luo", "ci", "hui", "hui",
	"mang|bang", "fu", "yang", "wa", "lie", "zhu", "yi", "xian", "kuo", "jiao",
	"li", "yi|xu", "ping", "jie", "ge|ha", "she", "yi", "wang", "mo", "qiong",
	"qie|ni", "gui", "qiong", "zhi", "man", "lao", "zhe", "jia", "nao", "si",
	"qi", "xing", "jie", "qiu", "xiao", "yong", "jia", "tui", "che", "bei",
	"e|yi", "han", "shu", "xuan", "feng", "shen", "shen", "fu", "xian", "zhe",
	"wu", "fu", "li", "lang", "bi", "chu", "yuan", "you", "jie", "dan",
	"yan", "ting", "dian", "tui", "hui", "wo", "zhi", "zhong", "fei", "ju",
	"mi", "qi", "qi", "yu", "jun", "la", "meng", "qiang", "si", "xi",
	"lun", "li", "die", "tiao", "tao", "kun", "han", "han", "yu", "bang",
	"fei", "pi", "wei", "dun", "yi", "yuan", "suo", "quan", "qian", "rui",
	"ni", "qing", "wei", "liang", "guo", "wan", "dong", "e", "ban", "di",
	"wang", "can", "yang", "ying", "guo", "chan", "ding", "la", "ke", "ji",
	"xie", "ting", "mao", "xu", "mian", "yu", "jie", "shi", "xuan", "huang",
	"yan", "bian", "rou", "wei", "fu", "yuan", "mei", "wei", "fu", "ru",
	"xie", "you", "qiu", "mao", "xia", "ying", "shi", "chong", "tang", "zhu",
	"zong", "di", "fu", "yuan", "kui", "meng", "la", "dai", "hu", "qiu",
	"die", "li", "wo", "yun", "qu", "nan", "lou", "chun", "rong", "ying",
	"jiang", "ban", "lang", "pang", "si", "xi", "ci", "xi", "yuan", "weng",
	"lian", "sou", "ban", "rong", "rong", "ji", "wu", "xiu", "han", "qin",
	"yi", "bi", "hua", "tang", "yi", "du", "nai|neng", "he|xia", "hu", "gui|hui",
	"ma", "ming", "yi", "wen", "ying", "teng", "zhong", "cang", "sao", "qi",
	"man", "dao", "shang", "shi|zhe", "cao", "chi", "di", "ao", "lu", "wei",
	"die|zhi", "tang", "chen", "piao", "qu|ju", "pi", "yu", "chan|jian", "luo", "lou",
	"qin", "zhong", "yin", "jiang", "shuai", "wen", "xiao", "wan", "zhe", "zhe",
	"ma", "ma", "guo", "liu", "mao", "xi", "cong", "li", "man", "xiao",
	"chang", "zhang", "mang|meng", "xiang", "mo", "zui", "si", "qiu", "te", "zhi",
	"peng", "peng", "jiao", "qu", "bie", "liao", "pan", "gui", "xi", "ji",
	"zhuan", "huang", "fei|ben", "lao|liao", "jue", "jue", "hui", "yin|xun", "chan", "jiao",
	"shan", "nao", "xiao", "wu", "chong", "xun", "si", "chu", "cheng", "dang",
	"li", "xie", "shan", "yi", "jing", "da", "chan", "qi", "ci", "xiang",
	"she", "luo", "qin", "ying", "chai", "li", "zei", "xuan", "lian", "zhu",
	"ze", "xie", "mang", "xie", "qi", "rong", "jian", "meng", "hao", "ru",
	"huo", "zhuo", "jie", "pin", "he", "mie", "fan", "lei", "jie", "la",
	"min", "li", "chun", "li", "qiu", "nie", "lu", "du", "xiao", "zhu",
	"long", "li", "long", "feng", "ye", "pi", "nang", "gu", "juan", "ying",
	"shu", "xi", "can", "qu", "quan", "du", "can", "man", "qu", "jie",
	"zhu", "zhuo", "xie", "huang", "nv", "pei", "nv", "xin", "zhong", "mai",
	"er", "ke", "mie", "xi", "xing|hang|heng", "yan", "kan", "yuan", "qu", "ling",
	"xuan", "shu", "xian", "tong", "xiang", "jie", "xian", "ya", "hu", "wei",
	"dao", "chong", "wei", "dao", "zhun", "heng", "qu", "yi", "yi", "bu",
	"gan", "yu", "biao", "cha", "yi", "shan", "chen", "fu", "gun", "fen",
	"shuai", "jie", "na", "zhong", "dan", "ri", "zhong", "zhong", "jie", "zhi",
	"xie", "ran", "zhi", "ren", "qin", "jin", "jun", "yuan", "mei", "chai",
	"ao", "niao", "hui", "ran", "jia", "tuo", "ling", "dai", "bao|pao", "pao",
	"yao", "zuo", "bi", "shao", "tan", "ju|jie", "he|ke", "xue", "xiu", "zhen",
	"yi", "pa", "fu", "di", "wa", "fu", "gun", "zhi", "zhi", "ran",
	"pan", "yi", "mao", "tuo", "na|jue", "gou", "xuan", "zhe", "qu", "bei|pi",
	"yu", "xi", "mi", "bo", "uu", "fu", "chi|nuo", "chi|qi|duo|nuo", "ku", "ren",
	"peng", "jia|jie|qia", "jian|zun", "bo|mo", "jie", "er", "ge", "ru", "zhu", "gui|gua",
	"yin", "cai", "lie", "ka", "hang", "zhuang", "dang", "xu", "kun", "ken",
	"niao", "shu", "jia", "kun", "cheng", "li", "juan", "shen", "pou", "ge|jie",
	"yi", "yu", "zhen", "liu", "qiu", "qun", "ji", "yi", "bu", "zhuang",
	"shui", "sha", "qun", "li", "lian", "lian", "ku", "jian", "bao", "chan",
	"bi|pi", "kun", "tao", "yuan", "ling", "chi", "chang", "chou|dao", "duo", "biao",
	"liang", "chang|shBng", "pei", "pei", "fei", "yuan|gun", "luo", "guo", "yan|an", "du",
	"xi|ti", "zhi", "ju", "yi", "qi", "guo", "gua", "ken", "qi", "ti",
	"ti", "fu", "chong", "xie", "bian", "die", "kun", "duan", "xiu", "xiu",
	"he", "yuan", "bao", "bao", "fu", "yu", "tuan", "yan", "hui", "bei",
	"zhu", "lv", "pao", "dan", "yun", "ta", "gou", "da", "huai", "rong",
	"yuan", "ru", "nai", "jiong", "suo", "ban", "tui", "chi", "sang", "niao",
	"ying", "jie", "qian", "huai", "ku", "lian", "lan", "li", "zhe", "shi",
	"lv", "yi", "die", "xie", "xian", "wei", "biao", "cao", "ji", "qiang",
	"sen", "bao", "xiang", "bi", "fu", "jian", "zhuan", "jian", "cui", "ji",
	"dan", "za", "fan", "bo", "xiang", "xin", "bie", "rao", "man", "lan",
	"ao", "ze", "gui", "cao", "sui", "nong", "chan", "lian", "bi", "jin",
	"dang", "shu", "tan", "bi", "lan", "fu", "ru", "zhi", "ta", "shu",
	"wa", "shi", "bai", "xie", "bo", "chen", "lai", "long", "xi", "xian",
	"lan", "zhe", "dai", "ju", "zan", "shi", "jian", "pan", "yi", "lan",
	"ya", "xi", "ya", "yao", "feng", "tan|qin", "fu", "fiao", "fu", "ba|po",
	"he", "ji", "ji", "jian|xian", "guan", "bian", "yan", "gui", "jue|jiao", "pian",
	"mao", "mi", "mi", "pie|mie", "shi", "si", "chan", "zhen", "jue|jiao", "mi",
	"tiao", "lian", "yao", "zhi", "jun", "xi", "shan", "wei", "xi", "tian",
	"yu", "lan", "e", "du", "qin|qing", "pang", "ji", "ming", "ying", "gou",
	"qu", "zhan", "jin", "guan", "deng", "jian|bian", "luo|luan", "qu", "jian", "wei",
	"jue|jiao", "qu", "luo", "lan", "shen", "di", "guan", "jian|xian", "guan", "yan",
	"gui", "mi", "shi", "chan", "lan", "jue|jiao", "ji", "xi", "di", "tian",
	"yu", "gou", "jin", "qu", "jiao|jue", "qiu", "jin", "cu", "jue", "zhi",
	"chao", "ji", "gu", "dan", "zi|zui", "di", "shang", "hua|xie", "quan", "ge",
	"shi", "jie|xie", "gui", "gong", "chu", "jie|xie", "hun", "qiu", "xing", "su",
	"ni", "ji|qi", "jue", "zhi", "zha", "bi", "xing", "hu", "shang", "gong",
	"zhi", "xue|hu", "chu", "xi", "yi", "li|lu", "jue", "xi", "yan", "xi",
	"yan", "yan", "ding", "fu", "qiu", "qiu", "jiao", "hong", "ji", "fan",
	"xun", "diao", "hong", "chai", "tao", "xu", "jie", "dan", "ren", "xun",
	"yin", "shan", "qi", "tuo", "ji", "xun", "yin", "e", "fen", "ya",
	"yao", "song", "shen", "yin", "xin", "jue", "xiao", "ne", "chen", "you",
	"zhi", "xiong", "fang", "xin", "chao", "she", "yan", "sa", "zhun", "xu",
	"yi", "yi", "su", "chi", "he", "shen", "he", "xu", "zhen", "zhu",
	"zheng", "gou", "zi", "zi", "zhan", "gu", "fu", "jian", "die", "ling",
	"di", "yang", "li", "nao", "pan", "zhou", "gan", "yi", "ju", "yao",
	"zha", "tuo", "yi", "qu", "zhao", "ping", "bi", "xiong", "qu", "ba",
	"da", "zu", "tao", "zhu", "ci", "zhe", "yong", "xu", "xun", "yi",
	"huang", "he", "shi", "cha", "xiao", "shi", "hen", "cha", "gou", "gui",
	"quan", "hui", "jie", "hua", "gai", "xiang", "wei", "shen", "chou", "tong",
	"mi", "zhan", "ming", "luo", "hui", "yan", "xiong", "gua", "er", "bing",
	"tiao|diao", "yi|chi", "lei", "zhu", "kuang", "kua", "wu", "yu", "teng", "ji",
	"zhi", "ren", "cu", "lang", "e", "kuang", "ei|xi", "shi", "ting", "dan",
	"bei|bo", "chan", "you", "keng", "qiao", "qin", "shua", "an", "yu", "xiao",
	"cheng", "jie", "xian", "wu", "wu", "gao", "song", "bu", "hui", "jing",
	"shuo|shui|yue", "zhen", "shuo|shui|yue", "du", "hua", "chang", "shui|shei", "jie", "ke", "qu|jue",
	"cong", "xiao", "sui", "wang", "xian", "fei", "chi|lai", "ta", "yi", "ni|na",
	"yin", "diao|tiao", "pi|bei", "zhuo", "chan", "chen", "zhun", "ji", "qi", "tan",
	"zhui", "wei", "ju", "qing", "dong", "zheng", "ze|zuo|zha|cuo", "zou", "qian", "zhuo",
	"liang", "jian", "chu|ji", "xia|hao", "lun", "shen", "biao", "hua", "bian", "yu",
	"die", "xu", "pian", "shi|di", "xuan", "shi", "hun", "hua|gua", "e", "zhong",
	"di", "xie", "fu", "pu", "ting", "jian", "qi", "yu", "zi", "zhuan",
	"xi|shai|ai", "hui", "yin", "an", "xian", "nan", "chen", "feng", "zhu", "yang",
	"yan", "huang", "xuan", "ge", "nuo", "xu", "mou", "ye", "wei", "xing",
	"teng", "zhou", "shan", "jian", "bo", "kui", "huang", "huo", "ge", "ying",
	"mi", "xiao", "mi", "xi", "qiang", "chen", "xue", "ti", "su", "bang",
	"chi", "qian", "shi", "jiang", "yuan", "xie", "he", "tao", "yao", "yao",
	"lu", "yu", "biao", "cong", "qing", "li", "mo", "mo", "shang", "zhe",
	"miu", "jian", "ze", "jie", "lian", "lou", "can", "ou", "gun", "xi",
	"zhuo", "ao", "ao", "jin", "zhe", "yi", "hu", "jiang", "man", "chao",
	"han", "hua", "chan", "xu", "zeng", "se", "xi", "zha", "dui", "zheng",
	"nao", "lan", "e", "ying", "jue", "ji", "zun", "jiao", "bo", "hui",
	"zhuan", "wu", "zen", "zha", "shi", "qiao", "tan", "jian", "pu", "sheng",
	"xuan", "zao", "tan", "dang", "sui", "xian", "ji", "jiao", "jing", "zhan",
	"nong", "yi", "ai", "zhan", "pi", "hui", "hua", "yi", "yi", "shan",
	"rang", "rou", "qian", "dui", "ta", "hu", "zhou", "hao", "ai", "ying",
	"jian", "yu", "jian", "hui", "du", "zhe", "juan|xuan", "zan", "lei", "shen",
	"wei", "chan", "li", "yi|tui", "bian", "zhe", "yan", "e", "chou", "wei",
	"chou", "yao", "chan", "rang", "yin", "lan", "chen", "xie", "nie", "huan",
	"zan", "yi", "dang", "zhan", "yan", "du", "yan", "ji", "ding", "fu",
	"ren", "ji", "jie", "hong", "tao", "rang", "shan", "qi", "tuo", "xun",
	"yi", "xun", "ji", "ren", "jiang", "hui", "ou", "ju", "ya", "ne",
	"xu|hu", "e", "lun", "xiong", "song", "feng", "she", "fang", "jue", "zheng",
	"gu", "he", "ping", "zu", "shi|zhi", "xiong", "zha", "su", "zhen", "di",
	"zhou", "ci", "qu", "zhao", "bi", "yi", "yi|dai", "kuang", "lei", "shi",
	"gua", "shi", "jie|ji", "hui", "cheng", "zhu", "shen", "hua", "dan", "gou",
	"quan", "gui", "xun", "yi", "zheng", "gai", "xiang|yang", "cha", "hun", "xu",
	"zhou|chou", "jie", "wu", "yu", "qiao", "wu", "gao", "you", "hui", "kuang",
	"shuo|shui|yue", "song", "ei|xi", "qing", "zhu", "zou", "nuo", "du|dou", "zhuo", "fei",
	"ke", "wei", "yu", "shui", "shen", "diao", "chan", "liang", "zhun", "sui",
	"tan", "shen", "yi", "mou", "chen", "die", "huang", "jian", "xie", "xue",
	"ye", "wei", "e", "yu", "xuan", "chan", "zi", "an", "yan", "di",
	"mi", "pian", "xu", "mo", "dang", "su", "xie", "yao", "bang", "shi",
	"qian", "mi", "jin", "man", "zhe", "jian", "miu", "tan", "zen", "qiao",
	"lan", "pu", "jue", "yan", "qian", "zhan", "chen", "gu", "qian", "hong",
	"xia", "ji", "hong", "han", "hong", "xi", "xi", "huo", "liao", "han",
	"du", "long", "dou", "jiang", "qi", "chi", "li", "deng", "wan", "bi",
	"shu", "xian", "feng", "zhi", "zhi", "yan", "yan", "shi", "chu", "hui",
	"tun", "yi", "tun", "yi", "jian", "ba", "hou", "e", "chu", "xiang",
	"huan", "jian", "ken", "gai", "ju", "fu", "xi", "bin", "hao", "yu",
	"zhu", "jia", "fen", "xi", "hu", "wen", "huan", "bin", "di", "zong",
	"fen", "yi", "zhi", "bao", "chai", "an", "pi", "na", "pi", "gou",
	"na", "you", "diao", "mo", "si", "xiu", "huan", "ken|kun", "he|mo", "he|hao|mo",
	"mo", "an", "mao", "li", "ni", "bi", "yu", "jia", "tuan", "mao",
	"pi", "xi", "yi", "ju|lou", "mo", "chu", "tan", "huan", "jue", "bei",
	"zhen", "yuan|yun", "fu", "cai", "gong", "dai", "yi", "hang", "wan", "pin",
	"huo", "fan", "tan", "guan", "ze|zhai", "zhi", "er", "zhu", "shi", "bi",
	"zi", "er", "gui", "pian", "bian", "mai", "dai|te", "sheng", "kuang", "fei",
	"tie", "yi", "chi", "mao", "he", "bi|ben", "lu", "lin", "hui", "gai",
	"pian", "zi", "jia|gu", "xu", "zei", "jiao", "gai", "zang", "jian", "ying",
	"jun", "zhen", "she", "bin", "bin", "qiu", "she", "chuan", "zang", "zhou",
	"lai", "zan", "ci", "chen", "shang", "tian", "pei", "geng", "xian", "mai",
	"jian", "sui", "fu", "dan", "cong", "cong", "zhi", "lai", "zhang", "du",
	"jin", "xiong|min", "chun", "yun", "bao", "zai", "lai", "feng", "cang", "ji",
	"sheng", "ai", "zhuan|zuan", "fu", "gou", "sai", "ze", "liao", "yi", "bai",
	"chen", "wan", "zhi", "zhui", "biao", "yun", "zeng", "dan", "zan", "yan",
	"pu", "shan", "wan", "ying", "jin", "gan", "xian", "zang", "bi", "du",
	"shu", "yan", "shang", "xuan", "long", "gan", "zang", "bei", "zhen", "fu",
	"yuan", "gong", "cai", "ze", "xian", "bai", "zhang", "huo", "zhi", "fan",
	"tan", "pin", "bian", "gou", "zhu", "guan", "er", "jian", "bi", "shi",
	"tie", "gui", "kuang", "dai", "mao", "fei", "he", "yi", "zei", "zhi",
	"jia|gu", "hui", "zi", "lin", "lu", "zang", "zi", "gai", "jin", "qiu",
	"zhen", "lai", "she", "fu", "du", "ji", "shu", "shang", "ci", "bi",
	"zhou", "geng", "pei", "dan", "lai", "feng", "zhui", "fu", "zhuan", "sai",
	"ze", "yan", "zan", "yun", "zeng", "shan", "ying", "gan", "chi", "xi",
	"she", "nan", "tong", "xi", "cheng", "he", "cheng", "zhe", "xia", "tang",
	"zou", "zou", "li", "jiu", "fu", "zhao", "gan", "qi", "shan", "qiong",
	"yin", "xian", "zi", "jue", "qin", "chi", "ci", "chen", "chen", "die|tu",
	"qie|ju", "chao", "di", "xi", "zhan", "jue", "yue", "qu|cu", "ji|jie", "qu",
	"chu", "gua|huo", "xue", "zi", "tiao", "duo", "lie", "gan", "suo", "cu",
	"xi", "zhao", "su", "yin", "ju", "jian", "que|qi|ji", "tang", "chuo", "cui",
	"lu", "qu|cu", "dang", "qiu", "zi", "ti", "qu|cu", "chi", "huang", "qiao",
	"qiao", "jiao", "zao", "ti|yue", "er", "zan", "zan", "zu", "pa", "bao|bo",
	"kua|wu", "ke", "dun", "jue|gui", "fu", "chen", "jian", "fang|pang", "zhi", "ta",
	"yue", "ba|pao", "qi", "yue", "qiang", "tuo", "tai", "yi", "jian|chen", "ling",
	"mei", "ba", "die", "ku", "tuo", "jia", "ci", "pao", "qia", "zhu",
	"ju", "dian|tie|die", "zhi", "fu", "pan|ban", "ju|qie", "shan", "bo", "ni", "ju",
	"li|luo", "gen", "yi", "ji", "dai|duo|chi", "xian", "jiao", "duo", "zhu", "quan",
	"kua", "zhuai", "gui", "qiong", "kui", "xiang", "die", "lu", "pian|beng", "zhi",
	"jie", "tiao|tao", "cai", "jian", "da", "qiao", "bi", "xian", "duo", "ji",
	"ju", "ji", "shu|chou", "tu", "chuo", "jing", "nie", "xiao", "bu", "xue",
	"qun", "mu", "shu", "liang", "yong", "jiao", "chou", "qiao", "mou", "ta",
	"jian", "ji", "wo", "wei", "chuo", "jie", "ji", "nie", "ju", "nie",
	"lun", "lu", "leng", "huai", "ju", "chi", "wan", "quan", "ti", "bo",
	"zu", "qie", "qi", "cu", "zong", "cai", "zong", "peng", "zhi", "zheng",
	"dian", "zhi", "yu", "duo", "dun", "chuan", "yong", "zhong", "di", "zhe",
	"chen", "chuai", "jian", "gua", "tang", "ju", "fu", "cu", "die", "pian",
	"rou", "nuo", "ti", "cha", "tui", "jian", "dao", "cuo", "xi", "ta",
	"qiang", "nian", "dian", "ti", "ji", "nie", "pan", "liu", "zan", "bi",
	"chong", "lu", "liao", "cu", "tang", "dai", "su", "xi", "kui", "ji",
	"zhi", "qiang", "di", "pan", "zong", "lian", "beng", "zao", "nian", "bie",
	"tui", "ju", "deng", "ceng", "xian", "fan", "chu", "zhong", "dun", "bo",
	"cu", "cu", "jue", "jue", "lin", "ta", "qiao", "qiao", "pu", "liao",
	"dun", "cuan", "guan", "zao", "ta", "bi", "bi", "zhu", "ju", "chu",
	"qiao", "dun", "chou", "ji", "wu", "yue", "nian", "lin", "lie", "zhi",
	"li|luo", "zhi", "chan", "chu", "duan", "wei", "long", "lin", "xian", "wei",
	"zuan", "lan", "xie", "rang", "sa|xie", "nie", "ta", "qu", "ji", "cuan",
	"zuan", "xi", "kui", "jue", "lin", "shen", "gong", "dan", "fen", "qu",
	"ti", "duo", "duo", "gong", "lang", "ren", "luo", "ai", "ji", "ju",
	"tang", "kong", "lao", "yan", "mei", "kang", "qu", "lou", "lao", "duo",
	"zhi", "yan", "ti", "dao", "ying", "yu", "che|ju", "ya|zha|ga", "gui", "jun",
	"wei", "yue", "xin|xian", "dai", "xuan", "fan|gui", "ren", "shan", "kuang", "shu",
	"tun", "chen", "dai", "e", "na", "qi", "mao", "ruan", "kuang", "qian",
	"zhuan", "hong", "hu", "qu", "kuang", "di", "ling", "dai", "ao", "zhen",
	"fan", "kuang", "yang", "peng", "bei", "gu", "gu", "pao", "zhu", "rong",
	"e", "ba", "zhou", "zhi", "yao", "ke", "yi", "qing", "shi", "ping",
	"er", "gong", "ju", "jiao", "guang", "lu", "kai", "quan", "zhou", "zai",
	"zhi", "she", "liang", "yu", "shao", "you", "wan", "yin", "zhe", "wan",
	"fu", "qing", "zhou", "ni", "ling", "zhe", "han", "liang", "zi", "hui",
	"wang", "chuo", "guo", "kan", "yi", "peng", "qian", "gun", "nian", "ping",
	"guan", "bei", "lun", "pai", "liang", "ruan", "rou", "ji", "yang", "xian",
	"chuan", "cou", "chun", "ge", "you", "hong", "shu", "fu", "zi", "fu",
	"wen", "fan", "zhan", "yu", "wen", "tao", "gu", "zhen", "xia", "yuan",
	"lu", "jiao", "chao", "zhuan", "wei", "hun", "xue", "zhe", "jiao", "zhan",
	"bu", "lao", "fen", "fan", "lin", "ge", "se", "kan", "huan", "yi",
	"ji", "dui", "er", "yu", "jian", "hong", "lei", "pei", "li", "li",
	"lu", "lin", "che", "ya", "gui", "xuan", "dai", "ren", "zhuan", "e",
	"lun", "ruan", "hong", "gu", "ke", "lu", "zhou", "zhi", "yi", "hu",
	"zhen", "li", "yao", "qing", "shi", "zai", "zhi", "jiao", "zhou", "quan",
	"lu", "jiao", "zhe", "fu", "liang", "nian", "bei", "hui", "gun", "wang",
	"liang", "chuo", "zi", "cou", "fu", "ji", "wen", "shu", "pei", "yuan",
	"xia", "zhan|nian", "lu", "zhe", "lin", "xin", "gu", "ci", "ci", "bi|pi",
	"zui", "bian", "la", "la", "ci", "xue", "ban", "bian", "bian", "bian",
	"xue", "bian", "ban", "ci", "bian", "bian", "chen", "ru", "nong", "nong",
	"zhen", "chuo", "chuo", "yi", "reng", "bian", "dao|bian", "shi", "yu", "liao",
	"da", "chan", "gan", "qian", "yu", "yu", "qi", "xun", "yi", "guo",
	"mai", "qi", "bi", "wang|kuang", "tu", "zhun", "ying", "da", "yun", "jin",
	"hang", "ya", "fan", "wu", "da", "e", "huan|hai", "zhe|zhei", "da", "jin",
	"yuan", "wei", "lian", "chi", "che", "chi", "tiao", "zhi|li", "yi", "jiong",
	"jia", "chen", "dai", "er", "di", "po|pai", "zhu|wang", "die", "ze", "tao",
	"shu", "yi", "keop", "jing", "hui", "dong", "you", "mi", "beng", "ji",
	"nai", "yi", "jie", "zhui|dui", "lie", "xun", "tui", "song", "kuo", "tao",
	"pang", "hou", "ni", "dun", "jiong", "xuan", "xun", "bu", "you", "xiao",
	"qiu", "tou", "zhu", "qiu", "di", "di", "tu", "jing", "ti", "dou",
	"yi", "zhe", "tong", "guang", "wu", "shi", "cheng", "su", "zao", "qun",
	"feng", "lian", "suo", "hui", "li", "gu", "lai", "ben", "cuo", "zhu",
	"beng", "huan", "dai", "lu", "you", "zhou", "jin", "yu", "chuo", "kui",
	"wei", "ti", "yi", "da", "yuan", "luo", "bi", "nuo", "yu", "dang",
	"sui", "dun", "sui", "yan", "chuan", "chi", "di", "yu", "shi", "zhen",
	"you", "yun", "e", "bian", "guo", "e", "xia", "huang", "qiu", "dao",
	"da", "wei", "nan", "yi", "gou", "yao", "chou", "liu", "xun", "ta",
	"di", "chi", "yuan", "su", "ta", "qian", "ma", "yao", "guan", "zhang",
	"ao", "shi", "ca", "chi", "su", "zao", "zhe", "dun", "di", "lou",
	"chi", "cuo", "lin", "zun", "rao", "qian", "xuan", "yu", "wei", "e",
	"liao", "ju", "shi", "bi", "yao", "mai", "xie", "sui", "huan|hai", "zhan",
	"teng", "er", "miao", "bian", "bian", "la", "li|chi", "yuan", "yao", "luo",
	"li", "yi", "ting", "deng", "qi", "yong", "shan", "han", "yu", "mang",
	"ru", "qiong", "xi", "kuang", "fu", "kang|hang", "bin", "fang", "xing", "na|nei",
	"xin", "shen", "bang", "yuan", "cun", "huo", "xie|ya|ye|yu|xu", "bang", "wu", "ju",
	"you", "han", "tai", "qiu", "bi", "pi", "bing", "shao", "bei", "wa",
	"di", "zou", "ye", "lin", "kuang", "gui", "zhu", "shi", "ku", "yu",
	"gai|hai", "he", "qie|xi", "zhi", "ji", "xun|huan", "hou", "xing", "jiao", "xi",
	"gui", "na", "lang", "jia", "kuai", "zheng", "lang", "yun", "yan", "cheng",
	"dou", "chi", "lv", "fu", "wu", "fu", "gao", "hao", "lang", "jia",
	"geng", "jun", "ying", "bo", "xi", "bei", "li|zhi", "yun", "bu", "xiao|ao",
	"qi", "pi", "qing", "guo", "zhou", "tan", "zou", "ping", "lai", "ni",
	"chen", "you", "bu", "xiang", "dan", "ju", "yong", "qiao", "yi", "du|dou",
	"yan", "mei", "ruo", "bei", "e", "shu", "juan", "yu", "yun", "hou",
	"kui", "xiang", "xiang", "sou", "tang", "ming", "xi", "ru", "chu", "zi",
	"zou", "yi", "wu", "xiang", "yun", "hao", "yong", "bi", "mao", "chao",
	"fu", "liao", "yin", "zhuan", "hu", "qiao", "yan", "zhang", "man", "qiao",
	"xu", "deng", "bi", "xun", "bi", "zeng", "wei", "zheng", "mao", "shan",
	"lin", "po", "dan", "meng", "ye", "cao", "kuai", "feng", "meng", "zou",
	"kuang", "lian", "zan", "chan", "you", "qi", "yan", "chan", "cuo", "ling",
	"huan", "xi", "feng", "cuo", "li", "you", "ding", "qiu", "zhuo", "pei",
	"zhou", "yi", "gan", "yu", "jiu", "yan", "zui", "mao", "dan", "xu",
	"dou", "zhen", "fen", "yuan", "fu", "yun", "tai", "tian", "qia", "tuo",
	"cu", "han", "gu", "su", "fa", "chou", "zai", "ming", "lao", "chuo",
	"chou", "you", "tong", "zhi", "xian", "jiang", "cheng", "yin", "tu", "jiao",
	"mei", "ku", "suan", "lei", "pu", "zui", "hai", "yan", "shai", "niang",
	"wei", "lu", "lan", "yan", "tao", "pei", "zhan", "chun", "tan|dan", "zui",
	"zhui", "cu", "kun", "ti", "xian", "du", "hu", "xu", "xing", "tan",
	"qiu|chou", "chun", "yun", "fa", "ke", "sou", "mi", "quan", "chou", "cuo",
	"yun", "yong", "ang", "zha", "hai", "tang", "jiang", "piao", "chan|chen", "yu",
	"li", "zao", "lao", "yi", "jiang", "bu", "jiao", "xi", "tan", "po|fa",
	"nong", "yi|shi", "li", "ju", "yan|lian|xian", "yi", "niang", "ru", "xun", "chou",
	"yan", "ling", "mi", "mi", "niang", "xin", "jiao", "shi", "mi", "yan",
	"bian", "cai", "shi", "you", "shi", "shi", "li", "zhong|chong", "ye", "liang",
	"li", "jin", "jin", "ga", "yi", "liao", "dao", "zhao", "ding", "po",
	"qiu", "he", "fu", "zhen", "zhi", "ba", "luan", "fu", "nai", "diao",
	"shan", "qiao|jiao", "kou", "chuan", "zi", "fan", "hua|yu", "hua|wu", "han", "gang",
	"qi", "mang", "ri|ren|jian", "di|dai", "si", "xi", "yi", "chai", "shi|yi", "tu",
	"xi", "nv", "qian", "qiu", "ri|ren|jian", "pi|zhao", "ye|ya", "jin", "ba", "fang",
	"chen", "xing", "dou", "yue", "qian", "fu", "bu", "na", "xin", "e",
	"jue", "dun", "gou", "yin", "qian", "ban", "sa", "ren", "chao", "niu",
	"fen", "yun", "yi", "qin", "pi", "guo", "hong", "yin", "jun", "diao",
	"yi", "zhong", "xi", "gai", "ri", "huo", "tai", "kang", "yuan", "lu",
	"e", "qin", "duo", "zi", "ni", "tu", "shi", "min", "gu", "ke",
	"ling", "bing", "si", "gu", "bo", "pi", "yu", "si", "zuo", "bu",
	"you", "dian", "jia", "zhen", "shi", "shi", "tie", "ju", "zuan", "shi",
	"ta", "xuan", "zhao", "bao", "he", "bi", "sheng", "chu", "shi", "bo",
	"zhu", "chi", "za", "po", "tong", "qian", "fu", "zhai", "mao", "qian",
	"fu", "li", "yue", "pi", "yang", "ban", "bo", "jie", "gou", "shu",
	"zheng", "mu", "xi", "xi", "di", "jia", "mu", "tan", "shen", "yi",
	"si", "kuang", "ka", "bei", "jian", "tong", "xing", "hong", "jiao", "chi",
	"er", "ge", "bing", "shi", "mao", "ha", "yin", "jun", "zhou", "chong",
	"xiang|jiong", "tong", "mo", "lei", "ji", "yu|si", "xu|hui", "ren", "zun", "zhi",
	"qiong", "shan|shuo", "chi|li", "xian|xi", "xing", "quan", "pi", "tie", "zhu", "hou|xiang",
	"ming", "kua", "diao|tiao|yao", "xian|kuo|tian|gua", "xian", "xiu", "jun", "cha", "lao", "ji",
	"pi", "ru", "mi", "yi", "yin", "guang", "an", "diu", "you", "se",
	"kao", "qian", "luan", "si", "ng", "diao", "han", "rui", "shi|zhi", "keng",
	"qiu", "xiao", "zhe|nie", "xiu", "zang", "ti", "cuo", "xian|kuo|tian|gua", "hong|gong", "zhong|yong",
	"tou|tu|dou", "lv", "mei|meng", "lang", "wan|jian", "xin", "yun|jun", "bei", "wu", "su",
	"yu", "chan", "ting|ding", "bo", "han", "jia", "hong", "juan|jian|cuan", "feng", "chan",
	"wan", "zhi", "si", "xuan|juan", "hua|wu", "wu", "tiao", "kuang", "zhuo|chuo", "lve",
	"xing|jing", "qin", "shen", "han", "lve", "ye", "chu", "zeng", "ju", "xian",
	"e", "mang", "pu", "li", "pan", "rui", "cheng", "gao", "li", "te",
	"bing", "zhu", "zhen", "tu", "liu", "zui|nie", "ju", "chang", "yuan|wan", "jian",
	"gang", "diao", "tao", "shang", "lun", "ke", "ling", "pi", "lu", "li",
	"qing", "pei", "juan", "min", "zui", "peng", "an", "pi", "xian", "ya",
	"zhui", "lei", "a", "kong", "ta", "kun", "du", "nei", "chui", "zi",
	"zheng", "ben", "nie", "cong", "chun", "tan", "ding", "qi", "qian", "zhui",
	"ji", "yu", "jin", "guan", "mao", "chang", "tian", "xi", "lian", "diao",
	"gu", "cuo", "shu", "zhen", "lu", "meng", "lu", "hua", "biao", "ga",
	"lai", "ken", "fang", "bu", "nai", "wan", "zan", "hu", "de", "xian",
	"uu", "huo", "liang", "fa", "men", "kai", "yang", "chi", "lian", "guo",
	"xian", "du", "tu", "wei", "zong", "fu", "rou", "ji", "e", "jun",
	"chen", "ti", "zha", "hu", "yang", "duan", "xia", "yu", "keng", "sheng",
	"huang", "wei", "fu", "zhao", "cha", "qie", "shi", "hong", "kui", "nuo",
	"mou", "qiao", "qiao", "hou", "tou", "cong", "huan", "ye", "min", "jian",
	"duan", "jian", "si", "kui", "hu", "xuan", "zhe", "jie", "zhen", "bian",
	"zhong", "zi", "xiu", "ye", "mei", "pai", "ai", "jie", "qian", "mei",
	"cuo|cha", "da|ta", "bang", "xia", "lian", "suo|se", "kai", "liu", "yao|zu", "ye|ta|ge",
	"nou", "weng", "rong", "tang", "suo", "qiang|cheng", "ge|li", "shuo", "chui", "bo",
	"pan", "da", "bi|pi", "sang", "gang", "zi", "wu", "ying", "huang", "tiao",
	"liu", "kai", "sun", "sha", "sou", "wan|jian", "gao|hao", "zhen", "zhen", "lang",
	"yi", "yuan", "tang", "nie", "xi", "jia", "ge", "ma", "juan", "song",
	"zu", "suo", "xia", "feng", "wen", "na", "lu", "suo", "ou", "zu|chuo",
	"tuan", "xiu", "guan", "xuan", "lian", "shou|sou", "ao", "man", "mo", "luo",
	"bi", "wei", "liu", "di", "san|qiao|can", "cong", "yi", "lu|ao", "ao", "keng",
	"qiang", "cui", "qi", "shang", "tang", "man", "yong", "chan", "feng", "jing",
	"biao", "shu", "lou", "xiu", "cong", "long", "zan", "jian|zan", "cao", "li",
	"xia", "xi", "kang", "shuang", "beng", "zhang", "qian", "zheng", "lu", "hua",
	"ji", "pu", "hui|sui|rui", "qiang", "po", "lin", "se", "xiu", "san|xian|sa", "cheng",
	"gui", "si", "liu", "nao", "huang", "pie", "sui", "fan", "qiao", "quan",
	"xi", "tang", "xiang", "jue", "jiao", "zun", "liao", "qi", "lao", "dui",
	"xin", "zan", "ji", "jian", "zhong", "deng", "ya", "ying", "dui", "jue",
	"nou", "zan", "pu", "tie", "uu", "cheng", "ding", "shan", "kai", "jian",
	"fei", "sui", "lu", "juan", "hui", "yu", "lian", "zhuo", "qiao", "jian",
	"zhuo", "lei", "bi", "tie", "huan", "ye", "duo", "guo", "dang", "ju",
	"fen", "da", "bei", "yi", "ai", "zong", "xun", "diao", "zhu", "heng",
	"zhui", "ji", "nie", "he", "huo", "qing", "bin", "ying", "gui", "ning",
	"xu", "jian", "jian", "qian", "cha", "zhi", "mie", "li", "lei", "ji",
	"zuan", "kuang", "shang", "peng", "la", "du", "shuo", "chuo", "lv", "biao",
	"pao", "lu", "xian", "kuan", "long", "e", "lu", "xin", "jian", "lan",
	"bo", "jian", "yao", "chan", "xiang", "jian", "xi", "guan", "cang", "nie",
	"lei", "cuan", "qu", "pan", "luo", "zuan", "luan", "zao", "nie", "jue",
	"tang", "zhu", "lan", "jin", "ga", "yi", "zhen", "ding", "zhao", "po",
	"liao", "tu", "qian", "chuan", "shan", "sa|xi", "fan", "diao", "men", "nv",
	"yang", "chai", "xing", "gai", "bu", "tai", "ju", "dun", "chao", "zhong",
	"na", "bei", "gang", "ban", "qian", "yue|yao", "qin", "jun", "wu", "gou",
	"kang", "fang", "huo", "dou", "niu", "ba|pa", "yu", "qian", "zheng", "qian",
	"gu", "bo", "ke", "po", "bu", "bo", "yue", "zuan", "mu", "tan",
	"jia", "dian|tian", "you", "tie", "bo", "ling", "shuo", "qian|yan", "mao", "bao",
	"shi", "xuan", "ta|tuo", "bi", "ni", "pi", "duo", "xing", "kao", "lao",
	"er", "mang", "ya", "you", "cheng", "jia", "ye", "nao", "zhi", "dang|cheng",
	"tong", "lv", "diao", "yin", "kai", "zha", "zhu", "xian|xi", "ting|ding", "diu",
	"xian|kuo|tian|gua", "hua", "quan", "sha", "ha|ke", "diao|tiao|yao", "ge", "ming", "zheng", "se",
	"jiao", "yi", "chan", "chong", "tang", "an", "yin", "ru", "zhu", "lao",
	"pu", "wu", "lai", "te", "lian", "keng", "xiao", "suo", "li", "zeng",
	"chu", "guo", "gao", "e", "xiu", "cuo", "lve", "feng", "xin", "liu",
	"kai", "jian", "rui", "ti", "lang", "qin", "ju", "a", "qiang", "zhe",
	"nuo", "cuo", "mao", "ben", "qi", "de", "ke", "kun", "chang", "xi",
	"gu", "luo", "chui", "zhui", "jin", "zhi", "xian", "juan", "huo", "pei",
	"tan", "ding", "jian", "ju", "meng", "zi", "qie", "ying", "kai", "qiang",
	"si", "e", "cha", "qiao", "zhong", "duan", "sou", "huang", "huan", "ai",
	"du", "mei", "lou", "zi", "fei", "mei", "mo", "zhen", "bo", "ge",
	"nie", "tang", "juan", "nie", "na", "liu", "gao", "bang", "yi", "jia",
	"bin", "rong", "biao", "tang", "man", "luo", "beng", "yong", "jing", "di",
	"zu", "xuan", "liu", "xin", "jue", "liao", "pu", "lu", "dui", "lan",
	"pu", "cuan", "qiang", "deng", "huo", "lei", "huan", "zhuo", "lian", "yi",
	"cha", "biao", "la", "chan", "xiang", "chang", "chang", "jiu", "ao", "die",
	"jie", "liao", "mi", "chang|zhang", "men", "ma", "shuan", "shan", "huo|shan", "men",
	"yan", "bi", "han|bi", "bi", "ci ka Bi lu", "kai", "kang", "beng", "hong", "run",
	"san", "xian", "xian|jian", "jian", "min", "xia", "lao", "dou", "zha", "nao",
	"zhan", "peng", "xia|ke", "ling", "bian|guan", "bi", "run", "he", "guan", "ge",
	"he", "fa", "chu", "hong|xiang", "gui", "min", "se", "kun", "lang", "lv",
	"ting", "sha", "ju", "yue", "yue", "chan", "qu", "lin", "chang", "sha",
	"kun", "yan", "wen", "yan", "e|yan", "hun", "yu", "wen", "hong", "bao",
	"hong|juan|xiang", "qu", "yao", "wen", "ban|pan", "an", "wei", "yin", "kuo", "que",
	"lan", "du", "quan", "pBi ying|po he deng", "tian", "nie", "ta", "kai", "he", "que",
	"chuang", "guan", "dou", "qi", "kui", "tang|chang", "guan", "piao", "kan|han", "xi|se|ta",
	"hui", "chan", "bi", "dang", "huan", "ta", "wen", "ta", "men", "shuan",
	"shan", "yan", "han|bi", "bi", "wen", "chuang", "run", "wei", "xian", "hong",
	"jian", "min", "kang", "men", "zha", "nao", "gui", "wen", "ta", "min",
	"lv", "kai", "fa", "ge", "he", "kun", "jiu", "yue", "lang", "du",
	"yu", "yan", "chang", "xi", "wen", "hun", "yan", "e", "chan", "lan",
	"qu", "hui", "kuo", "que", "he", "tian", "ta", "que", "kan|han", "huan",
	"fu", "fu", "le", "dui", "xin", "qian", "wu", "yi", "tuo", "yin",
	"yang", "dou", "e", "sheng", "ban", "pei", "keng", "yun", "ruan", "zhi",
	"pi", "jing", "fang", "yang", "yin", "zhen", "jie", "cheng", "e", "qu",
	"di", "zu", "zuo", "dian", "lin", "a", "tuo", "tuo", "bei", "bing",
	"fu", "ji", "lu", "long", "chen", "xing", "duo", "lou", "mo", "jiang",
	"shu", "duo", "xian", "er", "gui", "yu", "gai", "shan", "jun", "qiao",
	"xing", "chun", "wu", "bi", "xia", "shan", "sheng", "zhi", "pu", "dou",
	"yuan", "zhen", "chu", "xian", "dao", "nie", "yun", "xian", "pei", "fei",
	"zou", "qi", "dui", "lun", "yin", "ju", "chui", "chen", "pi", "ling",
	"tao", "xian", "lu", "sheng", "xian", "yin", "zhu", "yang", "reng", "xia",
	"chong", "yan", "yin", "yu|yao|shu", "di", "yu", "long", "wei", "wei", "nie",
	"dui|zhui", "sui|duo", "an", "huang", "jie", "sui", "yin", "qi|gai|ai", "yan", "hui|duo",
	"ge", "yun", "wu", "wei|kui", "ai", "xi", "tang", "ji", "zhang", "dao",
	"ao", "xi", "yin", "sa", "rao", "lin", "tui", "deng", "pi", "sui",
	"sui", "ao|yu", "xian", "fen", "ni", "er", "ji", "dao", "xi", "yin",
	"zhi", "hui|duo", "long", "xi", "li|dai", "li|dai", "li|dai", "zhui|cui|wei", "hu|he", "zhi",
	"sun", "jun|juan", "nan|nuo", "yi", "que|qiao", "yan", "qin", "jian", "xiong", "ya",
	"ji", "gu", "huan", "zhi", "gou", "jun|juan", "ci", "yong", "ju", "chu",
	"hu", "za", "luo", "yu", "chou", "diao", "sui", "han", "huo", "shuang",
	"guan|huan", "chu", "za", "yong", "ji", "gui|xi", "chou", "liu", "li", "nan|nuo",
	"yu", "za", "chou", "ji", "yu", "yu", "xue", "na", "fou", "se|xi",
	"mu", "wen", "fen", "pang", "yun", "li", "chi", "yang", "ling", "lei",
	"an", "bao", "wu|meng", "dian", "dang", "hu", "wu", "diao", "xu", "ji",
	"mu", "chen", "xiao", "zha", "ting", "zhen", "pei", "mei", "ling", "qi",
	"zhou", "huo", "sha", "fei", "hong", "zhan", "yin", "ni", "shu", "tun",
	"lin", "ling", "dong", "ying", "wu", "ling", "shuang", "ling", "xia", "hong",
	"yin", "mai", "mai", "yun", "liu", "meng", "bin", "wu", "wei", "kuo",
	"yin", "xi", "yi", "ai", "dan", "teng", "xian", "yu", "lu", "long",
	"dai", "ji", "pang", "yang", "ba", "pi", "wei", "uu", "xi", "ji",
	"mai", "meng", "meng", "lei", "li", "huo", "ai", "fei", "dai", "long",
	"ling", "ai", "feng", "li", "bao", "he", "he", "he", "bing", "qing",
	"qing", "liang", "tian", "zheng", "jing", "cheng", "qing", "jing", "liang", "dian",
	"jing", "tian", "fei", "fei", "kao", "mi", "mian", "mian", "pao", "ye",
	"mian", "hui", "ye", "ge", "ding", "cha", "jian", "ren", "di", "du",
	"wu", "ren", "qin", "jin", "xue", "niu", "ba", "yin", "sa", "na",
	"mo", "zu", "da", "ban", "xie", "yao", "tao", "bei", "jie", "hong",
	"pao", "yang", "bing", "yin", "ge|ta|sa", "tao", "jie|ji", "xie", "an", "an",
	"hen", "gong", "qia", "da", "qiao", "ting", "man|men", "bian|ying", "sui", "tiao",
	"qiao|shao", "xuan|juan", "kong", "beng", "ta", "shang|zhang", "bing|pi|bi|bei", "kuo", "ju", "la",
	"xie|die", "rou", "bang", "eng", "qiu", "qiu", "he", "qiao", "mu|mou", "ju",
	"jian", "bian", "di", "jian", "wen|yun", "tao", "gou", "ta", "bei", "xie",
	"pan", "ge", "bi|bing", "kuo", "tang", "lou", "gui", "qiao", "xue", "ji",
	"jian", "jiang", "chan", "da", "huo", "xian", "qian", "du", "wa", "jian",
	"lan", "wei", "ren", "fu", "mei|wa", "quan", "ge", "wei", "qiao", "han",
	"chang", "kuo", "rou", "yun", "she|xie", "wei", "ge", "bai", "tao", "gou",
	"yun", "gao", "bi", "wei", "sui", "du", "wa", "du", "wei", "ren",
	"fu", "han", "wei", "yun|wen", "tao", "jiu", "jiu", "xian", "xie", "xian",
	"ji", "yin", "za", "yun", "shao", "le", "peng", "huang", "ying", "yun",
	"peng", "an", "yin", "xiang", "hu", "ye", "ding", "qing", "qiu", "xiang",
	"shun", "han", "xu", "yi", "xu", "e", "song", "kui", "qi", "hang",
	"yu", "wan", "ban", "dun", "di", "dan", "pan", "po", "ling", "che",
	"jing", "lei", "he", "qiao", "e", "e", "wei", "jie", "kuo", "shen",
	"yi", "yi", "ke", "dui", "yu", "ping", "lei", "fu", "jia", "tou",
	"hui", "kui", "jia", "luo", "ting", "cheng", "ying", "jun", "hu", "han",
	"geng", "tui", "tui", "bin", "lai", "tui", "zi", "zi", "chui", "ding",
	"lai", "tan", "han", "qian", "ke", "cui", "jiong", "qin", "yi", "sai",
	"ti", "e", "e", "yan", "wen", "kan", "yong", "zhuan", "yan", "xian",
	"xin", "yi", "yuan", "sang", "dian", "dian", "jiang", "kui", "lei", "lao",
	"piao", "wai", "man", "cu", "yao", "hao", "qiao", "gu", "xun", "yan",
	"hui", "chan", "ru", "meng", "bin", "xian", "pin", "lu", "lan", "nie",
	"quan", "ye", "ding", "qing", "han", "xiang", "shun", "xu", "xu", "wan",
	"gu", "dun", "qi", "ban", "song", "hang", "yu", "lu", "ling", "po",
	"jing|geng", "jie|xie|jia", "jia", "ting", "he|ge", "ying", "jiong", "ke", "yi", "pin|bin",
	"hui", "tui", "han", "ying", "ying", "ke", "ti", "yong", "e", "zhuan",
	"yan", "e", "nie", "man", "dian", "sang", "hao", "lei", "chan|zhan", "ru",
	"pin", "quan", "feng", "biao|diu", "gua", "fu", "xia", "zhan", "biao", "sa",
	"ba|fu", "tai", "lie", "gua", "xuan", "xiao", "ju", "biao", "si", "wei",
	"yang", "yao", "sou", "kai", "sao|sou", "fan", "liu", "xi", "liu|liao", "piao",
	"piao", "liu", "biao", "biao", "biao", "liao", "biao", "se", "feng", "xiu",
	"feng", "yang", "zhan", "biao", "sa", "ju", "si", "sou", "yao", "liu",
	"piao", "biao", "biao", "fei", "fan", "fei", "fei", "shi|si|yi", "shi", "can",
	"ji", "ding", "si", "tuo", "zhan", "sun", "xiang", "tun", "ren", "yu",
	"yang|juan", "chi", "yin", "fan", "fan", "sun", "yin", "zhu|tou", "si", "zuo|ze|zha",
	"bi", "jie", "tao", "bao", "ci", "tie", "si", "bao", "shi", "duo",
	"hai", "ren", "tian", "jiao", "he", "bing", "yao", "tong", "ci", "xiang",
	"yang", "juan", "er", "yan", "le", "xi", "can", "bo", "nei", "e",
	"bu", "jun", "dou", "su", "yu", "shi", "yao", "hun", "guo", "shi",
	"jian", "chuo", "bing", "xian", "bu", "ye", "dan", "fei", "zhang", "wei",
	"guan", "e", "nuan", "yun", "hu", "huang", "tie", "hui", "jian", "hou",
	"ai", "xing", "fen", "wei", "gu", "cha", "song", "tang", "bo", "gao",
	"xi", "kui", "liu", "sou", "tao", "ye", "wen", "mo", "tang", "man",
	"bi", "yu", "xiu", "jin", "san", "kui", "zhuan", "shan", "xi", "dan",
	"yi", "ji", "rao", "cheng", "yong", "tao", "wei", "xiang", "zhan", "fen",
	"hai", "meng", "yan", "mo", "chan", "xiang", "luo", "zan", "nang", "shi",
	"ding", "ji", "tuo", "xing", "tun", "xi", "ren", "yu", "chi", "fan",
	"yin", "jian", "shi", "bao", "si", "duo", "yi", "er", "rao", "xiang",
	"he", "ge", "jiao", "xi", "bing", "bo", "dou", "e", "yu", "nei",
	"jun", "guo", "hun", "xian", "guan", "cha", "kui", "gu", "sou", "chan",
	"ye", "mo", "bo", "liu", "xiu", "jin", "man", "san", "zhuan", "nang",
	"shou", "kui", "guo", "xiang", "fen", "bo", "ni", "bi", "bo", "tu",
	"han", "fei", "jian", "an", "ai", "fu", "xian", "yun|wo", "xin", "fen",
	"pin", "xin", "ma", "yu", "feng|ping", "han", "di", "tuo|duo", "tuo|zhe", "chi",
	"xun", "zhu", "zhi|shi", "pei", "xin|jin", "ri", "sa", "yun", "wen", "zhi",
	"dan", "lu", "you", "bo", "bao", "jue|kuai", "tuo|duo", "yi", "qu", "wen",
	"qu", "jiong", "po", "zhao", "yuan", "peng", "zhou", "ju", "zhu", "nu",
	"ju", "pi", "zang", "jia", "ling", "zhen", "tai|dai", "fu", "yang", "shi",
	"bi", "tuo", "tuo", "si", "liu", "ma", "pian", "tao", "zhi", "rong",
	"teng", "dong", "xun|xuan", "quan", "shen", "jiong", "er", "hai", "bo", "zhu",
	"yin", "luo", "zhou", "dan", "hai", "liu", "ju", "song", "qin", "mang",
	"liang|lang", "han", "tu", "xuan", "tui", "jun", "e", "cheng", "xing", "dai",
	"lu", "zhui", "zhou", "she", "pian", "kun", "tao", "lai", "zong", "ke",
	"qi", "qi", "yan", "fei", "sao", "yan", "ge", "yao", "wu", "pian",
	"cong", "pian", "qian", "fei", "huang", "qian", "huo", "yu", "ti", "quan",
	"xia", "zong", "kui", "rou", "si", "gua", "tuo", "gui", "sou", "qian",
	"cheng", "zhi", "liu", "peng", "teng", "xi", "cao", "du", "yan", "yuan",
	"zou", "sao", "shan", "qi", "zhi", "shuang", "lu", "xi", "luo", "zhang",
	"mo", "ao", "can", "piao", "cong", "qu", "bi", "zhi", "yu", "xu",
	"hua", "bo", "su", "xiao", "lin", "zhan", "dun", "liu", "tuo", "ceng",
	"dian", "jiao", "tie", "yan", "luo", "zhan", "jing", "yi", "ye", "tuo",
	"pin", "zhou", "yan", "long", "lv", "teng", "xiang", "ji", "shuang", "ju",
	"xi", "huan", "li", "biao", "ma", "yu", "duo", "xun", "chi", "qu",
	"ri", "bo", "lv", "zang", "shi", "si", "fu", "ju", "zou", "zhu",
	"tuo", "nu", "jia", "yi", "dai", "xiao", "ma", "yin", "jiao", "hua",
	"luo", "hai", "pian", "biao", "li", "cheng", "yan", "xing", "qin", "jun",
	"qi", "qi", "ke", "zhui", "zong", "su", "can", "pian", "zhi", "kui",
	"sao", "wu", "ao", "liu", "qian", "shan", "piao|biao", "luo", "cong", "chan",
	"zhou", "ji", "shuang", "xiang", "gu", "wei", "wei", "wei", "yu", "gan",
	"yi", "ang", "tou", "jie", "bao", "bei|mo", "ci", "ti", "di", "ku",
	"hai", "qiao|xiao", "hou", "kua", "ge", "tui", "geng", "pian", "bi", "ke",
	"qia", "ou", "sui", "lou", "bo", "xiao", "bang", "bo|jue", "ci", "kuan",
	"bin", "mo", "liao", "lou", "xiao", "du", "zang", "sui", "ti", "bin",
	"kuan", "lu", "gao", "gao", "qiao", "kao", "qiao", "lao", "sao", "biao",
	"kun", "kun", "di", "fang", "xiu", "ran", "mao", "dan", "kun", "bin",
	"fa", "tiao", "pi", "zi", "fa", "ran", "ti", "bao", "bi|po", "mao|meng",
	"fu", "er", "er", "qu", "gong", "xiu", "kuo|yue", "ji", "peng", "zhua",
	"shao", "sha", "ti", "li", "bin", "zong", "ti", "peng", "song", "zheng",
	"quan", "zong", "shun", "jian", "duo", "hu", "la", "jiu", "qi", "lian",
	"zhen", "bin", "peng", "ma", "san", "man", "man", "seng", "xu", "lie",
	"qian", "qian", "nong", "huan", "kuo", "ning", "bin", "lie", "rang", "dou",
	"dou", "nao", "hong", "xi", "dou", "kan", "dou", "dou", "jiu", "chang",
	"yu", "yu", "ge", "yan", "fu", "zeng", "gui", "zong", "liu", "gui",
	"shang", "yu", "gui", "mei", "ji", "qi", "ga", "kui", "hun", "ba",
	"bo", "mei", "xu", "yan", "xiao", "liang", "yu", "tui", "qi", "wang",
	"liang", "wei", "gan", "chi", "piao", "bi", "mo", "ji", "xu", "chou",
	"yan", "zhan", "yu", "dao", "ren", "ji", "ba", "hong", "tuo", "diao",
	"ji", "yu", "e", "ji", "sha", "hang", "tun", "mo", "jie", "shen",
	"ban", "yuan", "pi", "lu", "wen", "hu", "lu", "za", "fang", "fen",
	"na", "you", "pian", "mo", "he", "xia", "qu", "han", "pi", "ling",
	"tuo", "ba", "qiu", "ping", "fu", "bi", "ci|ji", "wei", "ju", "diao",
	"bo|ba", "you", "gun", "pi", "nian", "xing", "tai", "bao", "fu", "zha",
	"ju", "gu", "shi", "dong", "chou", "ta", "jie", "shu", "hou", "xiang",
	"er", "an", "wei", "zhao", "zhu", "yin", "lie", "luo|ge", "tong", "yi",
	"yi", "bing", "wei", "jiao", "ku", "gui|xie|wa|kui", "xian", "ge", "hui", "lao",
	"fu", "kao", "xiu", "tuo", "jun", "ti", "mian", "shao", "zha", "suo",
	"qin", "yu", "nei", "zhe", "gun", "geng", "su", "wu", "qiu", "shan",
	"pu|bu", "huan", "tiao", "li", "sha", "sha", "kao", "meng", "cheng", "li",
	"zou", "xi", "yong", "shen", "zi", "qi", "qing", "xiang", "nei", "chun",
	"ji", "diao", "qie", "gu", "zhou", "dong", "lai", "fei", "ni", "yi|si",
	"kun", "lu", "jiu", "chang", "jing", "lun", "ling", "zou", "li", "meng",
	"zong", "zhi", "nian", "hu", "yu", "di", "shi", "shen", "huan", "ti",
	"hou", "xing", "zhu", "la", "zong", "ji", "bian", "bian", "huan", "quan",
	"zei", "wei", "wei", "yu", "chun", "rou", "die", "huang", "lian", "yan",
	"qiu", "qiu", "jian", "bi", "e", "yang", "fu", "sai", "jian", "xia",
	"tuo", "hu", "shi", "ruo", "xuan", "wen", "jian", "hao", "wu", "pang",
	"sao", "liu", "ma", "shi", "shi", "guan", "zi", "teng", "ta", "yao",
	"e", "yong", "qian", "qi", "wen", "ruo", "ha ta ha ta", "lian", "ao", "le",
	"hui", "min", "ji", "tiao", "qu", "jian", "shen", "man", "xi", "qiu",
	"piao", "ji", "ji", "zhu", "jiang", "xiu", "zhuan", "yong", "zhang", "kang",
	"xue", "bie", "yu", "qu", "xiang", "bo", "jiao", "xun", "su", "huang",
	"zun", "shan", "shan", "fan", "gui", "lin", "xun", "yao", "xi", "zeng",
	"xiang", "fen", "guan", "hou", "kuai", "zei", "sao", "zhan", "gan", "gui",
	"ying", "li", "chang", "lei", "se", "ai", "ru", "ji", "xu", "hu",
	"shu", "li", "lie", "le", "mie", "zhen", "xiang", "e", "lu", "guan",
	"li", "xian", "yu", "dao", "ji", "you", "tun", "lu", "fang", "ba",
	"he|ge", "ba", "ping", "nian", "lu", "you", "zha", "fu", "bo|ba", "bao",
	"hou", "pi", "tai", "gui|xie", "jie", "kao", "wei", "er", "tong", "zei",
	"hou", "kuai", "ji", "jiao", "xian", "zha", "xiang", "xun", "geng", "li",
	"lian", "jian", "li", "shi", "tiao", "gun", "sha", "huan", "jun", "ji",
	"yong", "qing", "ling", "qi", "zou", "fei", "kun", "chang", "gu", "ni",
	"nian", "diao", "jing", "shen", "shi", "zi", "fen", "die", "bi", "chang",
	"ti", "wen", "wei", "sai|xi", "e", "qiu", "fu", "huang", "quan", "jiang",
	"bian", "sao", "ao", "qi", "ta", "guan", "yao", "pang", "jian", "le",
	"biao", "xue", "bie", "man", "min", "yong", "wei", "xi", "gui|jue", "shan",
	"lin", "zun", "hu", "gan", "li", "zhan|shan", "guan", "niao|diao", "yi", "fu",
	"li", "jiu", "bu", "yan", "fu", "diao|zhao", "ji", "feng", "ru", "gan|han|yan",
	"shi", "feng", "ming", "bao", "yuan", "zhi", "hu", "qin", "fu|gui", "ban|fen",
	"wen", "jian|qian|zhan", "shi", "yu", "fou", "yao", "jue", "jue", "pi", "huan",
	"zhen", "bao", "yan", "ya", "zheng", "fang", "feng", "wen", "ou", "dai",
	"jia", "ru", "ling", "mie", "fu", "tuo", "min", "li", "bian", "zhi",
	"ge", "yuan", "ci", "qu", "xiao", "chi", "dan", "ju", "yao", "gu",
	"zhong", "yu", "yang", "yu", "ya", "die", "yu", "tian", "ying", "dui",
	"wu", "er", "gua", "ai", "zhi", "yan", "heng", "xiao", "jia", "lie",
	"zhu", "yang", "yi", "hong", "lu", "ru", "mou", "ge", "ren", "jiao",
	"xiu", "zhou", "chi", "luo", "heng", "nian", "e", "luan", "jia", "ji",
	"tu", "huan", "tuo", "bu", "wu", "juan", "yu", "bo", "jun", "jun",
	"bi", "xi", "jun", "ju", "tu", "jing", "ti", "e", "e", "kuang",
	"hu", "wu", "shen", "lai", "zan", "pan", "lu", "pi", "shu", "fu",
	"an", "zhuo", "peng", "qin", "qian", "bei", "diao", "lu", "que", "jian",
	"ju", "tu", "ya", "yuan", "qi", "li", "ye", "zhui", "kong", "duo",
	"kun", "sheng", "qi", "jing", "yi", "yi", "jing", "zi", "lai", "dong",
	"qi", "chun", "geng", "ju", "qu", "yi", "zun", "ji", "shu", "ying",
	"chi", "miao", "rou", "an", "qiu", "ti|chi", "hu", "ti|chi", "e", "jie",
	"mao", "fu|bi", "chun", "tu", "yan", "he|jie", "yuan", "pian|bian", "kun", "mei",
	"hu", "ying", "chuan|zhi", "wu", "ju", "dong", "cang|qiang", "fang", "he|hu", "ying",
	"yuan", "xian", "weng", "shi", "he", "chu", "tang", "xia", "ruo", "liu",
	"ji", "gu|hu", "jian", "sun|xun", "han", "ci", "ci", "yi", "yao", "yan",
	"ji", "li", "tian", "kou", "ti", "ti", "yi", "tu", "ma", "xiao",
	"gao", "tian", "chen", "ji", "tuan", "zhe", "ao", "yao", "yi", "ou",
	"chi", "zhi", "liu", "yong", "lou|lv", "bi", "shuang", "zhuo", "yu", "wu",
	"jue", "yin", "ti", "si", "jiao", "yi", "hua", "bi", "ying", "su",
	"huang", "fan", "jiao", "liao", "yan", "gao", "jiu", "xian", "xian", "tu",
	"mai", "zun", "yu", "ying", "lu", "tuan", "xian", "xue", "yi", "pi",
	"zhu", "luo", "xi", "yi", "ji", "ze", "yu", "zhan", "ye", "yang",
	"pi", "ning", "hu", "mi", "ying", "meng", "di", "yue", "yu", "lei",
	"bu", "lu", "he", "long", "shuang", "yue", "ying", "guan", "qu", "li",
	"luan", "niao", "jiu", "ji", "yuan", "ming", "shi", "ou", "ya", "cang",
	"bao", "zhen", "gu", "dong", "lu", "ya", "xiao", "yang", "ling", "chi",
	"qu", "yuan", "xue", "tuo", "si", "zhi", "er", "gua", "xiu", "heng",
	"zhou", "ge", "luan", "hong", "wu", "bo", "li", "juan", "hu", "e",
	"yu", "xian", "ti", "wu", "que", "miao", "an", "kun", "bei", "peng",
	"qian", "chun", "geng", "yuan", "su", "hu", "he", "e", "gu", "qiu",
	"ci", "mei", "wu", "yi", "yao", "weng", "liu", "ji", "yi", "jian",
	"he", "yi", "ying", "zhe", "liu", "liao", "jiao", "jiu", "yu", "lu",
	"huan", "zhan", "ying", "hu", "meng", "guan", "shuang", "lu", "jin", "ling",
	"jian", "xian", "cuo", "jian", "jian", "yan", "cuo", "lu", "you", "cu",
	"ji", "pao|biao", "cu", "pao", "zhu|cu", "jun|qun", "zhu", "jian", "mi", "mi",
	"yu", "liu", "chen", "jun", "lin", "ni", "qi", "lu", "jiu", "jun",
	"jing", "li", "xiang", "xian", "jia", "mi", "li", "she", "zhang", "lin",
	"jing", "qi", "ling", "yan", "cu", "mai", "mai", "he", "chao", "fu",
	"mian", "mian", "fu", "pao", "qu", "qu", "mou", "fu", "xian", "lai",
	"qu", "mian", "chi", "feng", "fu", "qu", "mian", "ma", "mo|me", "mo|me",
	"hui", "mi", "zou", "nun", "fen", "huang", "huang", "jin", "guang", "tian",
	"tou", "hong", "hua", "kuang", "hong", "shu", "li", "nian", "chi", "hei",
	"hei", "yi", "qian", "dan", "xi", "tun", "mo", "mo", "qian", "dai",
	"chu", "you", "dian", "yi", "xia", "yan", "qu", "mei", "yan", "qing",
	"yue", "li", "dang", "du", "can", "yan", "yan", "yan", "dan|shen", "an",
	"zhen|yan", "dai", "can", "yi", "mei", "dan|zhan", "yan", "du", "lu", "zhi",
	"fen", "fu", "fu", "min|mian|meng", "min|mian|meng", "yuan", "cu", "qu", "chao", "wa",
	"zhu", "zhi", "meng", "ao", "bie", "tuo", "bi", "yuan", "chao", "tuo",
	"ding", "mi", "nai", "ding", "zi", "gu", "gu", "dong", "fen", "tao",
	"yuan", "pi", "chang", "gao", "cao", "yuan", "tang", "teng", "shu", "shu",
	"fen", "fei", "wen", "ba", "diao", "tuo", "zhong", "qu", "sheng", "shi",
	"you", "shi", "ting", "wu", "ju", "jing", "hun", "ju", "yan", "tu",
	"si", "xi", "xian", "yan", "lei", "bi", "yao", "qiu", "han", "wu",
	"wu", "hou", "xie", "e", "zha", "xiu", "weng", "zha", "nong", "nang",
	"qi", "zhai", "ji", "zi", "ji", "ji", "qi", "ji", "chi", "chen",
	"chen", "he", "ya", "yin", "xie", "bao", "ze", "xie", "zi", "chi",
	"yan", "ju", "tiao", "ling", "ling", "chu", "quan", "xie", "yin", "nie",
	"jiu", "yao", "chuo", "yun", "yu", "chu", "yi", "ni", "ze", "zou",
	"qu", "yun", "yan", "yu", "e", "wo", "yi", "ci", "zou", "dian",
	"chu", "jin", "ya", "chi", "chen", "he", "yin|ken", "ju", "ling", "bao",
	"tiao", "zi", "yin|ken", "yu", "chuo", "qu", "wo", "long", "pang", "gong|wo",
	"pang", "yan", "long", "long", "gong", "kan", "da", "ling", "da", "long",
	"gong", "kan", "gui|jun|qiu", "qiu", "bie", "gui|jun|qiu", "yue", "chui", "he", "jiao",
	"xie", "yu"
};

#define DUOYINZI_SEPERATOR '|'


static int __media_svc_check_utf8(char c)
{
	if ((c & 0xff) < (128 & 0xff))
		return 1;
	else if ((c & (char)0xe0) == (char)0xc0)
		return 2;
	else if ((c & (char)0xf0) == (char)0xe0)
		return 3;
	else if ((c & (char)0xf8) == (char)0xf0)
		return 4;
	else if ((c & (char)0xfc) == (char)0xf8)
		return 5;
	else if ((c & (char)0xfe) == (char)0xfc)
		return 6;
	else
		return MS_MEDIA_ERR_INVALID_PARAMETER;
}

static inline int __media_svc_get_pinyinspell(UChar src, char spell[CHINESE_DUOYINZI_MAX_COUNT][CHINESE_PINYIN_SPELL_MAX_LEN])
{
	int offset, len, i, j;
	int count = 0;

	offset = src - CHINESE_UNICODE_START;
	media_svc_retvm_if(offset < 0 || offset >= CHINESE_COUNT, MS_MEDIA_ERR_INVALID_PARAMETER, "src is invalid");

	len = strlen(pinyin_spell_table[offset]);

	for (i = 0, j = 0; i <= len; i++) {
		if (pinyin_spell_table[offset][i] == DUOYINZI_SEPERATOR
		    || pinyin_spell_table[offset][i] == '\0') {
			strncpy(spell[count], pinyin_spell_table[offset] + j, i - j);
			j = i + 1;
			count++;
		}
	}

	return count;
}

static inline bool __media_svc_is_chinese(const UChar *src)
{
	if (CHINESE_UNICODE_START <= *src && *src <= CHINESE_UNICODE_END)
		return true;

	return	false;
}

#define MEDIA_SVC_CHINESE_MULTIPLE_PINYIN_MAX_LEN	3

int _media_svc_convert_chinese_to_pinyin(const char *src, pinyin_name_s **name, int *size)
{
	UChar	temp_result[strlen(src) + 1];
	int	count = 0, len = 0, total_count = 0;
	int ret, i, j;
	int multi_pinyin_count = 0;
	UErrorCode status = 0;
	pinyin_name_s *temp_name = NULL;

	*size = 0;

	media_svc_retvm_if(src == NULL, MS_MEDIA_ERR_INVALID_PARAMETER, "src is NULL");
	media_svc_retvm_if(!*src, MS_MEDIA_ERR_INVALID_PARAMETER, "*src is NULL");

	u_strFromUTF8(temp_result, array_sizeof(temp_result), NULL, src, -1, &status);
	if (U_FAILURE(status)) {
		media_svc_error("u_strFromUTF8 Failed(%s)", u_errorName(status));
		return MS_MEDIA_ERR_INTERNAL;
	}

	len = u_strlen(temp_result);

	char spell[len][CHINESE_DUOYINZI_MAX_COUNT][CHINESE_PINYIN_SPELL_MAX_LEN];
	int pinyin_spell_count[len];
	memset(spell, 0x0, len * CHINESE_DUOYINZI_MAX_COUNT * CHINESE_PINYIN_SPELL_MAX_LEN);

	for (count = 0; count < len; count++) {
		if (temp_result[count] == 0xFEFF || temp_result[count] == 0xFFFE) { /*  ||temp_result[count] == 0xFF) { */
			media_svc_error("FIND BOM, GO TO THE NEXT CHARACTER");
			pinyin_spell_count[count] = 1;
			continue;
		}

		if (__media_svc_is_chinese(&temp_result[count])) {
			ret = __media_svc_get_pinyinspell(temp_result[count], spell[count]);
			media_svc_retvm_if(ret < MS_MEDIA_ERR_NONE, MS_MEDIA_ERR_INTERNAL, "__media_svc_get_pinyinspell() Failed(%d)", ret);
			if (multi_pinyin_count >= MEDIA_SVC_CHINESE_MULTIPLE_PINYIN_MAX_LEN)
				ret = 1;

			pinyin_spell_count[count] = ret;

			if (total_count == 0)
				total_count = ret;
			else
				total_count *= ret;
			if (ret > 1)
				multi_pinyin_count++;
		} else {
			UChar temp[2];
			int temp_size;

			temp[0] = temp_result[count];
			temp[1] = 0x00;
			u_strToUTF8(spell[count][0], 10, &temp_size, temp, -1, &status);
			media_svc_retvm_if(U_FAILURE(status), MS_MEDIA_ERR_INTERNAL, "u_strToUTF8() Failed(%s)", u_errorName(status));
			spell[count][0][temp_size] = '\0';
			pinyin_spell_count[count] = 1;
		}
	}

	*size = total_count;
	temp_name = calloc(total_count, sizeof(pinyin_name_s));
	media_svc_retvm_if(temp_name == NULL, MS_MEDIA_ERR_OUT_OF_MEMORY, "calloc Failed()");

	int repeat = 1;
	int name_len[total_count];
	int initial_len[total_count];
	int pinyin_name_len = sizeof(char) * ((len + 2) * CHINESE_PINYIN_SPELL_MAX_LEN);
	int pinyin_initial_len = sizeof(char) * (len * 5 + 1);
	for (i = 0; i < count ; i++) {
		for (j = 0; j < total_count; j++) {
			if (pinyin_spell_count[i] == 0)
				continue;

			int index = (j / repeat) % pinyin_spell_count[i];

			if (i == 0) {
				name_len[j] = 0;
				initial_len[j] = 0;

				temp_name[j].pinyin_name = calloc(1, pinyin_name_len);
				temp_name[j].pinyin_initial = calloc(1, pinyin_initial_len);
				if (temp_name[j].pinyin_initial == NULL || temp_name[j].pinyin_name == NULL) {
					media_svc_error("calloc failed");
					SAFE_FREE(temp_name[j].pinyin_name);
					SAFE_FREE(temp_name[j].pinyin_initial);
					continue;
				}
			}

			if (spell[i][index][0]) {
				/*if(temp_name[j].pinyin_name[0]) */
				/*	name_len[j] += snprintf(temp_name[j].pinyin_name + name_len[j], pinyin_name_len - name_len[j], " "); */

				name_len[j] += snprintf(temp_name[j].pinyin_name + name_len[j], pinyin_name_len - name_len[j], "%s", spell[i][index]);

				int char_len = __media_svc_check_utf8(spell[i][index][0]);
				if (char_len > 0) {
					if (char_len == 1)
						initial_len[j] += snprintf(temp_name[j].pinyin_initial + initial_len[j], pinyin_initial_len - initial_len[j], "%c", spell[i][index][0]);
					else {
						char temp[10];
						snprintf(temp, sizeof(temp), "%s", spell[i][index]);
						temp[char_len] = '\0';
						initial_len[j] += snprintf(temp_name[j].pinyin_initial + initial_len[j], pinyin_initial_len - initial_len[j], "%s", temp);
					}
				} else {
					media_svc_error("_media_svc_check_utf8 failed");
					continue;
				}
			}
		}
		repeat *= pinyin_spell_count[i];
	}

	*name = temp_name;

	return MS_MEDIA_ERR_NONE;
}

void _media_svc_pinyin_free(pinyin_name_s *pinyinname, int size)
{
	int i;
	if (pinyinname == NULL)
		return;

	for (i = 0; i < size; i++) {
		SAFE_FREE(pinyinname[i].pinyin_initial);
		SAFE_FREE(pinyinname[i].pinyin_name);
	}
	SAFE_FREE(pinyinname);
}

